
#ifdef GET_DIAG_ARRAYS
static const int16_t DiagArrays[] = {
  /* Empty */ -1,
  /* DiagArray1 */ diag::warn_pragma_message, -1,
  /* DiagArray2 */ diag::pp_hash_warning, -1,
  /* DiagArray3 */ diag::warn_cfstring_truncated, -1,
  /* DiagArray5 */ diag::warn_independentclass_attribute, diag::warn_ptr_independentclass_attribute, -1,
  /* DiagArray6 */ diag::warn_nsobject_attribute, -1,
  /* DiagArray8 */ diag::warn_abs_too_small, diag::warn_pointer_abs, diag::warn_unsigned_abs, diag::warn_wrong_absolute_value_type, -1,
  /* DiagArray9 */ diag::warn_abstract_final_class, -1,
  /* DiagArray10 */ diag::warn_abstract_vbase_init_ignored, -1,
  /* DiagArray12 */ diag::warn_taking_address_of_packed_member, -1,
  /* DiagArray13 */ diag::ext_typecheck_addrof_temporary, -1,
  /* DiagArray16 */ diag::warn_alloca, -1,
  /* DiagArray17 */ diag::warn_alloca_align_alignof, -1,
  /* DiagArray18 */ diag::warn_ambiguous_suitable_delete_function_found, -1,
  /* DiagArray19 */ diag::warn_misplaced_ellipsis_vararg, -1,
  /* DiagArray20 */ diag::warn_pp_ambiguous_macro, -1,
  /* DiagArray21 */ diag::ext_nested_name_member_ref_lookup_ambiguous, -1,
  /* DiagArray22 */ diag::ext_ovl_ambiguous_oper_binary_reversed, -1,
  /* DiagArray23 */ diag::warn_incompatible_analyzer_plugin_api, -1,
  /* DiagArray24 */ diag::warn_arith_conv_mixed_anon_enum_types, -1,
  /* DiagArray25 */ diag::ext_abstract_pack_declarator_parens, -1,
  /* DiagArray27 */ diag::warn_arc_bridge_cast_nonarc, -1,
  /* DiagArray28 */ diag::warn_arc_possible_repeated_use_of_weak, -1,
  /* DiagArray29 */ diag::warn_arc_object_memaccess, -1,
  /* DiagArray30 */ diag::warn_arc_perform_selector_leaks, -1,
  /* DiagArray31 */ diag::warn_arc_repeated_use_of_weak, -1,
  /* DiagArray32 */ diag::warn_arc_retain_cycle, -1,
  /* DiagArray33 */ diag::warn_arc_literal_assign, diag::warn_arc_retained_assign, diag::warn_arc_retained_property_assign, -1,
  /* DiagArray34 */ diag::warn_argument_invalid_range, -1,
  /* DiagArray35 */ diag::warn_array_index_exceeds_bounds, diag::warn_array_index_precedes_bounds, diag::warn_static_array_too_small, -1,
  /* DiagArray36 */ diag::warn_ptr_arith_exceeds_bounds, diag::warn_ptr_arith_precedes_bounds, -1,
  /* DiagArray38 */ diag::warn_asm_mismatched_size_modifier, -1,
  /* DiagArray39 */ diag::warn_not_in_enum_assignment, -1,
  /* DiagArray40 */ diag::warn_assume_side_effects, -1,
  /* DiagArray42 */ diag::warn_atimport_in_framework_header, -1,
  /* DiagArray43 */ diag::warn_atomic_op_misaligned, diag::warn_atomic_op_oversized, -1,
  /* DiagArray44 */ diag::warn_atomic_implicit_seq_cst, -1,
  /* DiagArray45 */ diag::warn_atomic_op_has_invalid_memory_order, -1,
  /* DiagArray47 */ diag::warn_atomic_property_rule, -1,
  /* DiagArray48 */ diag::warn_attribute_packed_for_bitfield, -1,
  /* DiagArray50 */ diag::warn_drv_disabling_vptr_no_rtti_default, -1,
  /* DiagArray51 */ diag::warn_auto_module_import, -1,
  /* DiagArray52 */ diag::ext_auto_storage_class, -1,
  /* DiagArray53 */ diag::warn_auto_var_is_id, -1,
  /* DiagArray54 */ diag::warn_availability_and_unavailable, diag::warn_availability_on_static_initializer, diag::warn_availability_swift_unavailable_deprecated_only, diag::warn_availability_unknown_platform, diag::warn_availability_version_ordering, diag::warn_expected_consistent_version_separator, diag::warn_mismatched_availability, diag::warn_mismatched_availability_override, diag::warn_mismatched_availability_override_unavail, -1,
  /* DiagArray55 */ diag::warn_drv_avr_family_linking_stdlibs_not_implemented, diag::warn_drv_avr_gcc_not_found, diag::warn_drv_avr_libc_not_found, diag::warn_drv_avr_linker_section_addresses_not_implemented, diag::warn_drv_avr_mcu_not_specified, diag::warn_drv_avr_stdlib_not_linked, -1,
  /* DiagArray56 */ diag::warn_fe_backend_plugin, -1,
  /* DiagArray57 */ diag::backslash_newline_space, -1,
  /* DiagArray58 */ diag::warn_bad_function_cast, -1,
  /* DiagArray60 */ diag::ext_rvalue_to_reference_access_ctor, diag::ext_rvalue_to_reference_temp_copy_no_viable, -1,
  /* DiagArray61 */ diag::ext_decomp_decl_cond, -1,
  /* DiagArray62 */ diag::warn_impcast_bitfield_precision_constant, -1,
  /* DiagArray63 */ diag::warn_bitfield_too_small_for_enum, diag::warn_signed_bitfield_enum_conversion, diag::warn_unsigned_bitfield_assigned_signed_enum, -1,
  /* DiagArray64 */ diag::warn_bitfield_width_exceeds_type_width, -1,
  /* DiagArray65 */ diag::warn_precedence_bitwise_conditional, -1,
  /* DiagArray66 */ diag::warn_bitwise_op_in_bitwise_op, -1,
  /* DiagArray67 */ diag::warn_block_capture_autoreleasing, -1,
  /* DiagArray68 */ diag::warn_impcast_bool_to_null_pointer, -1,
  /* DiagArray70 */ diag::warn_bitwise_negation_bool, -1,
  /* DiagArray71 */ diag::warn_braces_around_init, -1,
  /* DiagArray72 */ diag::warn_objc_invalid_bridge, diag::warn_objc_invalid_bridge_to_cf, -1,
  /* DiagArray73 */ diag::warn_assume_aligned_too_great, -1,
  /* DiagArray74 */ diag::ext_pp_redef_builtin_macro, diag::ext_pp_undef_builtin_macro, -1,
  /* DiagArray75 */ diag::warn_builtin_chk_overflow, -1,
  /* DiagArray76 */ diag::warn_implicit_decl_requires_sysheader, -1,
  /* DiagArray77 */ diag::warn_zero_size_struct_union_compat, -1,
  /* DiagArray81 */ diag::ext_old_implicitly_unsigned_long_cxx, diag::warn_auto_storage_class, diag::warn_cxx11_compat_user_defined_literal, diag::warn_cxx11_keyword, diag::warn_cxx11_right_shift_in_template_arg, diag::warn_explicit_instantiation_inline_0x, diag::warn_explicit_instantiation_must_be_global_0x, diag::warn_explicit_instantiation_out_of_scope_0x, diag::warn_explicit_instantiation_unqualified_wrong_namespace_0x, diag::warn_old_implicitly_unsigned_long_cxx, -1,
  /* DiagArray82 */ diag::warn_deprecated_string_literal_conversion, -1,
  /* DiagArray84 */ diag::warn_cxx11_compat_reserved_user_defined_literal, -1,
  /* DiagArray85 */ diag::ext_alias_declaration, diag::ext_array_size_conversion, diag::ext_auto_type_specifier, diag::ext_cxx11_enum_fixed_underlying_type, diag::ext_defaulted_deleted_function, diag::ext_enum_friend, diag::ext_enumerator_list_comma_cxx, diag::ext_explicit_conversion_functions, diag::ext_extern_template, diag::ext_for_range, diag::ext_generalized_initializer_lists, diag::ext_nested_name_spec_is_enum, diag::ext_nonclass_type_friend, diag::ext_nonstatic_member_init, diag::ext_override_control_keyword, diag::ext_ref_qualifier, diag::ext_rvalue_reference, diag::ext_scoped_enum, diag::ext_static_data_member_in_union, diag::ext_template_arg_object_internal, diag::ext_template_outside_of_template, diag::ext_template_parameter_default_in_function_template, diag::ext_typename_outside_of_template, diag::ext_unelaborated_friend_type, diag::ext_variadic_templates, -1,
  /* DiagArray86 */ diag::ext_extra_semi_cxx11, -1,
  /* DiagArray87 */ diag::ext_inline_namespace, -1,
  /* DiagArray88 */ diag::ext_cxx11_longlong, -1,
  /* DiagArray89 */ diag::ext_cce_narrowing, diag::ext_init_list_constant_narrowing, diag::ext_init_list_type_narrowing, diag::ext_init_list_variable_narrowing, diag::warn_init_list_constant_narrowing, diag::warn_init_list_type_narrowing, diag::warn_init_list_variable_narrowing, -1,
  /* DiagArray90 */ diag::ext_binary_literal_cxx14, -1,
  /* DiagArray93 */ diag::ext_constexpr_body_invalid_stmt, diag::ext_constexpr_body_multiple_return, diag::ext_constexpr_local_var, diag::ext_constexpr_type_definition, diag::ext_cxx14_attr, diag::ext_decltype_auto_type_specifier, diag::ext_init_capture, diag::ext_variable_template, -1,
  /* DiagArray95 */ diag::warn_cxx17_compat_exception_spec_in_signature, -1,
  /* DiagArray97 */ diag::ext_auto_new_list_init, diag::ext_constexpr_if, diag::ext_constexpr_on_lambda_cxx17, diag::ext_cxx17_attr, diag::ext_decomp_decl, diag::ext_fold_expression, diag::ext_for_range_begin_end_types_differ, diag::ext_hex_literal_invalid, diag::ext_init_statement, diag::ext_inline_variable, diag::ext_multi_using_declaration, diag::ext_nested_namespace_definition, diag::ext_ns_enum_attribute, diag::ext_star_this_lambda_capture_cxx17, diag::ext_static_assert_no_message, diag::ext_template_template_param_typename, diag::ext_using_attribute_ns, diag::ext_using_declaration_pack, -1,
  /* DiagArray102 */ diag::warn_cxx20_compat_aggregate_init_with_ctors, diag::warn_cxx20_compat_consteval, diag::warn_cxx20_compat_constinit, diag::warn_cxx20_compat_explicit_bool, diag::warn_cxx20_compat_spaceship, diag::warn_cxx20_compat_utf8_string, diag::warn_cxx20_keyword, -1,
  /* DiagArray104 */ diag::ext_cxx_designated_init, -1,
  /* DiagArray105 */ diag::ext_adl_only_template_id, diag::ext_bitfield_member_init, diag::ext_constexpr_body_invalid_stmt_cxx20, diag::ext_constexpr_ctor_missing_init, diag::ext_constexpr_function_try_block_cxx20, diag::ext_constexpr_local_var_no_init, diag::ext_constexpr_union_ctor_no_init, diag::ext_cxx20_attr, diag::ext_decomp_decl_spec, diag::ext_defaulted_comparison, diag::ext_equals_this_lambda_capture_cxx20, diag::ext_explicit_bool, diag::ext_for_range_init_stmt, diag::ext_init_capture_pack, diag::ext_inline_nested_namespace_definition, diag::ext_lambda_template_parameter_list, diag::ext_pointer_to_const_ref_member_on_rvalue, -1,
  /* DiagArray109 */ diag::warn_cxx17_compat_adl_only_template_id, diag::warn_cxx17_compat_bitfield_member_init, diag::warn_cxx17_compat_constexpr_body_invalid_stmt, diag::warn_cxx17_compat_constexpr_ctor_missing_init, diag::warn_cxx17_compat_constexpr_function_try_block, diag::warn_cxx17_compat_constexpr_local_var_no_init, diag::warn_cxx17_compat_constexpr_union_ctor_no_init, diag::warn_cxx17_compat_constexpr_virtual, diag::warn_cxx17_compat_decomp_decl_spec, diag::warn_cxx17_compat_defaulted_comparison, diag::warn_cxx17_compat_defaulted_method_type_mismatch, diag::warn_cxx17_compat_equals_this_lambda_capture, diag::warn_cxx17_compat_explicit_bool, diag::warn_cxx17_compat_for_range_init_stmt, diag::warn_cxx17_compat_init_capture_pack, diag::warn_cxx17_compat_inline_nested_namespace_definition, diag::warn_cxx17_compat_lambda_def_ctor_assign, diag::warn_cxx17_compat_lambda_template_parameter_list, diag::warn_cxx17_compat_spaceship, diag::warn_cxx17_compat_template_nontype_parm_type, diag::warn_cxx17_compat_unicode_type, -1,
  /* DiagArray110 */ diag::warn_cxx17_compat_designated_init, diag::warn_cxx17_compat_pointer_to_const_ref_member_on_rvalue, -1,
  /* DiagArray111 */ diag::warn_cxx14_compat_class_template_argument_deduction, diag::warn_cxx14_compat_constexpr_if, diag::warn_cxx14_compat_constexpr_on_lambda, diag::warn_cxx14_compat_decomp_decl, diag::warn_cxx14_compat_fold_expression, diag::warn_cxx14_compat_init_statement, diag::warn_cxx14_compat_inline_variable, diag::warn_cxx14_compat_nested_namespace_definition, diag::warn_cxx14_compat_star_this_lambda_capture, diag::warn_cxx14_compat_static_assert_no_message, diag::warn_cxx14_compat_template_nontype_parm_auto_type, diag::warn_cxx14_compat_template_template_param_typename, diag::warn_cxx14_compat_u8_character_literal, diag::warn_cxx14_compat_using_attribute_ns, diag::warn_cxx17_compat_multi_using_declaration, diag::warn_cxx17_compat_using_declaration_pack, diag::warn_for_range_begin_end_types_differ, -1,
  /* DiagArray112 */ diag::warn_cxx14_compat_ns_enum_attribute, diag::warn_cxx17_hex_literal, -1,
  /* DiagArray113 */ diag::warn_cxx11_compat_constexpr_body_invalid_stmt, diag::warn_cxx11_compat_constexpr_body_multiple_return, diag::warn_cxx11_compat_constexpr_body_no_return, diag::warn_cxx11_compat_constexpr_local_var, diag::warn_cxx11_compat_constexpr_type_definition, diag::warn_cxx11_compat_decltype_auto_type_specifier, diag::warn_cxx11_compat_deduced_return_type, diag::warn_cxx11_compat_digit_separator, diag::warn_cxx11_compat_generic_lambda, diag::warn_cxx11_compat_init_capture, diag::warn_cxx11_compat_variable_template, -1,
  /* DiagArray114 */ diag::warn_cxx11_compat_binary_literal, -1,
  /* DiagArray116 */ diag::warn_cxx98_compat_alias_declaration, diag::warn_cxx98_compat_alignas, diag::warn_cxx98_compat_alignof, diag::warn_cxx98_compat_attribute, diag::warn_cxx98_compat_auto_type_specifier, diag::warn_cxx98_compat_constexpr, diag::warn_cxx98_compat_ctor_list_init, diag::warn_cxx98_compat_decltype, diag::warn_cxx98_compat_defaulted_deleted_function, diag::warn_cxx98_compat_delegating_ctor, diag::warn_cxx98_compat_empty_scalar_initializer, diag::warn_cxx98_compat_empty_sizeless_initializer, diag::warn_cxx98_compat_enum_fixed_underlying_type, diag::warn_cxx98_compat_enum_friend, diag::warn_cxx98_compat_enum_nested_name_spec, diag::warn_cxx98_compat_explicit_conversion_functions, diag::warn_cxx98_compat_for_range, diag::warn_cxx98_compat_friend_is_member, diag::warn_cxx98_compat_generalized_initializer_lists, diag::warn_cxx98_compat_goto_into_protected_scope, diag::warn_cxx98_compat_indirect_goto_in_protected_scope, diag::warn_cxx98_compat_initializer_list_init, diag::warn_cxx98_compat_inline_namespace, diag::warn_cxx98_compat_lambda, diag::warn_cxx98_compat_less_colon_colon, diag::warn_cxx98_compat_literal_operator, diag::warn_cxx98_compat_literal_ucn_control_character, diag::warn_cxx98_compat_literal_ucn_escape_basic_scs, diag::warn_cxx98_compat_noexcept_decl, diag::warn_cxx98_compat_noexcept_expr, diag::warn_cxx98_compat_non_static_member_use, diag::warn_cxx98_compat_nonclass_type_friend, diag::warn_cxx98_compat_nonstatic_member_init, diag::warn_cxx98_compat_nontrivial_union_or_anon_struct_member, diag::warn_cxx98_compat_nullptr, diag::warn_cxx98_compat_override_control_keyword, diag::warn_cxx98_compat_pass_non_pod_arg_to_vararg, diag::warn_cxx98_compat_raw_string_literal, diag::warn_cxx98_compat_ref_qualifier, diag::warn_cxx98_compat_reference_list_init, diag::warn_cxx98_compat_rvalue_reference, diag::warn_cxx98_compat_scoped_enum, diag::warn_cxx98_compat_sfinae_access_control, diag::warn_cxx98_compat_static_assert, diag::warn_cxx98_compat_static_data_member_in_union, diag::warn_cxx98_compat_switch_into_protected_scope, diag::warn_cxx98_compat_template_arg_extra_parens, diag::warn_cxx98_compat_template_arg_null, diag::warn_cxx98_compat_template_arg_object_internal, diag::warn_cxx98_compat_template_outside_of_template, diag::warn_cxx98_compat_template_parameter_default_in_function_template, diag::warn_cxx98_compat_trailing_return_type, diag::warn_cxx98_compat_two_right_angle_brackets, diag::warn_cxx98_compat_typename_outside_of_template, diag::warn_cxx98_compat_unelaborated_friend_type, diag::warn_cxx98_compat_unicode_id, diag::warn_cxx98_compat_unicode_literal, diag::warn_cxx98_compat_unicode_type, diag::warn_cxx98_compat_using_decl_constructor, diag::warn_cxx98_compat_variadic_templates, -1,
  /* DiagArray117 */ diag::warn_cxx98_compat_temp_copy, -1,
  /* DiagArray118 */ diag::warn_cxx98_compat_top_level_semi, -1,
  /* DiagArray119 */ diag::warn_cxx98_compat_template_arg_local_type, -1,
  /* DiagArray120 */ diag::warn_cxx98_compat_array_size_conversion, diag::warn_cxx98_compat_cast_fn_obj, diag::warn_cxx98_compat_empty_fnmacro_arg, diag::warn_cxx98_compat_enumerator_list_comma, diag::warn_cxx98_compat_extern_template, diag::warn_cxx98_compat_longlong, diag::warn_cxx98_compat_no_newline_eof, diag::warn_cxx98_compat_pp_line_too_big, diag::warn_cxx98_compat_variadic_macro, -1,
  /* DiagArray121 */ diag::warn_cxx98_compat_template_arg_unnamed_type, -1,
  /* DiagArray122 */ diag::ext_anonymous_union, diag::ext_c11_anonymous_struct, diag::ext_c11_feature, diag::ext_typecheck_compare_complete_incomplete_pointers, -1,
  /* DiagArray123 */ diag::ext_parameter_name_omitted_c2x, -1,
  /* DiagArray124 */ diag::warn_c99_compat_unicode_id, diag::warn_c99_compat_unicode_literal, diag::warn_old_implicitly_unsigned_long, -1,
  /* DiagArray125 */ diag::ext_designated_init, diag::ext_designated_init_array, diag::ext_designated_init_mixed, diag::ext_designated_init_nested, -1,
  /* DiagArray126 */ diag::ext_aggregate_init_not_constant, diag::ext_c99_array_usage, diag::ext_c99_compound_literal, diag::ext_c99_feature, diag::ext_c99_flexible_array_member, diag::ext_c99_variable_decl_in_for_loop, diag::ext_c99_whitespace_required_after_macro_name, diag::ext_empty_fnmacro_arg, diag::ext_enumerator_list_comma_c, diag::ext_hex_constant_invalid, -1,
  /* DiagArray127 */ diag::warn_call_to_pure_virtual_member_function_from_ctor_dtor, -1,
  /* DiagArray128 */ diag::warn_called_once_gets_called_twice, diag::warn_called_once_never_called, diag::warn_called_once_never_called_when, -1,
  /* DiagArray129 */ diag::warn_cast_align, -1,
  /* DiagArray130 */ diag::warn_cast_calling_conv, -1,
  /* DiagArray131 */ diag::warn_cast_pointer_from_sel, -1,
  /* DiagArray132 */ diag::warn_cast_qual, diag::warn_cast_qual2, -1,
  /* DiagArray133 */ diag::ext_bad_cxx_cast_qualifiers_away_incoherent, -1,
  /* DiagArray135 */ diag::warn_omp_section_is_char, diag::warn_subscript_is_char, -1,
  /* DiagArray136 */ diag::warn_drv_yc_multiple_inputs_clang_cl, diag::warn_drv_ycyu_different_arg_clang_cl, diag::warn_pp_hdrstop_filename_ignored, diag::warn_pp_macro_def_mismatch_with_pch, -1,
  /* DiagArray137 */ diag::warn_conv_to_base_not_used, diag::warn_conv_to_self_not_used, diag::warn_conv_to_void_not_used, -1,
  /* DiagArray138 */ diag::warn_pass_class_arg_to_vararg, -1,
  /* DiagArray139 */ diag::warn_cmse_nonsecure_union, -1,
  /* DiagArray140 */ diag::warn_comma_operator, -1,
  /* DiagArray141 */ diag::escaped_newline_block_comment_end, diag::ext_line_comment, diag::ext_multi_line_line_comment, diag::warn_nested_block_comment, -1,
  /* DiagArray143 */ diag::ext_typecheck_comparison_of_distinct_pointers, -1,
  /* DiagArray144 */ diag::warn_completion_handler_called_twice, diag::warn_completion_handler_never_called, diag::warn_completion_handler_never_called_when, -1,
  /* DiagArray145 */ diag::ext_complex_component_init, -1,
  /* DiagArray147 */ diag::warn_compound_token_split_by_macro, -1,
  /* DiagArray148 */ diag::warn_compound_token_split_by_whitespace, -1,
  /* DiagArray149 */ diag::ext_concept_legacy_bool_keyword, -1,
  /* DiagArray150 */ diag::ext_typecheck_cond_pointer_integer_mismatch, -1,
  /* DiagArray151 */ diag::warn_maybe_uninit_var, -1,
  /* DiagArray152 */ diag::warn_module_config_macro_undef, -1,
  /* DiagArray153 */ diag::warn_impcast_integer_precision_constant, -1,
  /* DiagArray154 */ diag::warn_is_constant_evaluated_always_true_constexpr, -1,
  /* DiagArray155 */ diag::warn_logical_instead_of_bitwise, -1,
  /* DiagArray156 */ diag::warn_cxx14_compat_constexpr_not_const, -1,
  /* DiagArray157 */ diag::warn_attr_on_unconsumable_class, diag::warn_loop_state_mismatch, diag::warn_param_return_typestate_mismatch, diag::warn_param_typestate_mismatch, diag::warn_return_typestate_for_unconsumable_type, diag::warn_return_typestate_mismatch, diag::warn_use_in_invalid_state, diag::warn_use_of_temp_in_invalid_state, -1,
  /* DiagArray158 */ diag::warn_impcast_complex_scalar, diag::warn_impcast_vector_scalar, diag::warn_opencl_generic_address_space_arg, diag::warn_template_arg_negative, diag::warn_template_arg_too_large, -1,
  /* DiagArray160 */ diag::warn_coroutine_handle_address_invalid_return_type, -1,
  /* DiagArray161 */ diag::warn_coroutine_promise_unhandled_exception_required_with_exceptions, -1,
  /* DiagArray162 */ diag::warn_unreachable_default, -1,
  /* DiagArray164 */ diag::warn_objc_cdirective_format_string, -1,
  /* DiagArray165 */ diag::warn_ctad_maybe_unsupported, -1,
  /* DiagArray167 */ diag::warn_ctu_incompat_triple, -1,
  /* DiagArray168 */ diag::warn_attribute_argument_n_negative, diag::warn_cuda_attr_lambda_position, diag::warn_kern_is_inline, diag::warn_kern_is_method, diag::warn_pragma_unroll_cuda_value_in_parens, -1,
  /* DiagArray169 */ diag::warn_default_atomic_custom_getter_setter, -1,
  /* DiagArray170 */ diag::warn_dangling_variable, diag::warn_unsupported_lifetime_extension, -1,
  /* DiagArray171 */ diag::warn_dangling_else, -1,
  /* DiagArray172 */ diag::warn_bind_ref_member_to_parameter, diag::warn_dangling_member, diag::warn_init_ptr_member_to_parameter_addr, diag::warn_new_dangling_reference, -1,
  /* DiagArray173 */ diag::warn_dangling_lifetime_pointer, diag::warn_dangling_lifetime_pointer_member, -1,
  /* DiagArray174 */ diag::warn_new_dangling_initializer_list, -1,
  /* DiagArray175 */ diag::warn_drv_darwin_sdk_invalid_settings, -1,
  /* DiagArray176 */ diag::warn_pp_date_time, -1,
  /* DiagArray177 */ diag::warn_dealloc_in_category, -1,
  /* DiagArray178 */ diag::warn_debug_compression_unavailable, -1,
  /* DiagArray179 */ diag::ext_mixed_decls_code, -1,
  /* DiagArray180 */ diag::warn_defaulted_comparison_deleted, diag::warn_defaulted_method_deleted, -1,
  /* DiagArray181 */ diag::warn_delegating_ctor_cycle, -1,
  /* DiagArray182 */ diag::warn_delete_abstract_non_virtual_dtor, -1,
  /* DiagArray183 */ diag::ext_delete_void_ptr_operand, diag::warn_delete_incomplete, -1,
  /* DiagArray184 */ diag::warn_delete_non_virtual_dtor, -1,
  /* DiagArray186 */ diag::warn_O4_is_O3, diag::warn_access_decl_deprecated, diag::warn_deprecated_redundant_constexpr_static_def, diag::warn_drv_deprecated_arg, diag::warn_drv_treating_input_as_cxx, diag::warn_fe_concepts_ts_flag, diag::warn_option_invalid_ocl_version, diag::warn_vector_long_decl_spec_combination, -1,
  /* DiagArray187 */ diag::warn_arith_conv_mixed_anon_enum_types_cxx20, -1,
  /* DiagArray188 */ diag::warn_depr_array_comparison, -1,
  /* DiagArray189 */ diag::warn_vector_mode_deprecated, -1,
  /* DiagArray190 */ diag::warn_deprecated_comma_subscript, -1,
  /* DiagArray191 */ diag::warn_deprecated_copy_operation, -1,
  /* DiagArray192 */ diag::warn_deprecated_copy_dtor_operation, -1,
  /* DiagArray193 */ diag::warn_atl_uuid_deprecated, diag::warn_cstyle_param, diag::warn_deprecated, diag::warn_deprecated_fwdclass_message, diag::warn_deprecated_message, diag::warn_property_method_deprecated, -1,
  /* DiagArray194 */ diag::warn_exception_spec_deprecated, -1,
  /* DiagArray195 */ diag::warn_comparison_mixed_enum_types_cxx20, -1,
  /* DiagArray196 */ diag::warn_conditional_mixed_enum_types_cxx20, -1,
  /* DiagArray197 */ diag::warn_arith_conv_mixed_enum_types_cxx20, -1,
  /* DiagArray198 */ diag::warn_arith_conv_enum_float_cxx20, -1,
  /* DiagArray199 */ diag::warn_deprecated_def, diag::warn_unavailable_def, -1,
  /* DiagArray200 */ diag::warn_increment_bool, -1,
  /* DiagArray201 */ diag::warn_objc_isa_assign, diag::warn_objc_isa_use, -1,
  /* DiagArray202 */ diag::warn_objc_pointer_masking, -1,
  /* DiagArray203 */ diag::warn_objc_pointer_masking_performSelector, -1,
  /* DiagArray204 */ diag::warn_deprecated_register, -1,
  /* DiagArray205 */ diag::warn_deprecated_this_capture, -1,
  /* DiagArray206 */ diag::warn_deprecated_compound_assign_volatile, diag::warn_deprecated_increment_decrement_volatile, diag::warn_deprecated_simple_assign_volatile, diag::warn_deprecated_volatile_param, diag::warn_deprecated_volatile_return, diag::warn_deprecated_volatile_structured_binding, -1,
  /* DiagArray208 */ diag::warn_direct_ivar_access, -1,
  /* DiagArray209 */ diag::pp_disabled_macro_expansion, -1,
  /* DiagArray212 */ diag::warn_conflicting_param_modifiers, diag::warn_conflicting_ret_type_modifiers, -1,
  /* DiagArray214 */ diag::warn_remainder_division_by_zero, -1,
  /* DiagArray215 */ diag::warn_attribute_dll_redeclaration, -1,
  /* DiagArray216 */ diag::warn_attribute_dllexport_explicit_instantiation_decl, -1,
  /* DiagArray217 */ diag::warn_attribute_dllimport_static_field_definition, -1,
  /* DiagArray218 */ diag::warn_doc_api_container_decl_mismatch, diag::warn_doc_block_command_duplicate, diag::warn_doc_block_command_empty_paragraph, diag::warn_doc_container_decl_mismatch, diag::warn_doc_function_method_decl_mismatch, diag::warn_doc_html_start_tag_expected_ident_or_greater, diag::warn_doc_html_start_tag_expected_quoted_string, diag::warn_doc_inline_contents_no_argument, diag::warn_doc_param_duplicate, diag::warn_doc_param_invalid_direction, diag::warn_doc_param_not_attached_to_a_function_decl, diag::warn_doc_param_not_found, diag::warn_doc_returns_attached_to_a_void_function, diag::warn_doc_returns_not_attached_to_a_function_decl, diag::warn_doc_tparam_duplicate, diag::warn_doc_tparam_not_attached_to_a_template_decl, diag::warn_doc_tparam_not_found, diag::warn_not_a_doxygen_trailing_member_comment, diag::warn_verbatim_block_end_without_start, -1,
  /* DiagArray219 */ diag::warn_doc_deprecated_not_sync, -1,
  /* DiagArray220 */ diag::warn_doc_html_end_forbidden, diag::warn_doc_html_end_unbalanced, diag::warn_doc_html_missing_end_tag, diag::warn_doc_html_start_end_mismatch, -1,
  /* DiagArray221 */ diag::warn_doc_param_spaces_in_direction, -1,
  /* DiagArray222 */ diag::warn_correct_comment_command_name, diag::warn_unknown_comment_command_name, -1,
  /* DiagArray223 */ diag::ext_dollar_in_identifier, -1,
  /* DiagArray224 */ diag::warn_impcast_double_promotion, -1,
  /* DiagArray225 */ diag::ext_dtor_name_ambiguous, diag::ext_dtor_named_in_wrong_scope, diag::ext_qualified_dtor_named_in_lexical_scope, -1,
  /* DiagArray226 */ diag::ext_destructor_typedef_name, -1,
  /* DiagArray227 */ diag::ext_duplicate_declspec, diag::ext_warn_duplicate_declspec, diag::warn_attribute_address_multiple_identical_qualifiers, diag::warn_duplicate_declspec, -1,
  /* DiagArray228 */ diag::warn_duplicate_enum_values, -1,
  /* DiagArray229 */ diag::warn_method_param_declaration, -1,
  /* DiagArray230 */ diag::warn_duplicate_method_decl, -1,
  /* DiagArray231 */ diag::warn_duplicate_protocol_def, -1,
  /* DiagArray232 */ diag::warn_dyn_class_memaccess, -1,
  /* DiagArray233 */ diag::ext_dynamic_exception_spec, -1,
  /* DiagArray235 */ diag::ext_enum_base_in_type_specifier, -1,
  /* DiagArray236 */ diag::ext_elaborated_enum_class, -1,
  /* DiagArray237 */ diag::ext_embedded_directive, -1,
  /* DiagArray238 */ diag::warn_empty_for_body, diag::warn_empty_if_body, diag::warn_empty_range_based_for_body, diag::warn_empty_switch_body, diag::warn_empty_while_body, -1,
  /* DiagArray239 */ diag::ext_decomp_decl_empty, -1,
  /* DiagArray240 */ diag::warn_empty_init_statement, -1,
  /* DiagArray241 */ diag::ext_empty_translation_unit, -1,
  /* DiagArray242 */ diag::warn_incomplete_encoded_type, -1,
  /* DiagArray244 */ diag::warn_comparison_mixed_enum_types, -1,
  /* DiagArray245 */ diag::warn_conditional_mixed_enum_types, -1,
  /* DiagArray246 */ diag::warn_comparison_of_mixed_enum_types_switch, -1,
  /* DiagArray247 */ diag::warn_impcast_different_enum_types, -1,
  /* DiagArray248 */ diag::warn_arith_conv_mixed_enum_types, -1,
  /* DiagArray249 */ diag::warn_arith_conv_enum_float, -1,
  /* DiagArray250 */ diag::ext_enum_too_large, diag::ext_enumerator_increment_too_large, -1,
  /* DiagArray251 */ diag::warn_cdtor_function_try_handler_mem_expr, diag::warn_exception_caught_by_earlier_handler, diag::warn_throw_in_noexcept_func, -1,
  /* DiagArray252 */ diag::ext_excess_initializers, diag::ext_excess_initializers_for_sizeless_type, diag::ext_excess_initializers_in_char_array_initializer, diag::ext_initializer_string_for_char_array_too_long, -1,
  /* DiagArray253 */ diag::warn_exit_time_destructor, -1,
  /* DiagArray254 */ diag::warn_defined_in_function_type_macro, diag::warn_defined_in_object_type_macro, -1,
  /* DiagArray255 */ diag::warn_direct_initialize_call, diag::warn_direct_super_initialize_call, -1,
  /* DiagArray256 */ diag::warn_arc_strong_pointer_objc_pointer, -1,
  /* DiagArray257 */ diag::ext_export_no_name_block, diag::ext_export_no_names, -1,
  /* DiagArray258 */ diag::ext_export_using_directive, -1,
  /* DiagArray259 */ diag::warn_zero_size_struct_union_in_extern_c, -1,
  /* DiagArray260 */ diag::warn_extern_init, -1,
  /* DiagArray261 */ diag::warn_arm_interrupt_calling_convention, -1,
  /* DiagArray262 */ diag::warn_namespace_member_extra_qualification, -1,
  /* DiagArray263 */ diag::ext_extra_semi, diag::warn_extra_semi_after_mem_fn_def, -1,
  /* DiagArray264 */ diag::warn_null_statement, -1,
  /* DiagArray265 */ diag::ext_pp_extra_tokens_at_eol, diag::warn_omp_extra_tokens_at_eol, -1,
  /* DiagArray266 */ diag::warn_drv_invoking_fallback, -1,
  /* DiagArray267 */ diag::warn_final_dtor_non_final_class, -1,
  /* DiagArray268 */ diag::ext_clang_c_enum_fixed_underlying_type, -1,
  /* DiagArray269 */ diag::warn_fixedpoint_constant_overflow, -1,
  /* DiagArray270 */ diag::warn_flag_enum_constant_out_of_range, -1,
  /* DiagArray271 */ diag::ext_flexible_array_in_array, diag::ext_flexible_array_in_struct, -1,
  /* DiagArray272 */ diag::warn_impcast_float_integer, -1,
  /* DiagArray273 */ diag::warn_floatingpoint_eq, -1,
  /* DiagArray274 */ diag::warn_impcast_float_to_integer, diag::warn_impcast_float_to_integer_out_of_range, -1,
  /* DiagArray275 */ diag::warn_impcast_float_to_integer_zero, -1,
  /* DiagArray276 */ diag::warn_redundant_loop_iteration, diag::warn_variables_not_in_loop_body, -1,
  /* DiagArray277 */ diag::warn_format_P_no_precision, diag::warn_format_argument_needs_cast, diag::warn_format_bool_as_character, diag::warn_format_conversion_argument_type_mismatch, diag::warn_format_invalid_annotation, diag::warn_format_invalid_positional_specifier, diag::warn_format_mix_positional_nonpositional_args, diag::warn_format_nonsensical_length, diag::warn_format_string_is_wide_literal, diag::warn_format_zero_positional_specifier, diag::warn_missing_format_string, diag::warn_printf_ObjCflags_without_ObjCConversion, diag::warn_printf_asterisk_missing_arg, diag::warn_printf_asterisk_wrong_type, diag::warn_printf_empty_objc_flag, diag::warn_printf_format_string_contains_null_char, diag::warn_printf_format_string_not_null_terminated, diag::warn_printf_ignored_flag, diag::warn_printf_incomplete_specifier, diag::warn_printf_invalid_objc_flag, diag::warn_printf_nonsensical_flag, diag::warn_printf_nonsensical_optional_amount, diag::warn_printf_positional_arg_exceeds_data_args, diag::warn_scanf_nonzero_width, diag::warn_scanf_scanlist_incomplete, -1,
  /* DiagArray278 */ diag::warn_printf_data_arg_not_used, -1,
  /* DiagArray279 */ diag::warn_printf_insufficient_data_args, -1,
  /* DiagArray280 */ diag::warn_format_invalid_conversion, -1,
  /* DiagArray281 */ diag::warn_format_non_standard, diag::warn_format_non_standard_conversion_spec, diag::warn_format_non_standard_positional_arg, -1,
  /* DiagArray282 */ diag::warn_format_nonliteral, -1,
  /* DiagArray283 */ diag::warn_format_argument_needs_cast_pedantic, diag::warn_format_conversion_argument_type_mismatch_pedantic, -1,
  /* DiagArray284 */ diag::warn_format_nonliteral_noargs, -1,
  /* DiagArray285 */ diag::warn_format_conversion_argument_type_mismatch_confusion, -1,
  /* DiagArray287 */ diag::warn_empty_format_string, -1,
  /* DiagArray289 */ diag::warn_fortify_source_format_overflow, diag::warn_fortify_source_overflow, diag::warn_fortify_source_size_mismatch, -1,
  /* DiagArray290 */ diag::warn_four_char_character_literal, -1,
  /* DiagArray291 */ diag::warn_frame_address, -1,
  /* DiagArray292 */ diag::warn_fe_backend_frame_larger_than, diag::warn_fe_frame_larger_than, -1,
  /* DiagArray293 */ diag::warn_framework_include_private_from_public, -1,
  /* DiagArray294 */ diag::warn_free_nonheap_object, -1,
  /* DiagArray295 */ diag::warn_function_def_in_objc_container, -1,
  /* DiagArray296 */ diag::warn_dispatch_body_ignored, diag::warn_multiversion_duplicate_entries, -1,
  /* DiagArray297 */ diag::warn_drv_fuse_ld_path, -1,
  /* DiagArray299 */ diag::ext_clang_diagnose_if, diag::ext_clang_enable_if, diag::ext_warn_gnu_final, diag::warn_attribute_on_function_definition, diag::warn_break_binds_to_switch, diag::warn_cleanup_ext, diag::warn_gcc_attribute_location, diag::warn_gcc_ignores_type_attr, diag::warn_gcc_variable_decl_in_for_loop, diag::warn_loop_ctrl_binds_to_inner, -1,
  /* DiagArray300 */ diag::warn_global_constructor, diag::warn_global_destructor, -1,
  /* DiagArray301 */ diag::warn_drv_global_isel_incomplete, diag::warn_drv_global_isel_incomplete_opt, -1,
  /* DiagArray303 */ diag::ext_alignof_expr, -1,
  /* DiagArray304 */ diag::ext_gnu_anonymous_struct, -1,
  /* DiagArray305 */ diag::ext_array_init_parens, -1,
  /* DiagArray306 */ diag::ext_auto_type, -1,
  /* DiagArray307 */ diag::ext_binary_literal, -1,
  /* DiagArray308 */ diag::ext_gnu_case_range, -1,
  /* DiagArray309 */ diag::ext_integer_complex, -1,
  /* DiagArray310 */ diag::ext_array_init_copy, -1,
  /* DiagArray311 */ diag::ext_gnu_conditional_expr, -1,
  /* DiagArray312 */ diag::ext_gnu_array_range, diag::ext_gnu_missing_equal_designator, diag::ext_gnu_old_style_field_designator, -1,
  /* DiagArray313 */ diag::ext_gnu_empty_initializer, -1,
  /* DiagArray314 */ diag::ext_empty_struct_union, diag::ext_flexible_array_empty_aggregate_gnu, diag::ext_no_named_members_in_struct_union, -1,
  /* DiagArray315 */ diag::ext_flexible_array_init, -1,
  /* DiagArray316 */ diag::ext_flexible_array_union_gnu, -1,
  /* DiagArray317 */ diag::ext_expr_not_ice, diag::ext_in_class_initializer_non_constant, diag::ext_vla_folded_to_constant, -1,
  /* DiagArray318 */ diag::ext_imaginary_constant, -1,
  /* DiagArray319 */ diag::ext_pp_include_next_directive, -1,
  /* DiagArray320 */ diag::warn_gnu_inline_cplusplus_without_extern, -1,
  /* DiagArray321 */ diag::ext_gnu_address_of_label, diag::ext_gnu_indirect_goto, -1,
  /* DiagArray322 */ diag::ext_forward_ref_enum_def, -1,
  /* DiagArray323 */ diag::ext_gnu_statement_expr, -1,
  /* DiagArray324 */ diag::ext_in_class_initializer_float_type, -1,
  /* DiagArray325 */ diag::ext_string_literal_operator_template, -1,
  /* DiagArray326 */ diag::ext_typecheck_cast_to_union, -1,
  /* DiagArray327 */ diag::ext_variable_sized_type_in_struct, -1,
  /* DiagArray328 */ diag::ext_pp_line_zero, -1,
  /* DiagArray329 */ diag::ext_missing_varargs_arg, diag::ext_paste_comma, -1,
  /* DiagArray330 */ diag::warn_header_guard, -1,
  /* DiagArray331 */ diag::warn_using_directive_in_header, -1,
  /* DiagArray332 */ diag::warn_ignored_hip_only_option, -1,
  /* DiagArray333 */ diag::warn_condition_is_idiomatic_assignment, -1,
  /* DiagArray334 */ diag::ext_cannot_use_trivial_abi, diag::warn_alias_to_weak_alias, diag::warn_alias_with_section, diag::warn_attr_abi_tag_namespace, diag::warn_attribute_after_definition_ignored, diag::warn_attribute_cmse_entry_static, diag::warn_attribute_dllexport_explicit_instantiation_def, diag::warn_attribute_has_no_effect_on_if_constexpr, diag::warn_attribute_has_no_effect_on_infinite_loop, diag::warn_attribute_iboutlet, diag::warn_attribute_ignored, diag::warn_attribute_ignored_for_field_of_type, diag::warn_attribute_ignored_on_inline, diag::warn_attribute_invalid_on_definition, diag::warn_attribute_no_decl, diag::warn_attribute_nonnull_no_pointers, diag::warn_attribute_nonnull_parm_no_args, diag::warn_attribute_not_on_decl, diag::warn_attribute_pointer_or_reference_only, diag::warn_attribute_pointers_only, diag::warn_attribute_precede_definition, diag::warn_attribute_return_pointers_only, diag::warn_attribute_return_pointers_refs_only, diag::warn_attribute_sentinel_named_arguments, diag::warn_attribute_sentinel_not_variadic, diag::warn_attribute_type_not_supported, diag::warn_attribute_unknown_visibility, diag::warn_attribute_void_function_method, diag::warn_attribute_weak_on_field, diag::warn_attribute_weak_on_local, diag::warn_attribute_wrong_decl_type, diag::warn_attribute_wrong_decl_type_str, diag::warn_attributes_likelihood_ifstmt_conflict, diag::warn_block_literal_attributes_on_omitted_return_type, diag::warn_cconv_unsupported, diag::warn_cxx11_gnu_attribute_on_type, diag::warn_declspec_allocator_nonpointer, diag::warn_declspec_attribute_ignored, diag::warn_deprecated_anonymous_namespace, diag::warn_dllimport_dropped_from_inline_function, diag::warn_duplicate_attribute, diag::warn_duplicate_attribute_exact, diag::warn_gc_attribute_weak_on_local, diag::warn_gnu_inline_attribute_requires_inline, diag::warn_ignored_ms_inheritance, diag::warn_ignored_objc_externally_retained, diag::warn_import_on_definition, diag::warn_internal_linkage_local_storage, diag::warn_interrupt_attribute_invalid, diag::warn_microsoft_qualifiers_ignored, diag::warn_mig_server_routine_does_not_return_kern_return_t, diag::warn_mismatched_import, diag::warn_mmap_unknown_attribute, diag::warn_nocf_check_attribute_ignored, diag::warn_noderef_on_non_pointer_or_array, diag::warn_nomerge_attribute_ignored_in_stmt, diag::warn_nothrow_attribute_ignored, diag::warn_ns_attribute_wrong_parameter_type, diag::warn_ns_attribute_wrong_return_type, diag::warn_objc_direct_ignored, diag::warn_objc_direct_property_ignored, diag::warn_opencl_attr_deprecated_ignored, diag::warn_require_const_init_added_too_late, diag::warn_riscv_repeated_interrupt_attribute, diag::warn_sycl_kernel_invalid_template_param_type, diag::warn_sycl_kernel_num_of_function_params, diag::warn_sycl_kernel_num_of_template_params, diag::warn_sycl_kernel_return_type, diag::warn_transparent_union_attribute_field_size_align, diag::warn_transparent_union_attribute_floating, diag::warn_transparent_union_attribute_not_definition, diag::warn_transparent_union_attribute_zero_fields, diag::warn_type_attribute_wrong_type, diag::warn_unhandled_ms_attribute_ignored, diag::warn_unsupported_target_attribute, diag::warn_wrong_clang_attr_namespace, -1,
  /* DiagArray335 */ diag::warn_drv_unsupported_opt_for_target, diag::warn_ignored_gcc_optimization, -1,
  /* DiagArray336 */ diag::warn_pragma_intrinsic_builtin, -1,
  /* DiagArray337 */ diag::warn_pragma_optimize, -1,
  /* DiagArray338 */ diag::warn_pragma_align_expected_equal, diag::warn_pragma_align_invalid_option, diag::warn_pragma_begin_end_mismatch, diag::warn_pragma_comment_ignored, diag::warn_pragma_debug_missing_argument, diag::warn_pragma_debug_unexpected_command, diag::warn_pragma_debug_unknown_module, diag::warn_pragma_expected_action_or_r_paren, diag::warn_pragma_expected_colon, diag::warn_pragma_expected_colon_r_paren, diag::warn_pragma_expected_comma, diag::warn_pragma_expected_identifier, diag::warn_pragma_expected_init_seg, diag::warn_pragma_expected_integer, diag::warn_pragma_expected_lparen, diag::warn_pragma_expected_non_wide_string, diag::warn_pragma_expected_predicate, diag::warn_pragma_expected_punc, diag::warn_pragma_expected_rparen, diag::warn_pragma_expected_section_label_or_name, diag::warn_pragma_expected_section_name, diag::warn_pragma_expected_section_push_pop_or_name, diag::warn_pragma_expected_string, diag::warn_pragma_extra_tokens_at_eol, diag::warn_pragma_force_cuda_host_device_bad_arg, diag::warn_pragma_fp_ignored, diag::warn_pragma_init_seg_unsupported_target, diag::warn_pragma_invalid_action, diag::warn_pragma_invalid_argument, diag::warn_pragma_invalid_specific_action, diag::warn_pragma_missing_argument, diag::warn_pragma_ms_struct, diag::warn_pragma_options_align_reset_failed, diag::warn_pragma_options_expected_align, diag::warn_pragma_pack_invalid_alignment, diag::warn_pragma_pack_malformed, diag::warn_pragma_pop_failed, diag::warn_pragma_pop_macro_no_push, diag::warn_pragma_unknown_extension, diag::warn_pragma_unsupported_action, diag::warn_pragma_unsupported_extension, diag::warn_pragma_unused_expected_var, diag::warn_pragma_unused_expected_var_arg, diag::warn_pragma_unused_undeclared_var, diag::warn_stdc_unknown_rounding_mode, -1,
  /* DiagArray339 */ diag::warn_arc_lifetime_result_type, diag::warn_block_literal_qualifiers_on_omitted_return_type, diag::warn_qual_return_type, diag::warn_typecheck_function_qualifiers_ignored, diag::warn_typecheck_reference_qualifiers, -1,
  /* DiagArray341 */ diag::warn_auto_implicit_atomic_property, diag::warn_implicit_atomic_property, -1,
  /* DiagArray342 */ diag::warn_impcast_integer_float_precision_constant, -1,
  /* DiagArray343 */ diag::warn_impcast_floating_point_to_bool, -1,
  /* DiagArray344 */ diag::ext_implicit_exception_spec_mismatch, -1,
  /* DiagArray345 */ diag::warn_fallthrough_attr_unreachable, diag::warn_unannotated_fallthrough, -1,
  /* DiagArray346 */ diag::warn_unannotated_fallthrough_per_function, -1,
  /* DiagArray347 */ diag::warn_impcast_fixed_point_range, -1,
  /* DiagArray348 */ diag::warn_impcast_float_precision, diag::warn_impcast_float_result_precision, -1,
  /* DiagArray349 */ diag::ext_implicit_function_decl, diag::ext_implicit_lib_function_decl, diag::warn_builtin_unknown, diag::warn_implicit_function_decl, -1,
  /* DiagArray350 */ diag::ext_missing_type_specifier, -1,
  /* DiagArray351 */ diag::warn_impcast_high_order_zero_bits, diag::warn_impcast_integer_precision, -1,
  /* DiagArray352 */ diag::warn_impcast_integer_float_precision, -1,
  /* DiagArray353 */ diag::warn_implicitly_retains_self, -1,
  /* DiagArray354 */ diag::ext_integer_literal_too_large_for_signed, -1,
  /* DiagArray356 */ diag::ext_pp_import_directive, -1,
  /* DiagArray357 */ diag::warn_inaccessible_base_class, -1,
  /* DiagArray358 */ diag::pp_include_next_absolute_path, -1,
  /* DiagArray359 */ diag::pp_include_next_in_primary, -1,
  /* DiagArray360 */ diag::warn_deep_exception_specs_differ, diag::warn_incompatible_exception_specs, -1,
  /* DiagArray361 */ diag::ext_typecheck_convert_incompatible_function_pointer, -1,
  /* DiagArray362 */ diag::warn_redecl_library_builtin, -1,
  /* DiagArray363 */ diag::warn_cxx_ms_struct, diag::warn_npot_ms_struct, -1,
  /* DiagArray364 */ diag::ext_typecheck_convert_incompatible_pointer, -1,
  /* DiagArray365 */ diag::ext_nested_pointer_qualifier_mismatch, diag::ext_typecheck_convert_discards_qualifiers, diag::warn_bad_cxx_cast_nested_pointer_addr_space, -1,
  /* DiagArray366 */ diag::warn_property_types_are_incompatible, -1,
  /* DiagArray367 */ diag::warn_incompatible_sysroot, -1,
  /* DiagArray368 */ diag::warn_mmap_incomplete_framework_module_declaration, -1,
  /* DiagArray369 */ diag::warn_undef_method_impl, -1,
  /* DiagArray371 */ diag::warn_implicit_decl_no_jmp_buf, -1,
  /* DiagArray372 */ diag::warn_missing_submodule, diag::warn_mmap_umbrella_dir_not_found, diag::warn_uncovered_module_header, -1,
  /* DiagArray373 */ diag::warn_redeclaration_without_attribute_prev_attribute_ignored, diag::warn_redeclaration_without_import_attribute, -1,
  /* DiagArray374 */ diag::warn_inconsistent_destructor_marked_not_override_overriding, -1,
  /* DiagArray375 */ diag::warn_inconsistent_function_marked_not_override_overriding, -1,
  /* DiagArray376 */ diag::ext_increment_bool, -1,
  /* DiagArray377 */ diag::warn_infinite_recursive_function, -1,
  /* DiagArray379 */ diag::ext_initializer_overrides, diag::warn_initializer_overrides, -1,
  /* DiagArray380 */ diag::ext_out_of_line_qualified_id_type_names_constructor, -1,
  /* DiagArray382 */ diag::warn_fe_inline_asm, -1,
  /* DiagArray383 */ diag::warn_inline_namespace_reopened_noninline, -1,
  /* DiagArray384 */ diag::ext_operator_new_delete_declared_inline, -1,
  /* DiagArray385 */ diag::warn_explicit_instantiation_after_specialization, -1,
  /* DiagArray386 */ diag::ext_typecheck_convert_int_pointer, diag::ext_typecheck_convert_pointer_int, -1,
  /* DiagArray388 */ diag::warn_enum_constant_in_bool_context, diag::warn_left_shift_in_bool_context, -1,
  /* DiagArray389 */ diag::warn_int_to_pointer_cast, -1,
  /* DiagArray390 */ diag::warn_int_to_void_pointer_cast, -1,
  /* DiagArray391 */ diag::warn_integer_constant_overflow, -1,
  /* DiagArray392 */ diag::warn_drv_msp430_hwmult_mismatch, diag::warn_drv_msp430_hwmult_no_device, diag::warn_drv_msp430_hwmult_unsupported, diag::warn_drv_object_size_disabled_O0, diag::warn_drv_optimization_value, diag::warn_target_unsupported_extension, -1,
  /* DiagArray393 */ diag::ext_constexpr_function_never_constant_expr, -1,
  /* DiagArray394 */ diag::warn_iboutlet_object_type, diag::warn_iboutletcollection_property_assign, -1,
  /* DiagArray395 */ diag::warn_invalid_initializer_from_system_header, -1,
  /* DiagArray396 */ diag::warn_invalid_ios_deployment_target, -1,
  /* DiagArray397 */ diag::warn_attribute_no_builtin_invalid_builtin_name, -1,
  /* DiagArray398 */ diag::warn_falloff_noreturn_function, diag::warn_noreturn_function_has_return_expr, -1,
  /* DiagArray399 */ diag::ext_offsetof_non_pod_type, diag::ext_offsetof_non_standardlayout_type, -1,
  /* DiagArray400 */ diag::warn_drv_ps4_sdk_dir, diag::warn_drv_unable_to_find_directory_expected, -1,
  /* DiagArray401 */ diag::ext_partial_spec_not_more_specialized_than_primary, -1,
  /* DiagArray403 */ diag::ext_empty_character, diag::ext_unterminated_char_or_string, -1,
  /* DiagArray404 */ diag::warn_bad_character_encoding, diag::warn_bad_string_encoding, -1,
  /* DiagArray405 */ diag::ext_pp_bad_paste_ms, -1,
  /* DiagArray406 */ diag::warn_jump_out_of_seh_finally, -1,
  /* DiagArray407 */ diag::ext_keyword_as_ident, -1,
  /* DiagArray408 */ diag::warn_pp_macro_hides_keyword, -1,
  /* DiagArray409 */ diag::ext_param_promoted_not_compatible_with_prototype, -1,
  /* DiagArray410 */ diag::ext_token_used, -1,
  /* DiagArray411 */ diag::warn_parameter_size, diag::warn_return_value_size, -1,
  /* DiagArray413 */ diag::warn_impcast_literal_float_to_integer, diag::warn_impcast_literal_float_to_integer_out_of_range, -1,
  /* DiagArray414 */ diag::warn_float_overflow, diag::warn_float_underflow, -1,
  /* DiagArray415 */ diag::ext_template_arg_local_type, -1,
  /* DiagArray416 */ diag::warn_logical_not_on_lhs_of_check, -1,
  /* DiagArray417 */ diag::warn_logical_and_in_logical_or, -1,
  /* DiagArray418 */ diag::ext_c99_longlong, -1,
  /* DiagArray420 */ diag::ext_pp_macro_redef, -1,
  /* DiagArray421 */ diag::ext_main_used, diag::ext_noreturn_main, diag::ext_variadic_main, diag::warn_main_one_arg, diag::warn_main_redefined, diag::warn_main_returns_bool_literal, diag::warn_static_main, -1,
  /* DiagArray422 */ diag::ext_main_returns_nonint, -1,
  /* DiagArray423 */ diag::warn_has_warning_invalid_option, -1,
  /* DiagArray424 */ diag::ext_many_braces_around_init, -1,
  /* DiagArray425 */ diag::warn_max_tokens, diag::warn_max_tokens_total, -1,
  /* DiagArray426 */ diag::warn_max_unsigned_zero, -1,
  /* DiagArray427 */ diag::warn_suspicious_sizeof_memset, -1,
  /* DiagArray428 */ diag::warn_memsize_comparison, -1,
  /* DiagArray429 */ diag::warn_non_contravariant_param_types, diag::warn_non_covariant_ret_types, -1,
  /* DiagArray431 */ diag::ext_anonymous_record_with_type, diag::ext_ms_anonymous_record, -1,
  /* DiagArray432 */ diag::ext_ms_cast_fn_obj, diag::ext_ms_impcast_fn_obj, -1,
  /* DiagArray433 */ diag::ext_charize_microsoft, -1,
  /* DiagArray434 */ diag::ext_comment_paste_microsoft, -1,
  /* DiagArray435 */ diag::ext_default_init_const, -1,
  /* DiagArray436 */ diag::ext_pp_operator_used_as_macro_name, -1,
  /* DiagArray437 */ diag::ext_param_default_argument_redefinition, -1,
  /* DiagArray438 */ diag::warn_attribute_section_drectve, -1,
  /* DiagArray439 */ diag::ext_ctrl_z_eof_microsoft, -1,
  /* DiagArray440 */ diag::ext_ms_forward_ref_enum, -1,
  /* DiagArray441 */ diag::ext_enumerator_too_large, -1,
  /* DiagArray442 */ diag::ext_ellipsis_exception_spec, diag::ext_incomplete_in_exception_spec, diag::ext_mismatched_exception_spec, diag::ext_mismatched_exception_spec_explicit_instantiation, diag::ext_ms_missing_exception_specification, diag::ext_override_exception_spec, -1,
  /* DiagArray443 */ diag::warn_microsoft_dependent_exists, -1,
  /* DiagArray444 */ diag::ext_ms_explicit_constructor_call, -1,
  /* DiagArray445 */ diag::warn_member_extra_qualification, -1,
  /* DiagArray446 */ diag::ext_ms_c_enum_fixed_underlying_type, -1,
  /* DiagArray447 */ diag::ext_flexible_array_empty_aggregate_ms, diag::ext_flexible_array_union_ms, -1,
  /* DiagArray448 */ diag::ext_goto_into_protected_scope, -1,
  /* DiagArray449 */ diag::ext_ms_ambiguous_direct_base, -1,
  /* DiagArray450 */ diag::ext_pp_include_search_ms, -1,
  /* DiagArray451 */ diag::ext_mutable_reference, -1,
  /* DiagArray452 */ diag::ext_pure_function_definition, -1,
  /* DiagArray453 */ diag::ext_static_non_static, -1,
  /* DiagArray454 */ diag::ext_ms_sealed_keyword, -1,
  /* DiagArray455 */ diag::ext_explicit_instantiation_duplicate, diag::ext_found_in_dependent_base, diag::ext_found_later_in_class, diag::ext_ms_delayed_template_argument, diag::ext_ms_deref_template_argument, diag::ext_ms_template_spec_redecl_out_of_scope, diag::ext_ms_template_type_arg_missing_typename, diag::ext_static_out_of_line, diag::ext_undeclared_unqual_id_with_dependent_base, -1,
  /* DiagArray456 */ diag::ext_template_param_shadow, -1,
  /* DiagArray457 */ diag::ext_union_member_of_reference_type, -1,
  /* DiagArray458 */ diag::ext_friend_tag_redecl_outside_namespace, -1,
  /* DiagArray459 */ diag::ext_ms_using_declaration_inaccessible, -1,
  /* DiagArray460 */ diag::ext_pseudo_dtor_on_void, -1,
  /* DiagArray461 */ diag::warn_misleading_indentation, -1,
  /* DiagArray462 */ diag::warn_mismatched_delete_new, -1,
  /* DiagArray463 */ diag::warn_conflicting_param_types, -1,
  /* DiagArray464 */ diag::warn_conflicting_ret_types, -1,
  /* DiagArray465 */ diag::warn_struct_class_previous_tag_mismatch, diag::warn_struct_class_tag_mismatch, -1,
  /* DiagArray466 */ diag::warn_missing_braces, -1,
  /* DiagArray467 */ diag::ext_constinit_missing, -1,
  /* DiagArray468 */ diag::ext_no_declarators, diag::ext_standalone_specifier, diag::ext_typedef_without_a_name, diag::warn_standalone_specifier, -1,
  /* DiagArray469 */ diag::ext_missing_exception_specification, -1,
  /* DiagArray470 */ diag::warn_missing_field_initializers, -1,
  /* DiagArray473 */ diag::warn_missing_method_return_type, -1,
  /* DiagArray474 */ diag::warn_overriding_method_missing_noescape, -1,
  /* DiagArray475 */ diag::warn_suggest_noreturn_block, diag::warn_suggest_noreturn_function, -1,
  /* DiagArray476 */ diag::warn_cconv_knr, -1,
  /* DiagArray477 */ diag::warn_missing_prototype, -1,
  /* DiagArray478 */ diag::warn_missing_selector_name, -1,
  /* DiagArray479 */ diag::warn_missing_sysroot, -1,
  /* DiagArray480 */ diag::warn_missing_variable_declarations, -1,
  /* DiagArray481 */ diag::warn_assume_attribute_string_unknown_suggested, -1,
  /* DiagArray482 */ diag::remark_module_build, diag::remark_module_build_done, diag::remark_module_lock_failure, diag::remark_module_lock_timeout, -1,
  /* DiagArray483 */ diag::warn_module_conflict, diag::warn_module_system_bit_conflict, -1,
  /* DiagArray484 */ diag::warn_module_config_mismatch, -1,
  /* DiagArray485 */ diag::warn_duplicate_module_file_extension, -1,
  /* DiagArray486 */ diag::remark_module_import, -1,
  /* DiagArray487 */ diag::ext_module_import_in_extern_c, -1,
  /* DiagArray488 */ diag::ext_equivalent_internal_linkage_decl_in_modules, -1,
  /* DiagArray489 */ diag::ext_module_import_not_at_top_level_noop, -1,
  /* DiagArray493 */ diag::warn_drv_msvc_not_found, -1,
  /* DiagArray494 */ diag::warn_multichar_character_literal, -1,
  /* DiagArray495 */ diag::warn_vbase_moved_multiple_times, -1,
  /* DiagArray497 */ diag::ext_anonymous_record_with_anonymous_type, -1,
  /* DiagArray499 */ diag::warn_operator_new_returns_null, -1,
  /* DiagArray500 */ diag::ext_no_newline_eof, diag::warn_no_newline_eof, -1,
  /* DiagArray501 */ diag::warn_dereference_of_noderef_type, diag::warn_dereference_of_noderef_type_no_decl, diag::warn_noderef_to_dereferenceable_pointer, -1,
  /* DiagArray503 */ diag::ext_non_c_like_anon_struct_in_typedef, -1,
  /* DiagArray505 */ diag::warn_non_literal_null_pointer, -1,
  /* DiagArray506 */ diag::warn_non_modular_include_in_framework_module, -1,
  /* DiagArray507 */ diag::warn_non_modular_include_in_module, -1,
  /* DiagArray508 */ diag::warn_cannot_pass_non_pod_arg_to_vararg, diag::warn_non_pod_vararg_with_format_string, diag::warn_second_parameter_to_va_arg_not_pod, diag::warn_second_parameter_to_va_arg_ownership_qualified, -1,
  /* DiagArray509 */ diag::warn_alignment_not_power_of_two, -1,
  /* DiagArray510 */ diag::warn_non_virtual_dtor, -1,
  /* DiagArray511 */ diag::warn_null_arg, diag::warn_null_ret, -1,
  /* DiagArray513 */ diag::pp_nonportable_path, -1,
  /* DiagArray514 */ diag::pp_nonportable_system_path, -1,
  /* DiagArray515 */ diag::warn_neon_vector_initializer_non_portable, -1,
  /* DiagArray516 */ diag::warn_cstruct_memaccess, -1,
  /* DiagArray517 */ diag::warn_nsconsumed_attribute_mismatch, -1,
  /* DiagArray518 */ diag::warn_nsreturns_retained_attribute_mismatch, -1,
  /* DiagArray519 */ diag::warn_null_in_arithmetic_operation, diag::warn_null_in_comparison_operation, -1,
  /* DiagArray520 */ diag::null_in_char_or_string, diag::null_in_file, -1,
  /* DiagArray521 */ diag::warn_impcast_null_pointer_to_integer, -1,
  /* DiagArray522 */ diag::warn_binding_null_to_reference, diag::warn_indirection_through_null, -1,
  /* DiagArray523 */ diag::warn_gnu_null_ptr_arith, diag::warn_pointer_arith_null_ptr, -1,
  /* DiagArray524 */ diag::warn_conflicting_nullability_attr_overriding_param_types, diag::warn_conflicting_nullability_attr_overriding_ret_types, diag::warn_mismatched_nullability_attr, diag::warn_null_resettable_setter, diag::warn_nullability_duplicate, -1,
  /* DiagArray525 */ diag::warn_nullability_missing, -1,
  /* DiagArray526 */ diag::warn_nullability_missing_array, -1,
  /* DiagArray527 */ diag::warn_nullability_declspec, -1,
  /* DiagArray528 */ diag::ext_nullability, -1,
  /* DiagArray529 */ diag::warn_nullability_inferred_on_nested_type, -1,
  /* DiagArray530 */ diag::warn_nullability_lost, -1,
  /* DiagArray531 */ diag::warn_autosynthesis_property_ivar_match, -1,
  /* DiagArray532 */ diag::warn_impcast_constant_value_to_objc_bool, -1,
  /* DiagArray533 */ diag::warn_objc_boxing_invalid_utf8_string, -1,
  /* DiagArray534 */ diag::warn_objc_circular_container, -1,
  /* DiagArray536 */ diag::warn_objc_designated_init_missing_super_call, diag::warn_objc_designated_init_non_designated_init_call, diag::warn_objc_designated_init_non_super_designated_init_call, diag::warn_objc_implementation_missing_designated_init_override, diag::warn_objc_secondary_init_missing_init_call, diag::warn_objc_secondary_init_super_init_call, -1,
  /* DiagArray537 */ diag::warn_nsdictionary_duplicate_key, -1,
  /* DiagArray538 */ diag::warn_superclass_variable_sized_type_not_at_end, diag::warn_variable_sized_ivar_visibility, -1,
  /* DiagArray539 */ diag::warn_forward_class_redefinition, -1,
  /* DiagArray540 */ diag::warn_ivars_in_interface, -1,
  /* DiagArray541 */ diag::warn_objc_literal_comparison, -1,
  /* DiagArray542 */ diag::warn_impcast_objective_c_literal_to_bool, diag::warn_objc_collection_literal_element, -1,
  /* DiagArray543 */ diag::warn_pp_objc_macro_redef_ignored, -1,
  /* DiagArray544 */ diag::warn_messaging_unqualified_id, -1,
  /* DiagArray545 */ diag::warn_class_method_not_found, diag::warn_class_method_not_found_with_typo, diag::warn_inst_method_not_found, diag::warn_instance_method_not_found_with_typo, diag::warn_instance_method_on_class_found, diag::warn_root_inst_method_not_found, -1,
  /* DiagArray546 */ diag::warn_missing_explicit_synthesis, -1,
  /* DiagArray547 */ diag::warn_objc_missing_super_call, -1,
  /* DiagArray548 */ diag::warn_multiple_method_decl, -1,
  /* DiagArray549 */ diag::warn_objc_property_retain_of_block, -1,
  /* DiagArray550 */ diag::warn_objc_pointer_cxx_catch_fragile, -1,
  /* DiagArray551 */ diag::warn_objc_property_assign_on_object, -1,
  /* DiagArray552 */ diag::warn_impl_required_for_class_property, diag::warn_impl_required_in_category_for_class_property, diag::warn_setter_getter_impl_required, diag::warn_setter_getter_impl_required_in_category, -1,
  /* DiagArray553 */ diag::warn_property_implicitly_mismatched, -1,
  /* DiagArray554 */ diag::warn_cocoa_naming_owned_rule, -1,
  /* DiagArray555 */ diag::warn_objc_property_default_assign_on_object, diag::warn_objc_property_no_assignment_attribute, -1,
  /* DiagArray556 */ diag::warn_autosynthesis_property_in_superclass, diag::warn_no_autosynthesis_property, diag::warn_no_autosynthesis_shared_ivar_property, -1,
  /* DiagArray557 */ diag::warn_category_method_impl_match, -1,
  /* DiagArray558 */ diag::warn_auto_synthesizing_protocol_property, -1,
  /* DiagArray559 */ diag::warn_objc_redundant_qualified_class_type, -1,
  /* DiagArray560 */ diag::warn_objc_readonly_property_has_setter, -1,
  /* DiagArray562 */ diag::warn_objc_redundant_literal_use, -1,
  /* DiagArray563 */ diag::warn_objc_root_class_missing, -1,
  /* DiagArray565 */ diag::warn_impcast_float_to_objc_signed_char_bool, -1,
  /* DiagArray566 */ diag::warn_impcast_int_to_objc_signed_char_bool, -1,
  /* DiagArray567 */ diag::warn_objc_string_literal_comparison, -1,
  /* DiagArray568 */ diag::warn_concatenated_nsarray_literal, -1,
  /* DiagArray569 */ diag::warn_objc_unsafe_perform_selector, -1,
  /* DiagArray570 */ diag::warn_odr_different_num_template_parameters, diag::warn_odr_different_template_parameter_kind, diag::warn_odr_field_type_inconsistent, diag::warn_odr_function_type_inconsistent, diag::warn_odr_ivar_type_inconsistent, diag::warn_odr_non_type_parameter_type_inconsistent, diag::warn_odr_objc_method_num_params_inconsistent, diag::warn_odr_objc_method_param_type_inconsistent, diag::warn_odr_objc_method_result_type_inconsistent, diag::warn_odr_objc_method_variadic_inconsistent, diag::warn_odr_objc_property_impl_kind_inconsistent, diag::warn_odr_objc_property_type_inconsistent, diag::warn_odr_objc_superclass_inconsistent, diag::warn_odr_objc_synthesize_ivar_inconsistent, diag::warn_odr_parameter_pack_non_pack, diag::warn_odr_tag_type_inconsistent, diag::warn_odr_variable_multiple_def, diag::warn_odr_variable_type_inconsistent, -1,
  /* DiagArray571 */ diag::warn_old_style_cast, -1,
  /* DiagArray573 */ diag::ext_opencl_ext_vector_type_rgba_selector, -1,
  /* DiagArray575 */ diag::warn_omp_alignment_not_power_of_two, diag::warn_omp_allocate_thread_on_task_target_directive, diag::warn_omp_ctx_incompatible_property_for_selector, diag::warn_omp_ctx_incompatible_score_for_property, diag::warn_omp_ctx_incompatible_selector_for_set, diag::warn_omp_ctx_selector_without_properties, diag::warn_omp_declare_variant_ctx_mutiple_use, diag::warn_omp_declare_variant_ctx_not_a_property, diag::warn_omp_declare_variant_ctx_not_a_selector, diag::warn_omp_declare_variant_ctx_not_a_set, diag::warn_omp_declare_variant_expected, diag::warn_omp_declare_variant_string_literal_or_identifier, diag::warn_omp_linear_step_zero, diag::warn_omp_more_one_device_type_clause, diag::warn_omp_unknown_assumption_clause_missing_id, diag::warn_omp_unknown_assumption_clause_without_args, diag::warn_omp_used_different_allocator, -1,
  /* DiagArray576 */ diag::ext_omp_loop_not_canonical_init, diag::warn_omp_loop_64_bit_var, -1,
  /* DiagArray577 */ diag::warn_omp_non_trivial_type_mapped, -1,
  /* DiagArray578 */ diag::warn_drv_omp_offload_target_duplicate, diag::warn_omp_declare_target_after_first_use, diag::warn_omp_not_in_target_context, -1,
  /* DiagArray579 */ diag::warn_drv_fine_grained_bitfield_accesses_ignored, diag::warn_drv_moutline_atomics_unsupported_opt, diag::warn_drv_moutline_unsupported_opt, diag::warn_drv_ps4_force_pic, diag::warn_drv_unsupported_longcalls, diag::warn_drv_unsupported_pic_with_mabicalls, diag::warn_drv_unsupported_sdata, diag::warn_drv_vectorize_needs_hvx, -1,
  /* DiagArray580 */ diag::ext_typecheck_ordered_comparison_of_function_pointers, -1,
  /* DiagArray581 */ diag::ext_out_of_line_declaration, -1,
  /* DiagArray582 */ diag::ext_use_out_of_scope_declaration, -1,
  /* DiagArray583 */ diag::warn_overaligned_type, -1,
  /* DiagArray585 */ diag::ext_string_too_long, -1,
  /* DiagArray586 */ diag::warn_overloaded_shift_in_comparison, -1,
  /* DiagArray587 */ diag::warn_overloaded_virtual, -1,
  /* DiagArray589 */ diag::warn_fe_override_module, -1,
  /* DiagArray590 */ diag::warn_conflicting_overriding_param_modifiers, diag::warn_conflicting_overriding_param_types, diag::warn_conflicting_overriding_ret_type_modifiers, diag::warn_conflicting_overriding_ret_types, diag::warn_conflicting_overriding_variadic, diag::warn_non_contravariant_overriding_param_types, diag::warn_non_covariant_overriding_ret_types, -1,
  /* DiagArray591 */ diag::warn_drv_overriding_flag_option, -1,
  /* DiagArray592 */ diag::warn_unnecessary_packed, -1,
  /* DiagArray593 */ diag::warn_padded_struct_anon_field, diag::warn_padded_struct_field, diag::warn_padded_struct_size, -1,
  /* DiagArray594 */ diag::warn_condition_is_assignment, diag::warn_precedence_bitwise_rel, diag::warn_precedence_conditional, -1,
  /* DiagArray595 */ diag::warn_equality_with_extra_parens, -1,
  /* DiagArray597 */ diag::remark_fe_backend_optimization_remark, -1,
  /* DiagArray598 */ diag::remark_fe_backend_optimization_remark_analysis, diag::remark_fe_backend_optimization_remark_analysis_aliasing, diag::remark_fe_backend_optimization_remark_analysis_fpcommute, -1,
  /* DiagArray599 */ diag::warn_fe_backend_optimization_failure, -1,
  /* DiagArray600 */ diag::remark_fe_backend_optimization_remark_missed, -1,
  /* DiagArray601 */ diag::warn_module_uses_date_time, -1,
  /* DiagArray602 */ diag::ext_aggregate_init_not_constant, diag::ext_anonymous_record_with_type, diag::ext_anonymous_struct_union_qualified, diag::ext_array_size_conversion, diag::ext_auto_new_list_init, diag::ext_c99_array_usage, diag::ext_c99_compound_literal, diag::ext_c99_feature, diag::ext_c99_flexible_array_member, diag::ext_c99_variable_decl_in_for_loop, diag::ext_cast_fn_obj, diag::ext_clang_diagnose_if, diag::ext_clang_enable_if, diag::ext_cxx11_enum_fixed_underlying_type, diag::ext_cxx14_attr, diag::ext_cxx17_attr, diag::ext_cxx20_attr, diag::ext_designated_init, diag::ext_dtor_name_ambiguous, diag::ext_dtor_named_in_wrong_scope, diag::ext_duplicate_declspec, diag::ext_ellipsis_exception_spec, diag::ext_empty_fnmacro_arg, diag::ext_enum_value_not_int, diag::ext_enumerator_list_comma_c, diag::ext_enumerator_list_comma_cxx, diag::ext_explicit_instantiation_without_qualified_id, diag::ext_expr_not_ice, diag::ext_extern_template, diag::ext_extra_semi, diag::ext_forward_ref_enum, diag::ext_freestanding_complex, diag::ext_gnu_array_range, diag::ext_gnu_ptr_func_arith, diag::ext_gnu_subscript_void_type, diag::ext_gnu_void_ptr, diag::ext_hex_constant_invalid, diag::ext_hex_literal_invalid, diag::ext_ident_list_in_param, diag::ext_in_class_initializer_non_constant, diag::ext_integer_complement_complex, diag::ext_integer_increment_complex, diag::ext_internal_in_extern_inline_quiet, diag::ext_line_comment, diag::ext_main_used, diag::ext_multi_line_line_comment, diag::ext_named_variadic_macro, diag::ext_no_newline_eof, diag::ext_nonstandard_escape, diag::ext_ns_enum_attribute, diag::ext_param_not_declared, diag::ext_pointer_to_const_ref_member_on_rvalue, diag::ext_pp_bad_vaargs_use, diag::ext_pp_comma_expr, diag::ext_pp_ident_directive, diag::ext_pp_line_too_big, diag::ext_pp_opencl_variadic_macros, diag::ext_pp_warning_directive, diag::ext_return_has_void_expr, diag::ext_rvalue_to_reference_access_ctor, diag::ext_rvalue_to_reference_temp_copy_no_viable, diag::ext_sizeof_alignof_function_type, diag::ext_sizeof_alignof_void_type, diag::ext_subscript_non_lvalue, diag::ext_thread_before, diag::ext_typecheck_addrof_void, diag::ext_typecheck_cast_nonscalar, diag::ext_typecheck_comparison_of_fptr_to_void, diag::ext_typecheck_cond_one_void, diag::ext_typecheck_convert_pointer_void_func, diag::ext_typecheck_ordered_comparison_of_pointer_and_zero, diag::ext_variadic_macro, diag::warn_defined_in_function_type_macro, diag::warn_format_conversion_argument_type_mismatch_pedantic, diag::warn_kern_is_method, -1,
  /* DiagArray603 */ diag::warn_pragma_extension_is_core, -1,
  /* DiagArray604 */ diag::warn_pessimizing_move_on_initialization, diag::warn_pessimizing_move_on_return, -1,
  /* DiagArray605 */ diag::ext_gnu_ptr_func_arith, diag::ext_gnu_subscript_void_type, diag::ext_gnu_void_ptr, diag::ext_sizeof_alignof_function_type, diag::ext_sizeof_alignof_void_type, diag::warn_sub_ptr_zero_size_types, -1,
  /* DiagArray606 */ diag::warn_cast_nonnull_to_bool, diag::warn_impcast_pointer_to_bool, -1,
  /* DiagArray607 */ diag::warn_pointer_compare, -1,
  /* DiagArray608 */ diag::ext_typecheck_comparison_of_pointer_integer, -1,
  /* DiagArray609 */ diag::ext_typecheck_convert_incompatible_pointer_sign, -1,
  /* DiagArray610 */ diag::warn_pointer_to_enum_cast, -1,
  /* DiagArray611 */ diag::warn_pointer_to_int_cast, -1,
  /* DiagArray612 */ diag::ext_typecheck_cond_incompatible_pointers, -1,
  /* DiagArray613 */ diag::warn_poison_system_directories, -1,
  /* DiagArray614 */ diag::warn_potentially_direct_selector_expression, -1,
  /* DiagArray615 */ diag::warn_side_effects_typeid, -1,
  /* DiagArray616 */ diag::warn_pragma_attribute_unused, -1,
  /* DiagArray617 */ diag::pp_pragma_once_in_main_file, -1,
  /* DiagArray618 */ diag::warn_pragma_pack_modified_after_include, diag::warn_pragma_pack_no_pop_eof, -1,
  /* DiagArray619 */ diag::warn_pragma_pack_non_default_at_include, -1,
  /* DiagArray620 */ diag::pp_pragma_sysheader_in_main_file, -1,
  /* DiagArray621 */ diag::warn_redefine_extname_not_applied, -1,
  /* DiagArray622 */ diag::ext_predef_outside_function, -1,
  /* DiagArray623 */ diag::warn_private_extern, -1,
  /* DiagArray624 */ diag::warn_use_of_private_header_outside_module, -1,
  /* DiagArray625 */ diag::warn_mmap_mismatched_private_module_name, diag::warn_mmap_mismatched_private_submodule, diag::warn_mmap_redundant_export_as, diag::warn_no_priv_submodule_use_toplevel, -1,
  /* DiagArray626 */ diag::warn_profile_data_missing, -1,
  /* DiagArray627 */ diag::warn_profile_data_out_of_date, -1,
  /* DiagArray628 */ diag::warn_profile_data_unprofiled, -1,
  /* DiagArray629 */ diag::warn_property_access_suggest, -1,
  /* DiagArray630 */ diag::warn_property_attr_mismatch, diag::warn_property_attribute, diag::warn_property_redecl_getter_mismatch, diag::warn_readonly_property, -1,
  /* DiagArray631 */ diag::warn_unimplemented_protocol_method, -1,
  /* DiagArray632 */ diag::warn_protocol_property_mismatch, -1,
  /* DiagArray633 */ diag::warn_avx_calling_convention, -1,
  /* DiagArray634 */ diag::err_func_returning_qualified_void, -1,
  /* DiagArray635 */ diag::warn_quoted_include_in_framework_header, -1,
  /* DiagArray637 */ diag::warn_for_range_ref_binds_ret_temp, -1,
  /* DiagArray638 */ diag::warn_for_range_const_ref_binds_temp_built_from_ref, diag::warn_for_range_copy, -1,
  /* DiagArray639 */ diag::warn_auto_readonly_iboutlet_property, -1,
  /* DiagArray640 */ diag::warn_bad_receiver_type, -1,
  /* DiagArray641 */ diag::warn_receiver_forward_class, diag::warn_receiver_forward_instance, -1,
  /* DiagArray642 */ diag::ext_member_redeclared, -1,
  /* DiagArray644 */ diag::warn_redundant_move_on_return, -1,
  /* DiagArray645 */ diag::warn_redundant_parens_around_declarator, -1,
  /* DiagArray646 */ diag::ext_register_storage_class, -1,
  /* DiagArray647 */ diag::warn_reinterpret_different_from_static, -1,
  /* DiagArray648 */ diag::remark_fe_backend_plugin, -1,
  /* DiagArray650 */ diag::warn_initializer_out_of_order, -1,
  /* DiagArray651 */ diag::ext_designated_init_reordered, -1,
  /* DiagArray652 */ diag::warn_requires_expr_in_simple_requirement, -1,
  /* DiagArray653 */ diag::warn_objc_requires_super_protocol, -1,
  /* DiagArray654 */ diag::warn_pp_macro_is_reserved_id, -1,
  /* DiagArray655 */ diag::ext_ms_reserved_user_defined_literal, diag::ext_reserved_user_defined_literal, -1,
  /* DiagArray656 */ diag::ext_retained_language_linkage, -1,
  /* DiagArray657 */ diag::warn_ret_addr_label, diag::warn_ret_local_temp_addr_ref, diag::warn_ret_stack_addr_ref, -1,
  /* DiagArray658 */ diag::warn_return_std_move, -1,
  /* DiagArray659 */ diag::warn_return_std_move_in_cxx11, -1,
  /* DiagArray660 */ diag::ext_return_has_expr, diag::ext_return_missing_expr, diag::warn_falloff_nonvoid_coroutine, diag::warn_falloff_nonvoid_function, diag::warn_falloff_nonvoid_lambda, diag::warn_maybe_falloff_nonvoid_coroutine, diag::warn_maybe_falloff_nonvoid_function, diag::warn_maybe_falloff_nonvoid_lambda, diag::warn_return_missing_expr, -1,
  /* DiagArray661 */ diag::warn_return_value_udt, diag::warn_return_value_udt_incomplete, -1,
  /* DiagArray662 */ diag::ext_ovl_rewrite_equalequal_not_bool, -1,
  /* DiagArray663 */ diag::warn_no_dynamic_cast_with_rtti_disabled, diag::warn_no_typeid_with_rtti_disabled, -1,
  /* DiagArray664 */ diag::remark_sanitize_address_insert_extra_padding_accepted, diag::remark_sanitize_address_insert_extra_padding_rejected, -1,
  /* DiagArray665 */ diag::warn_attribute_section_on_redeclaration, diag::warn_duplicate_codeseg_attribute, diag::warn_mismatched_section, -1,
  /* DiagArray666 */ diag::warn_unimplemented_selector, -1,
  /* DiagArray667 */ diag::warn_multiple_selectors, -1,
  /* DiagArray668 */ diag::warn_self_assignment_builtin, -1,
  /* DiagArray669 */ diag::warn_identity_field_assign, -1,
  /* DiagArray670 */ diag::warn_self_assignment_overloaded, -1,
  /* DiagArray671 */ diag::warn_self_move, -1,
  /* DiagArray672 */ diag::warn_semicolon_before_method_body, -1,
  /* DiagArray673 */ diag::warn_missing_sentinel, diag::warn_not_enough_argument, -1,
  /* DiagArray675 */ diag::warn_fe_serialized_diag_failure, diag::warn_fe_serialized_diag_failure_during_finalisation, diag::warn_fe_serialized_diag_merge_failure, -1,
  /* DiagArray676 */ diag::warn_decl_shadow, -1,
  /* DiagArray678 */ diag::warn_shadow_field, -1,
  /* DiagArray679 */ diag::warn_ctor_parm_shadows_field, -1,
  /* DiagArray680 */ diag::warn_modifying_shadowing_decl, -1,
  /* DiagArray681 */ diag::warn_ivar_use_hidden, -1,
  /* DiagArray682 */ diag::warn_decl_shadow_uncaptured_local, -1,
  /* DiagArray683 */ diag::warn_shift_negative, -1,
  /* DiagArray684 */ diag::warn_shift_gt_typewidth, -1,
  /* DiagArray685 */ diag::warn_shift_lhs_negative, -1,
  /* DiagArray686 */ diag::warn_addition_in_bitshift, -1,
  /* DiagArray687 */ diag::warn_shift_result_gt_typewidth, -1,
  /* DiagArray688 */ diag::warn_shift_result_sets_sign_bit, -1,
  /* DiagArray689 */ diag::warn_impcast_integer_64_32, -1,
  /* DiagArray690 */ diag::warn_mixed_sign_comparison, -1,
  /* DiagArray691 */ diag::warn_impcast_integer_sign, diag::warn_impcast_integer_sign_conditional, diag::warn_impcast_nonnegative_result, -1,
  /* DiagArray693 */ diag::warn_no_underlying_type_specified_for_enum_bitfield, -1,
  /* DiagArray694 */ diag::ext_wchar_t_sign_spec, -1,
  /* DiagArray695 */ diag::warn_sizeof_array_param, -1,
  /* DiagArray696 */ diag::warn_sizeof_array_decay, -1,
  /* DiagArray697 */ diag::warn_division_sizeof_array, -1,
  /* DiagArray698 */ diag::warn_division_sizeof_ptr, -1,
  /* DiagArray699 */ diag::warn_sizeof_pointer_expr_memaccess, diag::warn_sizeof_pointer_type_memaccess, -1,
  /* DiagArray700 */ diag::warn_slash_u_filename, -1,
  /* DiagArray701 */ diag::warn_slh_does_not_support_asm_goto, -1,
  /* DiagArray702 */ diag::warn_sometimes_uninit_var, -1,
  /* DiagArray703 */ diag::warn_omp_declare_variant_after_emitted, diag::warn_omp_declare_variant_after_used, diag::warn_omp_declare_variant_marked_as_declare_variant, diag::warn_omp_declare_variant_score_not_constant, diag::warn_omp_nesting_simd, diag::warn_pragma_omp_ignored, diag::warn_unknown_begin_declare_variant_isa_trait, diag::warn_unknown_declare_variant_isa_trait, -1,
  /* DiagArray704 */ diag::warn_sampler_initializer_invalid_bits, -1,
  /* DiagArray705 */ diag::warn_stack_exhausted, -1,
  /* DiagArray706 */ diag::warn_stack_clash_protection_inline_asm, -1,
  /* DiagArray707 */ diag::ext_in_class_initializer_float_type_cxx11, -1,
  /* DiagArray708 */ diag::ext_internal_in_extern_inline, diag::ext_internal_in_extern_inline_quiet, -1,
  /* DiagArray709 */ diag::warn_static_inline_explicit_inst_ignored, -1,
  /* DiagArray710 */ diag::warn_static_local_in_extern_inline, -1,
  /* DiagArray711 */ diag::warn_static_self_reference_in_init, -1,
  /* DiagArray712 */ diag::warn_drv_libstdcxx_not_found, -1,
  /* DiagArray724 */ diag::warn_strict_potentially_direct_selector_expression, -1,
  /* DiagArray725 */ diag::warn_strict_prototypes, -1,
  /* DiagArray726 */ diag::warn_strict_multiple_method_decl, -1,
  /* DiagArray727 */ diag::warn_stringcompare, -1,
  /* DiagArray728 */ diag::warn_concatenated_literal_array_init, -1,
  /* DiagArray729 */ diag::warn_impcast_string_literal_to_bool, -1,
  /* DiagArray730 */ diag::warn_string_plus_char, -1,
  /* DiagArray731 */ diag::warn_string_plus_int, -1,
  /* DiagArray732 */ diag::warn_strlcpycat_wrong_size, -1,
  /* DiagArray733 */ diag::warn_strncat_large_size, diag::warn_strncat_src_size, diag::warn_strncat_wrong_size, -1,
  /* DiagArray734 */ diag::warn_suggest_destructor_marked_not_override_overriding, -1,
  /* DiagArray735 */ diag::warn_suggest_function_marked_not_override_overriding, -1,
  /* DiagArray736 */ diag::ext_typecheck_base_super, -1,
  /* DiagArray737 */ diag::warn_suspicious_bzero_size, -1,
  /* DiagArray739 */ diag::warn_attr_swift_name_decl_kind, diag::warn_attr_swift_name_decl_missing_params, diag::warn_attr_swift_name_function, diag::warn_attr_swift_name_getter_parameters, diag::warn_attr_swift_name_invalid_identifier, diag::warn_attr_swift_name_missing_parameters, diag::warn_attr_swift_name_multiple_selfs, diag::warn_attr_swift_name_num_params, diag::warn_attr_swift_name_setter_parameters, diag::warn_attr_swift_name_subscript_getter_newValue, diag::warn_attr_swift_name_subscript_invalid_parameter, diag::warn_attr_swift_name_subscript_setter_multiple_newValues, diag::warn_attr_swift_name_subscript_setter_no_newValue, -1,
  /* DiagArray740 */ diag::warn_case_value_overflow, diag::warn_missing_case, diag::warn_not_in_enum, -1,
  /* DiagArray741 */ diag::warn_bool_switch_condition, -1,
  /* DiagArray743 */ diag::warn_def_missing_case, -1,
  /* DiagArray744 */ diag::warn_sync_fetch_and_nand_semantics_change, -1,
  /* DiagArray746 */ diag::warn_comparison_bitwise_always, diag::warn_comparison_bitwise_or, -1,
  /* DiagArray747 */ diag::warn_alignment_builtin_useless, diag::warn_comparison_always, -1,
  /* DiagArray748 */ diag::warn_integer_constants_in_conditional_always_true, diag::warn_left_shift_always, diag::warn_tautological_bool_compare, -1,
  /* DiagArray750 */ diag::warn_out_of_range_compare, -1,
  /* DiagArray751 */ diag::warn_tautological_compare_objc_bool, -1,
  /* DiagArray752 */ diag::warn_tautological_overlap_comparison, -1,
  /* DiagArray753 */ diag::warn_nonnull_expr_compare, diag::warn_null_pointer_compare, -1,
  /* DiagArray754 */ diag::warn_tautological_constant_compare, -1,
  /* DiagArray755 */ diag::warn_address_of_reference_null_compare, diag::warn_this_null_compare, -1,
  /* DiagArray756 */ diag::warn_unsigned_enum_always_true_comparison, -1,
  /* DiagArray757 */ diag::warn_unsigned_always_true_comparison, -1,
  /* DiagArray758 */ diag::warn_tautological_compare_value_range, -1,
  /* DiagArray759 */ diag::warn_tcb_enforcement_violation, -1,
  /* DiagArray760 */ diag::ext_typecheck_decl_incomplete_type, -1,
  /* DiagArray762 */ diag::warn_acquired_before, diag::warn_acquired_before_after_cycle, diag::warn_cannot_resolve_lock, diag::warn_double_lock, diag::warn_expecting_lock_held_on_loop, diag::warn_expecting_locked, diag::warn_fun_excludes_mutex, diag::warn_fun_requires_lock, diag::warn_fun_requires_negative_cap, diag::warn_lock_exclusive_and_shared, diag::warn_lock_some_predecessors, diag::warn_no_unlock, diag::warn_unlock_but_no_lock, diag::warn_unlock_kind_mismatch, diag::warn_var_deref_requires_any_lock, diag::warn_var_deref_requires_lock, diag::warn_variable_requires_any_lock, diag::warn_variable_requires_lock, -1,
  /* DiagArray763 */ diag::warn_thread_attribute_argument_not_lockable, diag::warn_thread_attribute_decl_not_lockable, diag::warn_thread_attribute_decl_not_pointer, diag::warn_thread_attribute_ignored, diag::warn_thread_attribute_not_on_capability_member, diag::warn_thread_attribute_not_on_non_static_member, -1,
  /* DiagArray764 */ diag::warn_thread_safety_beta, -1,
  /* DiagArray765 */ diag::warn_acquire_requires_negative_cap, -1,
  /* DiagArray766 */ diag::warn_fun_requires_lock_precise, diag::warn_var_deref_requires_lock_precise, diag::warn_variable_requires_lock_precise, -1,
  /* DiagArray767 */ diag::warn_guarded_pass_by_reference, diag::warn_pt_guarded_pass_by_reference, -1,
  /* DiagArray768 */ diag::warn_thread_safety_verbose, -1,
  /* DiagArray769 */ diag::trigraph_converted, diag::trigraph_ends_block_comment, diag::trigraph_ignored, diag::trigraph_ignored_block_comment, -1,
  /* DiagArray771 */ diag::warn_type_safety_null_pointer_required, diag::warn_type_safety_type_mismatch, diag::warn_type_tag_for_datatype_wrong_kind, -1,
  /* DiagArray772 */ diag::ext_redefinition_of_typedef, -1,
  /* DiagArray773 */ diag::ext_typename_missing, -1,
  /* DiagArray774 */ diag::warn_fe_unable_to_open_stats_file, -1,
  /* DiagArray775 */ diag::warn_unavailable_fwdclass_message, -1,
  /* DiagArray776 */ diag::warn_undeclared_selector, diag::warn_undeclared_selector_with_typo, -1,
  /* DiagArray777 */ diag::warn_pp_undef_identifier, -1,
  /* DiagArray778 */ diag::warn_pp_undef_prefix, -1,
  /* DiagArray779 */ diag::warn_address_of_reference_bool_conversion, diag::warn_this_bool_conversion, -1,
  /* DiagArray780 */ diag::warn_func_template_missing, -1,
  /* DiagArray781 */ diag::warn_undefined_inline, -1,
  /* DiagArray782 */ diag::warn_undefined_internal, -1,
  /* DiagArray783 */ diag::ext_undefined_internal_type, -1,
  /* DiagArray784 */ diag::warn_pointer_indirection_from_incompatible_type, diag::warn_undefined_reinterpret_cast, -1,
  /* DiagArray785 */ diag::warn_var_template_missing, -1,
  /* DiagArray786 */ diag::warn_throw_underaligned_obj, -1,
  /* DiagArray787 */ diag::warn_side_effects_unevaluated_context, -1,
  /* DiagArray788 */ diag::warn_unguarded_availability, -1,
  /* DiagArray789 */ diag::warn_unguarded_availability_new, -1,
  /* DiagArray790 */ diag::warn_ucn_escape_incomplete, diag::warn_ucn_escape_no_digits, diag::warn_ucn_escape_surrogate, diag::warn_ucn_not_valid_in_c89, diag::warn_ucn_not_valid_in_c89_literal, -1,
  /* DiagArray791 */ diag::warn_utf8_symbol_homoglyph, -1,
  /* DiagArray792 */ diag::ext_unicode_whitespace, -1,
  /* DiagArray793 */ diag::warn_utf8_symbol_zero_width, -1,
  /* DiagArray794 */ diag::warn_base_class_is_uninit, diag::warn_field_is_uninit, diag::warn_reference_field_is_uninit, diag::warn_uninit_byref_blockvar_captured_by_block, diag::warn_uninit_self_reference_in_init, diag::warn_uninit_self_reference_in_reference_init, diag::warn_uninit_var, -1,
  /* DiagArray795 */ diag::warn_uninit_const_reference, -1,
  /* DiagArray796 */ diag::warn_drv_unknown_argument_clang_cl, diag::warn_drv_unknown_argument_clang_cl_with_suggestion, -1,
  /* DiagArray797 */ diag::warn_assume_attribute_string_unknown, -1,
  /* DiagArray798 */ diag::warn_unknown_attribute_ignored, -1,
  /* DiagArray799 */ diag::warn_drv_unknown_cuda_version, -1,
  /* DiagArray800 */ diag::ext_unknown_escape, -1,
  /* DiagArray801 */ diag::ext_on_off_switch_syntax, diag::ext_pragma_syntax_eod, diag::ext_stdc_pragma_ignored, diag::warn_pragma_diagnostic_cannot_pop, diag::warn_pragma_diagnostic_invalid, diag::warn_pragma_diagnostic_invalid_option, diag::warn_pragma_diagnostic_invalid_token, diag::warn_pragma_exec_charset_expected, diag::warn_pragma_exec_charset_push_invalid, diag::warn_pragma_exec_charset_spec_invalid, diag::warn_pragma_ignored, diag::warn_pragma_include_alias_expected, diag::warn_pragma_include_alias_expected_filename, diag::warn_pragma_include_alias_mismatch_angle, diag::warn_pragma_include_alias_mismatch_quote, diag::warn_pragma_warning_expected, diag::warn_pragma_warning_expected_number, diag::warn_pragma_warning_push_level, diag::warn_pragma_warning_spec_invalid, diag::warn_stdc_fenv_round_not_supported, -1,
  /* DiagArray802 */ diag::warn_unknown_sanitizer_ignored, -1,
  /* DiagArray803 */ diag::warn_pragma_diagnostic_unknown_warning, diag::warn_unknown_diag_option, diag::warn_unknown_warning_specifier, -1,
  /* DiagArray804 */ diag::ext_template_arg_unnamed_type, -1,
  /* DiagArray805 */ diag::warn_unneeded_internal_decl, diag::warn_unneeded_static_internal_decl, -1,
  /* DiagArray806 */ diag::warn_unneeded_member_function, -1,
  /* DiagArray807 */ diag::warn_unreachable, -1,
  /* DiagArray809 */ diag::warn_unreachable_break, -1,
  /* DiagArray810 */ diag::warn_unreachable_loop_increment, -1,
  /* DiagArray811 */ diag::warn_unreachable_return, -1,
  /* DiagArray812 */ diag::warn_unsequenced_mod_mod, diag::warn_unsequenced_mod_use, -1,
  /* DiagArray813 */ diag::warn_target_unsupported_abs2008, diag::warn_target_unsupported_abslegacy, -1,
  /* DiagArray814 */ diag::warn_at_available_unchecked_use, -1,
  /* DiagArray815 */ diag::warn_target_unsupported_compact_branches, -1,
  /* DiagArray816 */ diag::warn_attribute_dll_instantiated_base_class, -1,
  /* DiagArray817 */ diag::warn_fe_backend_unsupported_fp_exceptions, diag::warn_fe_backend_unsupported_fp_rounding, -1,
  /* DiagArray818 */ diag::warn_template_qualified_friend_ignored, diag::warn_template_qualified_friend_unsupported, -1,
  /* DiagArray819 */ diag::warn_drv_unsupported_gpopt, -1,
  /* DiagArray820 */ diag::warn_target_unsupported_nan2008, diag::warn_target_unsupported_nanlegacy, -1,
  /* DiagArray821 */ diag::warn_drv_dwarf_version_limited_by_target, diag::warn_drv_unsupported_debug_info_opt_for_target, -1,
  /* DiagArray822 */ diag::warn_attribute_protected_visibility, -1,
  /* DiagArray823 */ diag::ext_partial_specs_not_deducible, -1,
  /* DiagArray826 */ diag::warn_drv_diagnostics_hotness_requires_pgo, diag::warn_drv_empty_joined_argument, diag::warn_drv_input_file_unused, diag::warn_drv_input_file_unused_by_cpp, diag::warn_drv_preprocessed_input_file_unused, diag::warn_drv_unused_argument, diag::warn_ignored_clang_option, diag::warn_ignoring_fdiscard_for_bitcode, -1,
  /* DiagArray827 */ diag::warn_unused_comparison, -1,
  /* DiagArray828 */ diag::warn_unused_const_variable, -1,
  /* DiagArray829 */ diag::warn_unused_exception_param, -1,
  /* DiagArray830 */ diag::warn_unused_function, -1,
  /* DiagArray831 */ diag::warn_unused_property_expr, -1,
  /* DiagArray832 */ diag::warn_unused_label, -1,
  /* DiagArray833 */ diag::warn_unused_lambda_capture, -1,
  /* DiagArray834 */ diag::warn_unused_local_typedef, -1,
  /* DiagArray836 */ diag::pp_macro_not_used, -1,
  /* DiagArray837 */ diag::warn_unused_member_function, -1,
  /* DiagArray838 */ diag::warn_unused_parameter, -1,
  /* DiagArray839 */ diag::warn_unused_private_field, -1,
  /* DiagArray840 */ diag::warn_unused_property_backing_ivar, -1,
  /* DiagArray841 */ diag::warn_unused_result, diag::warn_unused_result_msg, -1,
  /* DiagArray842 */ diag::warn_unused_template, -1,
  /* DiagArray843 */ diag::warn_unused_call, diag::warn_unused_constructor, diag::warn_unused_constructor_msg, diag::warn_unused_container_subscript_expr, diag::warn_unused_expr, diag::warn_unused_voidptr, -1,
  /* DiagArray844 */ diag::warn_unused_variable, -1,
  /* DiagArray845 */ diag::warn_unused_volatile, -1,
  /* DiagArray846 */ diag::warn_used_but_marked_unused, -1,
  /* DiagArray847 */ diag::warn_user_literal_reserved, -1,
  /* DiagArray848 */ diag::warn_diagnose_if_succeeded, -1,
  /* DiagArray849 */ diag::warn_second_arg_of_va_start_not_last_named_param, diag::warn_second_parameter_to_va_arg_never_compatible, diag::warn_va_start_type_is_undefined, -1,
  /* DiagArray850 */ diag::ext_named_variadic_macro, diag::ext_pp_bad_vaopt_use, diag::ext_variadic_macro, -1,
  /* DiagArray851 */ diag::warn_typecheck_vector_element_sizes_not_equal, -1,
  /* DiagArray852 */ diag::warn_incompatible_vectors, -1,
  /* DiagArray854 */ diag::warn_empty_parens_are_function_decl, diag::warn_parens_disambiguated_as_function_declaration, diag::warn_parens_disambiguated_as_variable_declaration, -1,
  /* DiagArray855 */ diag::warn_decl_in_param_list, diag::warn_redefinition_in_param_list, -1,
  /* DiagArray856 */ diag::warn_vla_used, -1,
  /* DiagArray857 */ diag::ext_vla, -1,
  /* DiagArray858 */ diag::warn_void_pointer_to_enum_cast, -1,
  /* DiagArray859 */ diag::warn_void_pointer_to_int_cast, -1,
  /* DiagArray860 */ diag::ext_typecheck_indirection_through_void_pointer, -1,
  /* DiagArray862 */ diag::warn_wasm_dynamic_exception_spec_ignored, -1,
  /* DiagArray863 */ diag::warn_weak_template_vtable, -1,
  /* DiagArray864 */ diag::warn_weak_vtable, -1,
  /* DiagArray865 */ diag::ext_deprecated_string_literal_conversion, -1,
  /* DiagArray867 */ diag::warn_xor_used_as_pow, diag::warn_xor_used_as_pow_base, diag::warn_xor_used_as_pow_base_extra, -1,
  /* DiagArray868 */ diag::warn_zero_as_null_pointer_constant, -1,
  /* DiagArray869 */ diag::ext_typecheck_zero_array_size, -1,
};

static const int16_t DiagSubGroups[] = {
  /* Empty */ -1,
  /* DiagSubGroup0 */ 261, -1,
  /* DiagSubGroup4 */ 15, 261, -1,
  /* DiagSubGroup11 */ 606, 727, 753, -1,
  /* DiagSubGroup15 */ 490, 594, 740, 741, 461, -1,
  /* DiagSubGroup24 */ 187, -1,
  /* DiagSubGroup26 */ 33, 32, 29, -1,
  /* DiagSubGroup31 */ 28, -1,
  /* DiagSubGroup37 */ 38, -1,
  /* DiagSubGroup46 */ 341, 169, -1,
  /* DiagSubGroup49 */ 798, 334, -1,
  /* DiagSubGroup59 */ 90, 114, 307, -1,
  /* DiagSubGroup60 */ 117, -1,
  /* DiagSubGroup68 */ 606, 779, -1,
  /* DiagSubGroup69 */ 68, -1,
  /* DiagSubGroup78 */ 81, -1,
  /* DiagSubGroup79 */ 85, -1,
  /* DiagSubGroup80 */ 89, -1,
  /* DiagSubGroup81 */ 89, 84, 82, 113, 111, 109, -1,
  /* DiagSubGroup83 */ 81, 115, 112, 110, -1,
  /* DiagSubGroup85 */ 86, 87, 88, -1,
  /* DiagSubGroup91 */ 111, 109, -1,
  /* DiagSubGroup92 */ 91, 112, 110, -1,
  /* DiagSubGroup93 */ 90, -1,
  /* DiagSubGroup94 */ 204, 200, 95, 109, -1,
  /* DiagSubGroup96 */ 94, 110, -1,
  /* DiagSubGroup98 */ 93, -1,
  /* DiagSubGroup99 */ 94, -1,
  /* DiagSubGroup100 */ 95, -1,
  /* DiagSubGroup101 */ 97, -1,
  /* DiagSubGroup103 */ 102, -1,
  /* DiagSubGroup105 */ 104, -1,
  /* DiagSubGroup106 */ 102, -1,
  /* DiagSubGroup107 */ 103, -1,
  /* DiagSubGroup108 */ 105, -1,
  /* DiagSubGroup110 */ 109, -1,
  /* DiagSubGroup112 */ 111, -1,
  /* DiagSubGroup115 */ 113, 114, -1,
  /* DiagSubGroup116 */ 119, 121, 113, 111, 109, -1,
  /* DiagSubGroup120 */ 116, 117, 118, 115, 112, 110, -1,
  /* DiagSubGroup125 */ 104, -1,
  /* DiagSubGroup126 */ 125, -1,
  /* DiagSubGroup128 */ 144, -1,
  /* DiagSubGroup138 */ 508, -1,
  /* DiagSubGroup142 */ 141, -1,
  /* DiagSubGroup146 */ 147, 148, -1,
  /* DiagSubGroup153 */ 62, 532, -1,
  /* DiagSubGroup158 */ 68, 153, 247, 63, 272, 689, 386, 351, 348, 413, 505, 521, 542, 691, 729, -1,
  /* DiagSubGroup159 */ 521, -1,
  /* DiagSubGroup160 */ 161, -1,
  /* DiagSubGroup163 */ 2, -1,
  /* DiagSubGroup170 */ 172, 174, 173, 657, -1,
  /* DiagSubGroup185 */ 184, 182, -1,
  /* DiagSubGroup186 */ 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 200, 204, 205, 206, 207, -1,
  /* DiagSubGroup202 */ 203, -1,
  /* DiagSubGroup207 */ 82, -1,
  /* DiagSubGroup213 */ 214, -1,
  /* DiagSubGroup218 */ 220, 219, -1,
  /* DiagSubGroup221 */ 222, -1,
  /* DiagSubGroup233 */ 194, -1,
  /* DiagSubGroup234 */ 510, -1,
  /* DiagSubGroup243 */ 265, -1,
  /* DiagSubGroup244 */ 246, 195, -1,
  /* DiagSubGroup245 */ 196, -1,
  /* DiagSubGroup247 */ 248, 249, 245, -1,
  /* DiagSubGroup248 */ 197, -1,
  /* DiagSubGroup249 */ 198, -1,
  /* DiagSubGroup261 */ 191, 470, 339, 379, 672, 473, 690, 838, 523, 240, 728, 297, -1,
  /* DiagSubGroup263 */ 118, 86, -1,
  /* DiagSubGroup264 */ 240, -1,
  /* DiagSubGroup272 */ 274, 275, -1,
  /* DiagSubGroup277 */ 278, 287, 511, 284, 286, 280, 279, -1,
  /* DiagSubGroup288 */ 282, 284, 286, -1,
  /* DiagSubGroup302 */ 303, 304, 306, 307, 308, 309, 310, 311, 312, 313, 314, 857, 315, 316, 317, 318, 319, 321, 642, 322, 323, 324, 325, 326, 327, 869, 328, 329, -1,
  /* DiagSubGroup338 */ 336, 337, -1,
  /* DiagSubGroup340 */ 349, 350, -1,
  /* DiagSubGroup345 */ 346, -1,
  /* DiagSubGroup348 */ 352, 565, -1,
  /* DiagSubGroup351 */ 566, -1,
  /* DiagSubGroup352 */ 342, -1,
  /* DiagSubGroup364 */ 365, 361, -1,
  /* DiagSubGroup370 */ 372, 507, -1,
  /* DiagSubGroup376 */ 200, -1,
  /* DiagSubGroup387 */ 386, -1,
  /* DiagSubGroup389 */ 390, -1,
  /* DiagSubGroup392 */ 335, -1,
  /* DiagSubGroup415 */ 119, -1,
  /* DiagSubGroup418 */ 88, -1,
  /* DiagSubGroup419 */ 276, 636, -1,
  /* DiagSubGroup430 */ 433, 438, 450, 436, 446, 454, 458, 442, 459, 451, 452, 457, 444, 441, 437, 455, 453, 440, 448, 447, 445, 432, 435, 460, 431, 434, 439, 373, -1,
  /* DiagSubGroup455 */ 456, -1,
  /* DiagSubGroup490 */ 135, 141, 185, 277, 276, 291, 340, 377, 388, 465, 466, 491, 494, 638, 649, 660, 668, 671, 695, 696, 731, 747, 769, 794, 801, 824, 861, 547, 536, 538, 587, 623, 131, 259, 848, -1,
  /* DiagSubGroup491 */ 604, 644, 658, 671, -1,
  /* DiagSubGroup492 */ 450, -1,
  /* DiagSubGroup496 */ 89, -1,
  /* DiagSubGroup502 */ 95, -1,
  /* DiagSubGroup504 */ 690, 158, 414, -1,
  /* DiagSubGroup507 */ 506, -1,
  /* DiagSubGroup525 */ 526, -1,
  /* DiagSubGroup535 */ 561, -1,
  /* DiagSubGroup541 */ 567, -1,
  /* DiagSubGroup561 */ 562, -1,
  /* DiagSubGroup564 */ 566, 565, 532, 751, -1,
  /* DiagSubGroup574 */ 703, 575, 576, 578, 577, -1,
  /* DiagSubGroup578 */ 577, -1,
  /* DiagSubGroup588 */ 379, -1,
  /* DiagSubGroup594 */ 417, 416, 65, 66, 686, 586, 595, 171, -1,
  /* DiagSubGroup596 */ 788, -1,
  /* DiagSubGroup602 */ 122, 86, 88, 90, 104, 271, 304, 306, 307, 308, 309, 310, 311, 313, 314, 315, 316, 318, 319, 321, 322, 323, 326, 328, 329, 408, 418, 433, 434, 436, 439, 441, 446, 447, 453, 585, 857, 869, 356, 237, 241, 528, 268, 783, 656, 145, 497, 179, 223, 410, -1,
  /* DiagSubGroup610 */ 858, -1,
  /* DiagSubGroup611 */ 610, 859, -1,
  /* DiagSubGroup618 */ 619, -1,
  /* DiagSubGroup621 */ 801, 338, 616, 618, -1,
  /* DiagSubGroup636 */ 638, 637, -1,
  /* DiagSubGroup646 */ 204, -1,
  /* DiagSubGroup649 */ 650, 651, -1,
  /* DiagSubGroup655 */ 84, -1,
  /* DiagSubGroup660 */ 661, -1,
  /* DiagSubGroup666 */ 667, -1,
  /* DiagSubGroup668 */ 670, 669, -1,
  /* DiagSubGroup674 */ 812, -1,
  /* DiagSubGroup676 */ 680, 681, -1,
  /* DiagSubGroup677 */ 676, 679, 682, 678, -1,
  /* DiagSubGroup679 */ 680, -1,
  /* DiagSubGroup707 */ 324, -1,
  /* DiagSubGroup724 */ 614, -1,
  /* DiagSubGroup738 */ 699, 232, 516, 427, 737, -1,
  /* DiagSubGroup747 */ 748, 753, 752, 746, 755, 751, -1,
  /* DiagSubGroup748 */ 750, -1,
  /* DiagSubGroup749 */ 770, 758, -1,
  /* DiagSubGroup761 */ 763, 762, 766, 767, -1,
  /* DiagSubGroup770 */ 754, 757, 756, -1,
  /* DiagSubGroup787 */ 615, -1,
  /* DiagSubGroup788 */ 789, -1,
  /* DiagSubGroup794 */ 702, 711, 795, -1,
  /* DiagSubGroup804 */ 121, -1,
  /* DiagSubGroup807 */ 810, -1,
  /* DiagSubGroup808 */ 807, 809, 811, -1,
  /* DiagSubGroup824 */ 825, 830, 832, 839, 833, 834, 843, 844, 840, -1,
  /* DiagSubGroup830 */ 805, -1,
  /* DiagSubGroup835 */ 834, -1,
  /* DiagSubGroup837 */ 806, -1,
  /* DiagSubGroup842 */ 805, -1,
  /* DiagSubGroup843 */ 827, 841, 787, -1,
  /* DiagSubGroup844 */ 828, -1,
  /* DiagSubGroup853 */ 852, -1,
  /* DiagSubGroup856 */ 857, -1,
  /* DiagSubGroup859 */ 858, -1,
  /* DiagSubGroup865 */ 207, -1,
  /* DiagSubGroup866 */ 865, -1,
};

static const char DiagGroupNames[] = {
    "\000\020#pragma-messages\t#warnings\020CFString-literal\003CL4\032Indep"
    "endentClass-attribute\022NSObject-attribute\003abi\016absolute-value\024"
    "abstract-final-class\023abstract-vbase-init\007address\030address-of-pa"
    "cked-member\024address-of-temporary\020aggregate-return\003all\006alloc"
    "a\031alloca-with-align-alignof\020ambiguous-delete\022ambiguous-ellipsi"
    "s\017ambiguous-macro\031ambiguous-member-template\033ambiguous-reversed"
    "-operator\034analyzer-incompatible-plugin\031anon-enum-enum-conversion\025"
    "anonymous-pack-parens\003arc%arc-bridge-casts-disallowed-in-nonarc\036a"
    "rc-maybe-repeated-use-of-weak\025arc-non-pod-memaccess\031arc-performSe"
    "lector-leaks\030arc-repeated-use-of-weak\021arc-retain-cycles\032arc-un"
    "safe-retained-assign\026argument-outside-range\014array-bounds\037array"
    "-bounds-pointer-arithmetic\003asm\022asm-operand-widths\013assign-enum\006"
    "assume\013at-protocol\034atimport-in-framework-header\020atomic-alignme"
    "nt\027atomic-implicit-seq-cst\026atomic-memory-ordering\021atomic-prope"
    "rties*atomic-property-with-user-defined-accessor\035attribute-packed-fo"
    "r-bitfield\nattributes\033auto-disable-vptr-sanitizer\013auto-import\022"
    "auto-storage-class\013auto-var-id\014availability\030avr-rtlib-linking-"
    "quirks\016backend-plugin\030backslash-newline-escape\021bad-function-ca"
    "st\016binary-literal\026bind-to-temporary-copy\024binding-in-condition\034"
    "bitfield-constant-conversion\030bitfield-enum-conversion\016bitfield-wi"
    "dth\037bitwise-conditional-parentheses\026bitwise-op-parentheses\033blo"
    "ck-capture-autoreleasing\017bool-conversion\020bool-conversions\016bool"
    "-operation\022braced-scalar-init\013bridge-cast builtin-assume-aligned-"
    "alignment\027builtin-macro-redefined\027builtin-memcpy-chk-size\027buil"
    "tin-requires-header\nc++-compat\014c++0x-compat\020c++0x-extensions\017"
    "c++0x-narrowing\014c++11-compat(c++11-compat-deprecated-writable-string"
    "s\025c++11-compat-pedantic*c++11-compat-reserved-user-defined-literal\020"
    "c++11-extensions\020c++11-extra-semi\026c++11-inline-namespace\017c++11"
    "-long-long\017c++11-narrowing\024c++14-binary-literal\014c++14-compat\025"
    "c++14-compat-pedantic\020c++14-extensions\014c++17-compat\025c++17-comp"
    "at-mangling\025c++17-compat-pedantic\020c++17-extensions\020c++1y-exten"
    "sions\014c++1z-compat\025c++1z-compat-mangling\020c++1z-extensions\014c"
    "++20-compat\025c++20-compat-pedantic\020c++20-designator\020c++20-exten"
    "sions\014c++2a-compat\025c++2a-compat-pedantic\020c++2a-extensions\036c"
    "++98-c++11-c++14-c++17-compat'c++98-c++11-c++14-c++17-compat-pedantic\030"
    "c++98-c++11-c++14-compat!c++98-c++11-c++14-compat-pedantic\022c++98-c++"
    "11-compat!c++98-c++11-compat-binary-literal\033c++98-c++11-compat-pedan"
    "tic\014c++98-compat#c++98-compat-bind-to-temporary-copy\027c++98-compat"
    "-extra-semi%c++98-compat-local-type-template-args\025c++98-compat-pedan"
    "tic'c++98-compat-unnamed-type-template-args\016c11-extensions\016c2x-ex"
    "tensions\nc99-compat\016c99-designator\016c99-extensions#call-to-pure-v"
    "irtual-from-ctor-dtor\025called-once-parameter\ncast-align\027cast-call"
    "ing-convention\020cast-of-sel-type\tcast-qual\023cast-qual-unrelated\nc"
    "har-align\017char-subscripts\014clang-cl-pch\020class-conversion\015cla"
    "ss-varargs\017cmse-union-leak\005comma\007comment\010comments\036compar"
    "e-distinct-pointer-types\022completion-handler\026complex-component-ini"
    "t\024compound-token-split\035compound-token-split-by-macro\035compound-"
    "token-split-by-space\022concepts-ts-compat\031conditional-type-mismatch"
    "\031conditional-uninitialized\015config-macros\023constant-conversion\022"
    "constant-evaluated\030constant-logical-operand\023constexpr-not-const\010"
    "consumed\nconversion\017conversion-null\tcoroutine%coroutine-missing-un"
    "handled-exception\026covered-switch-default\003cpp\030cstring-format-di"
    "rective\026ctad-maybe-unsupported\021ctor-dtor-privacy\003ctu\013cuda-c"
    "ompat\030custom-atomic-properties\010dangling\015dangling-else\016dangl"
    "ing-field\014dangling-gsl\031dangling-initializer-list\023darwin-sdk-se"
    "ttings\tdate-time\023dealloc-in-category\035debug-compression-unavailab"
    "le\033declaration-after-statement\032defaulted-function-deleted\026dele"
    "gating-ctor-cycles delete-abstract-non-virtual-dtor\021delete-incomplet"
    "e$delete-non-abstract-non-virtual-dtor\027delete-non-virtual-dtor\ndepr"
    "ecated$deprecated-anon-enum-enum-conversion\030deprecated-array-compare"
    "\025deprecated-attributes\032deprecated-comma-subscript\017deprecated-c"
    "opy\024deprecated-copy-dtor\027deprecated-declarations!deprecated-dynam"
    "ic-exception-spec\027deprecated-enum-compare#deprecated-enum-compare-co"
    "nditional\037deprecated-enum-enum-conversion deprecated-enum-float-conv"
    "ersion\032deprecated-implementations\031deprecated-increment-bool\031de"
    "precated-objc-isa-usage%deprecated-objc-pointer-introspection5deprecate"
    "d-objc-pointer-introspection-performSelector\023deprecated-register\027"
    "deprecated-this-capture\023deprecated-volatile\033deprecated-writable-s"
    "trings\022direct-ivar-access\030disabled-macro-expansion\025disabled-op"
    "timization\014discard-qual\034distributed-object-modifiers\013div-by-ze"
    "ro\020division-by-zero\036dll-attribute-on-redeclaration%dllexport-expl"
    "icit-instantiation-decl\032dllimport-static-field-def\015documentation\035"
    "documentation-deprecated-sync\022documentation-html\026documentation-pe"
    "dantic\035documentation-unknown-command\036dollar-in-identifier-extensi"
    "on\020double-promotion\tdtor-name\014dtor-typedef\030duplicate-decl-spe"
    "cifier\016duplicate-enum\024duplicate-method-arg\026duplicate-method-ma"
    "tch\022duplicate-protocol\027dynamic-class-memaccess\026dynamic-excepti"
    "on-spec\006effc++\024elaborated-enum-base\025elaborated-enum-class\022e"
    "mbedded-directive\nempty-body\023empty-decomposition\017empty-init-stmt"
    "\026empty-translation-unit\013encode-type\014endif-labels\014enum-compa"
    "re\030enum-compare-conditional\023enum-compare-switch\017enum-conversio"
    "n\024enum-enum-conversion\025enum-float-conversion\016enum-too-large\ne"
    "xceptions\023excess-initializers\025exit-time-destructors\024expansion-"
    "to-defined\030explicit-initialize-call\027explicit-ownership-type\016ex"
    "port-unnamed\026export-using-directive\017extern-c-compat\022extern-ini"
    "tializer\005extra\023extra-qualification\nextra-semi\017extra-semi-stmt"
    "\014extra-tokens\010fallback\032final-dtor-non-final-class\024fixed-enu"
    "m-extension\024fixed-point-overflow\tflag-enum\031flexible-array-extens"
    "ions\020float-conversion\013float-equal\031float-overflow-conversion\025"
    "float-zero-conversion\021for-loop-analysis\006format\021format-extra-ar"
    "gs\030format-insufficient-args\030format-invalid-specifier\016format-no"
    "n-iso\021format-nonliteral\017format-pedantic\017format-security\025for"
    "mat-type-confusion\nformat-y2k\022format-zero-length\010format=2\016for"
    "tify-source\023four-char-constants\015frame-address\022frame-larger-tha"
    "n=%framework-include-private-from-public\023free-nonheap-object\036func"
    "tion-def-in-objc-container\025function-multiversion\014fuse-ld-path\015"
    "future-compat\ngcc-compat\023global-constructors\013global-isel\003gnu\026"
    "gnu-alignof-expression\024gnu-anonymous-struct\033gnu-array-member-pare"
    "n-init\015gnu-auto-type\022gnu-binary-literal\016gnu-case-range\023gnu-"
    "complex-integer gnu-compound-literal-initializer\037gnu-conditional-omi"
    "tted-operand\016gnu-designator\025gnu-empty-initializer\020gnu-empty-st"
    "ruct\036gnu-flexible-array-initializer\037gnu-flexible-array-union-memb"
    "er\024gnu-folding-constant\026gnu-imaginary-constant\020gnu-include-nex"
    "t\035gnu-inline-cpp-without-extern\022gnu-label-as-value\023gnu-redecla"
    "red-enum\030gnu-statement-expression\025gnu-static-float-init$gnu-strin"
    "g-literal-operator-template\016gnu-union-cast\"gnu-variable-sized-type-"
    "not-at-end\027gnu-zero-line-directive!gnu-zero-variadic-macro-arguments"
    "\014header-guard\016header-hygiene\010hip-only\025idiomatic-parentheses"
    "\022ignored-attributes\035ignored-optimization-argument\030ignored-prag"
    "ma-intrinsic\027ignored-pragma-optimize\017ignored-pragmas\022ignored-q"
    "ualifiers\010implicit\032implicit-atomic-properties#implicit-const-int-"
    "float-conversion*implicit-conversion-floating-point-to-bool implicit-ex"
    "ception-spec-mismatch\024implicit-fallthrough!implicit-fallthrough-per-"
    "function\037implicit-fixed-point-conversion\031implicit-float-conversio"
    "n\035implicit-function-declaration\014implicit-int\027implicit-int-conv"
    "ersion\035implicit-int-float-conversion\024implicit-retain-self\033impl"
    "icitly-unsigned-literal\006import&import-preprocessor-directive-pedanti"
    "c\021inaccessible-base\032include-next-absolute-path\033include-next-ou"
    "tside-header\033incompatible-exception-spec#incompatible-function-point"
    "er-types\"incompatible-library-redeclaration\026incompatible-ms-struct\032"
    "incompatible-pointer-types.incompatible-pointer-types-discards-qualifie"
    "rs\032incompatible-property-type\024incompatible-sysroot'incomplete-fra"
    "mework-module-declaration\031incomplete-implementation\021incomplete-mo"
    "dule\035incomplete-setjmp-declaration\023incomplete-umbrella\026inconsi"
    "stent-dllimport(inconsistent-missing-destructor-override\035inconsisten"
    "t-missing-override\016increment-bool\022infinite-recursion\tinit-self\025"
    "initializer-overrides\023injected-class-name\006inline\ninline-asm#inli"
    "ne-namespace-reopened-noninline\021inline-new-delete\"instantiation-aft"
    "er-specialization\016int-conversion\017int-conversions\023int-in-bool-c"
    "ontext\023int-to-pointer-cast\030int-to-void-pointer-cast\020integer-ov"
    "erflow\035invalid-command-line-argument\021invalid-constexpr\020invalid"
    "-iboutlet&invalid-initializer-from-system-header\035invalid-ios-deploym"
    "ent-target\030invalid-no-builtin-names\020invalid-noreturn\020invalid-o"
    "ffsetof invalid-or-nonexistent-directory\036invalid-partial-specializat"
    "ion\013invalid-pch\020invalid-pp-token\027invalid-source-encoding\023in"
    "valid-token-paste\020jump-seh-finally\016keyword-compat\015keyword-macr"
    "o\026knr-promoted-parameter\030language-extension-token\023large-by-val"
    "ue-copy\006liblto\022literal-conversion\015literal-range\030local-type-"
    "template-args\027logical-not-parentheses\026logical-op-parentheses\tlon"
    "g-long\015loop-analysis\017macro-redefined\004main\020main-return-type\027"
    "malformed-warning-check\036many-braces-around-scalar-init\nmax-tokens\021"
    "max-unsigned-zero\026memset-transposed-args\022memsize-comparison\021me"
    "thod-signatures\tmicrosoft\022microsoft-anon-tag\016microsoft-cast\021m"
    "icrosoft-charize\027microsoft-comment-paste\024microsoft-const-init\023"
    "microsoft-cpp-macro\"microsoft-default-arg-redefinition\031microsoft-dr"
    "ectve-section\025microsoft-end-of-file microsoft-enum-forward-reference"
    "\024microsoft-enum-value\030microsoft-exception-spec\020microsoft-exist"
    "s#microsoft-explicit-constructor-call\035microsoft-extra-qualification\024"
    "microsoft-fixed-enum\030microsoft-flexible-array\016microsoft-goto\033m"
    "icrosoft-inaccessible-base\021microsoft-include\033microsoft-mutable-re"
    "ference\031microsoft-pure-definition\032microsoft-redeclare-static\020m"
    "icrosoft-sealed\022microsoft-template\031microsoft-template-shadow micr"
    "osoft-union-member-reference\034microsoft-unqualified-friend\024microso"
    "ft-using-decl\032microsoft-void-pseudo-dtor\026misleading-indentation\025"
    "mismatched-new-delete\032mismatched-parameter-types\027mismatched-retur"
    "n-types\017mismatched-tags\016missing-braces\021missing-constinit\024mi"
    "ssing-declarations\026missing-exception-spec\032missing-field-initializ"
    "ers\030missing-format-attribute\024missing-include-dirs\032missing-meth"
    "od-return-type\020missing-noescape\020missing-noreturn\030missing-proto"
    "type-for-cc\022missing-prototypes\025missing-selector-name\017missing-s"
    "ysroot\035missing-variable-declarations\025misspelled-assumption\014mod"
    "ule-build\017module-conflict\033module-file-config-mismatch\025module-f"
    "ile-extension\015module-import\031module-import-in-extern-c\"modules-am"
    "biguous-internal-linkage\037modules-import-nested-redundant\004most\004"
    "move\014msvc-include\016msvc-not-found\tmultichar\023multiple-move-vbas"
    "e\tnarrowing\021nested-anon-types\016nested-externs\020new-returns-null"
    "\013newline-eof\007noderef\015noexcept-type\031non-c-typedef-for-linkag"
    "e\007non-gcc\033non-literal-null-conversion'non-modular-include-in-fram"
    "ework-module\035non-modular-include-in-module\017non-pod-varargs\032non"
    "-power-of-two-alignment\020non-virtual-dtor\007nonnull\025nonportable-c"
    "fstrings\030nonportable-include-path\037nonportable-system-include-path"
    "!nonportable-vector-initialization\024nontrivial-memaccess\023nsconsume"
    "d-mismatch\022nsreturns-mismatch\017null-arithmetic\016null-character\017"
    "null-conversion\020null-dereference\027null-pointer-arithmetic\013nulla"
    "bility\030nullability-completeness\"nullability-completeness-on-arrays\024"
    "nullability-declspec\025nullability-extension#nullability-inferred-on-n"
    "ested-type\036nullable-to-nonnull-conversion+objc-autosynthesis-propert"
    "y-ivar-name-match\035objc-bool-constant-conversion\013objc-boxing\027ob"
    "jc-circular-container\016objc-cocoa-api\034objc-designated-initializers"
    "\036objc-dictionary-duplicate-keys\023objc-flexible-array\037objc-forwa"
    "rd-class-redefinition\024objc-interface-ivars\024objc-literal-compare\027"
    "objc-literal-conversion\027objc-macro-redefinition\021objc-messaging-id"
    "\022objc-method-access\037objc-missing-property-synthesis\030objc-missi"
    "ng-super-calls\032objc-multiple-method-names\"objc-noncopy-retain-block"
    "-property\032objc-nonunified-exceptions#objc-property-assign-on-object-"
    "type\034objc-property-implementation\037objc-property-implicit-mismatch"
    "*objc-property-matches-cocoa-ownership-rule\032objc-property-no-attribu"
    "te\027objc-property-synthesis#objc-protocol-method-implementation objc-"
    "protocol-property-synthesis\030objc-protocol-qualifiers\"objc-readonly-"
    "with-setter-property\026objc-redundant-api-use\032objc-redundant-litera"
    "l-use\017objc-root-class\025objc-signed-char-bool/objc-signed-char-bool"
    "-implicit-float-conversion-objc-signed-char-bool-implicit-int-conversio"
    "n\023objc-string-compare\031objc-string-concatenation\034objc-unsafe-pe"
    "rform-selector\003odr\016old-style-cast\024old-style-definition\027open"
    "cl-unsupported-rgba\006openmp\016openmp-clauses\020openmp-loop-form\016"
    "openmp-mapping\015openmp-target\016option-ignored!ordered-compare-funct"
    "ion-pointers\027out-of-line-declaration\025out-of-scope-function\014ove"
    "r-aligned\010overflow\022overlength-strings\037overloaded-shift-op-pare"
    "ntheses\022overloaded-virtual\015override-init\017override-module\032ov"
    "erriding-method-mismatch\023overriding-t-option\006packed\006padded\013"
    "parentheses\024parentheses-equality\024partial-availability\004pass\015"
    "pass-analysis\013pass-failed\013pass-missed\015pch-date-time\010pedanti"
    "c\026pedantic-core-features\020pessimizing-move\015pointer-arith\027poi"
    "nter-bool-conversion\017pointer-compare\027pointer-integer-compare\014p"
    "ointer-sign\024pointer-to-enum-cast\023pointer-to-int-cast\025pointer-t"
    "ype-mismatch\031poison-system-directories\033potentially-direct-selecto"
    "r potentially-evaluated-expression\026pragma-clang-attribute\032pragma-"
    "once-outside-header\013pragma-pack\036pragma-pack-suspicious-include#pr"
    "agma-system-header-outside-header\007pragmas&predefined-identifier-outs"
    "ide-function\016private-extern\016private-header\016private-module\025p"
    "rofile-instr-missing\031profile-instr-out-of-date\030profile-instr-unpr"
    "ofiled\032property-access-dot-syntax\033property-attribute-mismatch\010"
    "protocol%protocol-property-synthesis-ambiguity\005psabi\032qualified-vo"
    "id-return-type\"quoted-include-in-framework-header\023range-loop-analys"
    "is\031range-loop-bind-reference\024range-loop-construct\032readonly-ibo"
    "utlet-property\015receiver-expr\026receiver-forward-class\027redeclared"
    "-class-member\017redundant-decls\016redundant-move\020redundant-parens\010"
    "register\026reinterpret-base-class\025remark-backend-plugin\007reorder\014"
    "reorder-ctor\021reorder-init-list\023requires-expression\030requires-su"
    "per-attribute\021reserved-id-macro\035reserved-user-defined-literal\031"
    "retained-language-linkage\024return-stack-address\017return-std-move\030"
    "return-std-move-in-c++11\013return-type\025return-type-c-linkage\020rew"
    "rite-not-bool\004rtti\020sanitize-address\007section\010selector\026sel"
    "ector-type-mismatch\013self-assign\021self-assign-field\026self-assign-"
    "overloaded\tself-move\034semicolon-before-method-body\010sentinel\016se"
    "quence-point\026serialized-diagnostics\006shadow\nshadow-all\014shadow-"
    "field\033shadow-field-in-constructor$shadow-field-in-constructor-modifi"
    "ed\013shadow-ivar\027shadow-uncaptured-local\024shift-count-negative\024"
    "shift-count-overflow\024shift-negative-value\024shift-op-parentheses\016"
    "shift-overflow\023shift-sign-overflow\020shorten-64-to-32\014sign-compa"
    "re\017sign-conversion\nsign-promo\024signed-enum-bitfield\025signed-uns"
    "igned-wchar\025sizeof-array-argument\022sizeof-array-decay\020sizeof-ar"
    "ray-div\022sizeof-pointer-div\030sizeof-pointer-memaccess\020slash-u-fi"
    "lename\014slh-asm-goto\027sometimes-uninitialized\022source-uses-openmp"
    "\013spir-compat\017stack-exhausted\017stack-protector\021static-float-i"
    "nit\020static-in-inline$static-inline-explicit-instantiation\026static-"
    "local-in-inline\020static-self-init\023stdlibcxx-not-found\017strict-al"
    "iasing\021strict-aliasing=0\021strict-aliasing=1\021strict-aliasing=2\017"
    "strict-overflow\021strict-overflow=0\021strict-overflow=1\021strict-ove"
    "rflow=2\021strict-overflow=3\021strict-overflow=4\021strict-overflow=5\""
    "strict-potentially-direct-selector\021strict-prototypes\025strict-selec"
    "tor-match\016string-compare\024string-concatenation\021string-conversio"
    "n\020string-plus-char\017string-plus-int\024strlcpy-strlcat-size\014str"
    "ncat-size\033suggest-destructor-override\020suggest-override\033super-c"
    "lass-method-mismatch\020suspicious-bzero\024suspicious-memaccess\024swi"
    "ft-name-attribute\006switch\013switch-bool\016switch-default\013switch-"
    "enum%sync-fetch-and-nand-semantics-changed\005synth\034tautological-bit"
    "wise-compare\024tautological-compare\035tautological-constant-compare&t"
    "autological-constant-in-range-compare*tautological-constant-out-of-rang"
    "e-compare\036tautological-objc-bool-compare\034tautological-overlap-com"
    "pare\034tautological-pointer-compare\037tautological-type-limit-compare"
    "\036tautological-undefined-compare'tautological-unsigned-enum-zero-comp"
    "are\"tautological-unsigned-zero-compare tautological-value-range-compar"
    "e\017tcb-enforcement$tentative-definition-incomplete-type\015thread-saf"
    "ety\026thread-safety-analysis\030thread-safety-attributes\022thread-saf"
    "ety-beta\026thread-safety-negative\025thread-safety-precise\027thread-s"
    "afety-reference\025thread-safety-verbose\ttrigraphs\013type-limits\013t"
    "ype-safety\024typedef-redefinition\020typename-missing\031unable-to-ope"
    "n-stats-file\030unavailable-declarations\023undeclared-selector\005unde"
    "f\014undef-prefix\031undefined-bool-conversion\027undefined-func-templa"
    "te\020undefined-inline\022undefined-internal\027undefined-internal-type"
    "\032undefined-reinterpret-cast\026undefined-var-template\035underaligne"
    "d-exception-object\026unevaluated-expression\026unguarded-availability\032"
    "unguarded-availability-new\007unicode\021unicode-homoglyph\022unicode-w"
    "hitespace\022unicode-zero-width\015uninitialized\035uninitialized-const"
    "-reference\020unknown-argument\022unknown-assumption\022unknown-attribu"
    "tes\024unknown-cuda-version\027unknown-escape-sequence\017unknown-pragm"
    "as\022unknown-sanitizers\026unknown-warning-option\032unnamed-type-temp"
    "late-args\035unneeded-internal-declaration\030unneeded-member-function\020"
    "unreachable-code\033unreachable-code-aggressive\026unreachable-code-bre"
    "ak\037unreachable-code-loop-increment\027unreachable-code-return\013uns"
    "equenced\017unsupported-abs\036unsupported-availability-guard\016unsupp"
    "orted-cb#unsupported-dll-base-class-template\036unsupported-floating-po"
    "int-opt\022unsupported-friend\021unsupported-gpopt\017unsupported-nan\026"
    "unsupported-target-opt\026unsupported-visibility\037unusable-partial-sp"
    "ecialization\006unused\017unused-argument\034unused-command-line-argume"
    "nt\021unused-comparison\025unused-const-variable\032unused-exception-pa"
    "rameter\017unused-function\032unused-getter-return-value\014unused-labe"
    "l\025unused-lambda-capture\024unused-local-typedef\025unused-local-type"
    "defs\015unused-macros\026unused-member-function\020unused-parameter\024"
    "unused-private-field\024unused-property-ivar\015unused-result\017unused"
    "-template\014unused-value\017unused-variable\026unused-volatile-lvalue\026"
    "used-but-marked-unused\025user-defined-literals\025user-defined-warning"
    "s\007varargs\017variadic-macros\015vec-elem-size\021vector-conversion\022"
    "vector-conversions\014vexing-parse\nvisibility\003vla\015vla-extension\031"
    "void-pointer-to-enum-cast\030void-pointer-to-int-cast\024void-ptr-deref"
    "erence\025volatile-register-var\023wasm-exception-spec\025weak-template"
    "-vtables\014weak-vtables\020writable-strings\015write-strings\017xor-us"
    "ed-as-pow\035zero-as-null-pointer-constant\021zero-length-array"};

#endif // GET_DIAG_ARRAYS


#ifdef GET_DIAG_TABLE
  { /*  */                                                      0, /* Empty */     0, /* DiagSubGroup0 */ 1 },
  { /* #pragma-messages */                                      1, /* DiagArray1 */ 1, /* Empty */         0 },
  { /* #warnings */                                             18, /* DiagArray2 */ 3, /* Empty */         0 },
  { /* CFString-literal */                                      28, /* DiagArray3 */ 5, /* Empty */         0 },
  { /* CL4 */                                                   45, /* Empty */     0, /* DiagSubGroup4 */ 3 },
  { /* IndependentClass-attribute */                            49, /* DiagArray5 */ 7, /* Empty */         0 },
  { /* NSObject-attribute */                                    76, /* DiagArray6 */ 10, /* Empty */         0 },
  { /* abi */                                                   95, /* Empty */     0, /* Empty */         0 },
  { /* absolute-value */                                        99, /* DiagArray8 */ 12, /* Empty */         0 },
  { /* abstract-final-class */                                  114, /* DiagArray9 */ 17, /* Empty */         0 },
  { /* abstract-vbase-init */                                   135, /* DiagArray10 */ 19, /* Empty */         0 },
  { /* address */                                               155, /* Empty */     0, /* DiagSubGroup11 */ 6 },
  { /* address-of-packed-member */                              163, /* DiagArray12 */ 21, /* Empty */         0 },
  { /* address-of-temporary */                                  188, /* DiagArray13 */ 23, /* Empty */         0 },
  { /* aggregate-return */                                      209, /* Empty */     0, /* Empty */         0 },
  { /* all */                                                   226, /* Empty */     0, /* DiagSubGroup15 */ 10 },
  { /* alloca */                                                230, /* DiagArray16 */ 25, /* Empty */         0 },
  { /* alloca-with-align-alignof */                             237, /* DiagArray17 */ 27, /* Empty */         0 },
  { /* ambiguous-delete */                                      263, /* DiagArray18 */ 29, /* Empty */         0 },
  { /* ambiguous-ellipsis */                                    280, /* DiagArray19 */ 31, /* Empty */         0 },
  { /* ambiguous-macro */                                       299, /* DiagArray20 */ 33, /* Empty */         0 },
  { /* ambiguous-member-template */                             315, /* DiagArray21 */ 35, /* Empty */         0 },
  { /* ambiguous-reversed-operator */                           341, /* DiagArray22 */ 37, /* Empty */         0 },
  { /* analyzer-incompatible-plugin */                          369, /* DiagArray23 */ 39, /* Empty */         0 },
  { /* anon-enum-enum-conversion */                             398, /* DiagArray24 */ 41, /* DiagSubGroup24 */ 16 },
  { /* anonymous-pack-parens */                                 424, /* DiagArray25 */ 43, /* Empty */         0 },
  { /* arc */                                                   446, /* Empty */     0, /* DiagSubGroup26 */ 18 },
  { /* arc-bridge-casts-disallowed-in-nonarc */                 450, /* DiagArray27 */ 45, /* Empty */         0 },
  { /* arc-maybe-repeated-use-of-weak */                        488, /* DiagArray28 */ 47, /* Empty */         0 },
  { /* arc-non-pod-memaccess */                                 519, /* DiagArray29 */ 49, /* Empty */         0 },
  { /* arc-performSelector-leaks */                             541, /* DiagArray30 */ 51, /* Empty */         0 },
  { /* arc-repeated-use-of-weak */                              567, /* DiagArray31 */ 53, /* DiagSubGroup31 */ 22 },
  { /* arc-retain-cycles */                                     592, /* DiagArray32 */ 55, /* Empty */         0 },
  { /* arc-unsafe-retained-assign */                            610, /* DiagArray33 */ 57, /* Empty */         0 },
  { /* argument-outside-range */                                637, /* DiagArray34 */ 61, /* Empty */         0 },
  { /* array-bounds */                                          660, /* DiagArray35 */ 63, /* Empty */         0 },
  { /* array-bounds-pointer-arithmetic */                       673, /* DiagArray36 */ 67, /* Empty */         0 },
  { /* asm */                                                   705, /* Empty */     0, /* DiagSubGroup37 */ 24 },
  { /* asm-operand-widths */                                    709, /* DiagArray38 */ 70, /* Empty */         0 },
  { /* assign-enum */                                           728, /* DiagArray39 */ 72, /* Empty */         0 },
  { /* assume */                                                740, /* DiagArray40 */ 74, /* Empty */         0 },
  { /* at-protocol */                                           747, /* Empty */     0, /* Empty */         0 },
  { /* atimport-in-framework-header */                          759, /* DiagArray42 */ 76, /* Empty */         0 },
  { /* atomic-alignment */                                      788, /* DiagArray43 */ 78, /* Empty */         0 },
  { /* atomic-implicit-seq-cst */                               805, /* DiagArray44 */ 81, /* Empty */         0 },
  { /* atomic-memory-ordering */                                829, /* DiagArray45 */ 83, /* Empty */         0 },
  { /* atomic-properties */                                     852, /* Empty */     0, /* DiagSubGroup46 */ 26 },
  { /* atomic-property-with-user-defined-accessor */            870, /* DiagArray47 */ 85, /* Empty */         0 },
  { /* attribute-packed-for-bitfield */                         913, /* DiagArray48 */ 87, /* Empty */         0 },
  { /* attributes */                                            943, /* Empty */     0, /* DiagSubGroup49 */ 29 },
  { /* auto-disable-vptr-sanitizer */                           954, /* DiagArray50 */ 89, /* Empty */         0 },
  { /* auto-import */                                           982, /* DiagArray51 */ 91, /* Empty */         0 },
  { /* auto-storage-class */                                    994, /* DiagArray52 */ 93, /* Empty */         0 },
  { /* auto-var-id */                                           1013, /* DiagArray53 */ 95, /* Empty */         0 },
  { /* availability */                                          1025, /* DiagArray54 */ 97, /* Empty */         0 },
  { /* avr-rtlib-linking-quirks */                              1038, /* DiagArray55 */ 107, /* Empty */         0 },
  { /* backend-plugin */                                        1063, /* DiagArray56 */ 114, /* Empty */         0 },
  { /* backslash-newline-escape */                              1078, /* DiagArray57 */ 116, /* Empty */         0 },
  { /* bad-function-cast */                                     1103, /* DiagArray58 */ 118, /* Empty */         0 },
  { /* binary-literal */                                        1121, /* Empty */     0, /* DiagSubGroup59 */ 32 },
  { /* bind-to-temporary-copy */                                1136, /* DiagArray60 */ 120, /* DiagSubGroup60 */ 36 },
  { /* binding-in-condition */                                  1159, /* DiagArray61 */ 123, /* Empty */         0 },
  { /* bitfield-constant-conversion */                          1180, /* DiagArray62 */ 125, /* Empty */         0 },
  { /* bitfield-enum-conversion */                              1209, /* DiagArray63 */ 127, /* Empty */         0 },
  { /* bitfield-width */                                        1234, /* DiagArray64 */ 131, /* Empty */         0 },
  { /* bitwise-conditional-parentheses */                       1249, /* DiagArray65 */ 133, /* Empty */         0 },
  { /* bitwise-op-parentheses */                                1281, /* DiagArray66 */ 135, /* Empty */         0 },
  { /* block-capture-autoreleasing */                           1304, /* DiagArray67 */ 137, /* Empty */         0 },
  { /* bool-conversion */                                       1332, /* DiagArray68 */ 139, /* DiagSubGroup68 */ 38 },
  { /* bool-conversions */                                      1348, /* Empty */     0, /* DiagSubGroup69 */ 41 },
  { /* bool-operation */                                        1365, /* DiagArray70 */ 141, /* Empty */         0 },
  { /* braced-scalar-init */                                    1380, /* DiagArray71 */ 143, /* Empty */         0 },
  { /* bridge-cast */                                           1399, /* DiagArray72 */ 145, /* Empty */         0 },
  { /* builtin-assume-aligned-alignment */                      1411, /* DiagArray73 */ 148, /* Empty */         0 },
  { /* builtin-macro-redefined */                               1444, /* DiagArray74 */ 150, /* Empty */         0 },
  { /* builtin-memcpy-chk-size */                               1468, /* DiagArray75 */ 153, /* Empty */         0 },
  { /* builtin-requires-header */                               1492, /* DiagArray76 */ 155, /* Empty */         0 },
  { /* c++-compat */                                            1516, /* DiagArray77 */ 157, /* Empty */         0 },
  { /* c++0x-compat */                                          1527, /* Empty */     0, /* DiagSubGroup78 */ 43 },
  { /* c++0x-extensions */                                      1540, /* Empty */     0, /* DiagSubGroup79 */ 45 },
  { /* c++0x-narrowing */                                       1557, /* Empty */     0, /* DiagSubGroup80 */ 47 },
  { /* c++11-compat */                                          1573, /* DiagArray81 */ 159, /* DiagSubGroup81 */ 49 },
  { /* c++11-compat-deprecated-writable-strings */              1586, /* DiagArray82 */ 170, /* Empty */         0 },
  { /* c++11-compat-pedantic */                                 1627, /* Empty */     0, /* DiagSubGroup83 */ 56 },
  { /* c++11-compat-reserved-user-defined-literal */            1649, /* DiagArray84 */ 172, /* Empty */         0 },
  { /* c++11-extensions */                                      1692, /* DiagArray85 */ 174, /* DiagSubGroup85 */ 61 },
  { /* c++11-extra-semi */                                      1709, /* DiagArray86 */ 200, /* Empty */         0 },
  { /* c++11-inline-namespace */                                1726, /* DiagArray87 */ 202, /* Empty */         0 },
  { /* c++11-long-long */                                       1749, /* DiagArray88 */ 204, /* Empty */         0 },
  { /* c++11-narrowing */                                       1765, /* DiagArray89 */ 206, /* Empty */         0 },
  { /* c++14-binary-literal */                                  1781, /* DiagArray90 */ 214, /* Empty */         0 },
  { /* c++14-compat */                                          1802, /* Empty */     0, /* DiagSubGroup91 */ 65 },
  { /* c++14-compat-pedantic */                                 1815, /* Empty */     0, /* DiagSubGroup92 */ 68 },
  { /* c++14-extensions */                                      1837, /* DiagArray93 */ 216, /* DiagSubGroup93 */ 72 },
  { /* c++17-compat */                                          1854, /* Empty */     0, /* DiagSubGroup94 */ 74 },
  { /* c++17-compat-mangling */                                 1867, /* DiagArray95 */ 225, /* Empty */         0 },
  { /* c++17-compat-pedantic */                                 1889, /* Empty */     0, /* DiagSubGroup96 */ 79 },
  { /* c++17-extensions */                                      1911, /* DiagArray97 */ 227, /* Empty */         0 },
  { /* c++1y-extensions */                                      1928, /* Empty */     0, /* DiagSubGroup98 */ 82 },
  { /* c++1z-compat */                                          1945, /* Empty */     0, /* DiagSubGroup99 */ 84 },
  { /* c++1z-compat-mangling */                                 1958, /* Empty */     0, /* DiagSubGroup100 */ 86 },
  { /* c++1z-extensions */                                      1980, /* Empty */     0, /* DiagSubGroup101 */ 88 },
  { /* c++20-compat */                                          1997, /* DiagArray102 */ 246, /* Empty */         0 },
  { /* c++20-compat-pedantic */                                 2010, /* Empty */     0, /* DiagSubGroup103 */ 90 },
  { /* c++20-designator */                                      2032, /* DiagArray104 */ 254, /* Empty */         0 },
  { /* c++20-extensions */                                      2049, /* DiagArray105 */ 256, /* DiagSubGroup105 */ 92 },
  { /* c++2a-compat */                                          2066, /* Empty */     0, /* DiagSubGroup106 */ 94 },
  { /* c++2a-compat-pedantic */                                 2079, /* Empty */     0, /* DiagSubGroup107 */ 96 },
  { /* c++2a-extensions */                                      2101, /* Empty */     0, /* DiagSubGroup108 */ 98 },
  { /* c++98-c++11-c++14-c++17-compat */                        2118, /* DiagArray109 */ 274, /* Empty */         0 },
  { /* c++98-c++11-c++14-c++17-compat-pedantic */               2149, /* DiagArray110 */ 296, /* DiagSubGroup110 */ 100 },
  { /* c++98-c++11-c++14-compat */                              2189, /* DiagArray111 */ 299, /* Empty */         0 },
  { /* c++98-c++11-c++14-compat-pedantic */                     2214, /* DiagArray112 */ 317, /* DiagSubGroup112 */ 102 },
  { /* c++98-c++11-compat */                                    2248, /* DiagArray113 */ 320, /* Empty */         0 },
  { /* c++98-c++11-compat-binary-literal */                     2267, /* DiagArray114 */ 332, /* Empty */         0 },
  { /* c++98-c++11-compat-pedantic */                           2301, /* Empty */     0, /* DiagSubGroup115 */ 104 },
  { /* c++98-compat */                                          2329, /* DiagArray116 */ 334, /* DiagSubGroup116 */ 107 },
  { /* c++98-compat-bind-to-temporary-copy */                   2342, /* DiagArray117 */ 395, /* Empty */         0 },
  { /* c++98-compat-extra-semi */                               2378, /* DiagArray118 */ 397, /* Empty */         0 },
  { /* c++98-compat-local-type-template-args */                 2402, /* DiagArray119 */ 399, /* Empty */         0 },
  { /* c++98-compat-pedantic */                                 2440, /* DiagArray120 */ 401, /* DiagSubGroup120 */ 113 },
  { /* c++98-compat-unnamed-type-template-args */               2462, /* DiagArray121 */ 411, /* Empty */         0 },
  { /* c11-extensions */                                        2502, /* DiagArray122 */ 413, /* Empty */         0 },
  { /* c2x-extensions */                                        2517, /* DiagArray123 */ 418, /* Empty */         0 },
  { /* c99-compat */                                            2532, /* DiagArray124 */ 420, /* Empty */         0 },
  { /* c99-designator */                                        2543, /* DiagArray125 */ 424, /* DiagSubGroup125 */ 120 },
  { /* c99-extensions */                                        2558, /* DiagArray126 */ 429, /* DiagSubGroup126 */ 122 },
  { /* call-to-pure-virtual-from-ctor-dtor */                   2573, /* DiagArray127 */ 440, /* Empty */         0 },
  { /* called-once-parameter */                                 2609, /* DiagArray128 */ 442, /* DiagSubGroup128 */ 124 },
  { /* cast-align */                                            2631, /* DiagArray129 */ 446, /* Empty */         0 },
  { /* cast-calling-convention */                               2642, /* DiagArray130 */ 448, /* Empty */         0 },
  { /* cast-of-sel-type */                                      2666, /* DiagArray131 */ 450, /* Empty */         0 },
  { /* cast-qual */                                             2683, /* DiagArray132 */ 452, /* Empty */         0 },
  { /* cast-qual-unrelated */                                   2693, /* DiagArray133 */ 455, /* Empty */         0 },
  { /* char-align */                                            2713, /* Empty */     0, /* Empty */         0 },
  { /* char-subscripts */                                       2724, /* DiagArray135 */ 457, /* Empty */         0 },
  { /* clang-cl-pch */                                          2740, /* DiagArray136 */ 460, /* Empty */         0 },
  { /* class-conversion */                                      2753, /* DiagArray137 */ 465, /* Empty */         0 },
  { /* class-varargs */                                         2770, /* DiagArray138 */ 469, /* DiagSubGroup138 */ 126 },
  { /* cmse-union-leak */                                       2784, /* DiagArray139 */ 471, /* Empty */         0 },
  { /* comma */                                                 2800, /* DiagArray140 */ 473, /* Empty */         0 },
  { /* comment */                                               2806, /* DiagArray141 */ 475, /* Empty */         0 },
  { /* comments */                                              2814, /* Empty */     0, /* DiagSubGroup142 */ 128 },
  { /* compare-distinct-pointer-types */                        2823, /* DiagArray143 */ 480, /* Empty */         0 },
  { /* completion-handler */                                    2854, /* DiagArray144 */ 482, /* Empty */         0 },
  { /* complex-component-init */                                2873, /* DiagArray145 */ 486, /* Empty */         0 },
  { /* compound-token-split */                                  2896, /* Empty */     0, /* DiagSubGroup146 */ 130 },
  { /* compound-token-split-by-macro */                         2917, /* DiagArray147 */ 488, /* Empty */         0 },
  { /* compound-token-split-by-space */                         2947, /* DiagArray148 */ 490, /* Empty */         0 },
  { /* concepts-ts-compat */                                    2977, /* DiagArray149 */ 492, /* Empty */         0 },
  { /* conditional-type-mismatch */                             2996, /* DiagArray150 */ 494, /* Empty */         0 },
  { /* conditional-uninitialized */                             3022, /* DiagArray151 */ 496, /* Empty */         0 },
  { /* config-macros */                                         3048, /* DiagArray152 */ 498, /* Empty */         0 },
  { /* constant-conversion */                                   3062, /* DiagArray153 */ 500, /* DiagSubGroup153 */ 133 },
  { /* constant-evaluated */                                    3082, /* DiagArray154 */ 502, /* Empty */         0 },
  { /* constant-logical-operand */                              3101, /* DiagArray155 */ 504, /* Empty */         0 },
  { /* constexpr-not-const */                                   3126, /* DiagArray156 */ 506, /* Empty */         0 },
  { /* consumed */                                              3146, /* DiagArray157 */ 508, /* Empty */         0 },
  { /* conversion */                                            3155, /* DiagArray158 */ 517, /* DiagSubGroup158 */ 136 },
  { /* conversion-null */                                       3166, /* Empty */     0, /* DiagSubGroup159 */ 152 },
  { /* coroutine */                                             3182, /* DiagArray160 */ 523, /* DiagSubGroup160 */ 154 },
  { /* coroutine-missing-unhandled-exception */                 3192, /* DiagArray161 */ 525, /* Empty */         0 },
  { /* covered-switch-default */                                3230, /* DiagArray162 */ 527, /* Empty */         0 },
  { /* cpp */                                                   3253, /* Empty */     0, /* DiagSubGroup163 */ 156 },
  { /* cstring-format-directive */                              3257, /* DiagArray164 */ 529, /* Empty */         0 },
  { /* ctad-maybe-unsupported */                                3282, /* DiagArray165 */ 531, /* Empty */         0 },
  { /* ctor-dtor-privacy */                                     3305, /* Empty */     0, /* Empty */         0 },
  { /* ctu */                                                   3323, /* DiagArray167 */ 533, /* Empty */         0 },
  { /* cuda-compat */                                           3327, /* DiagArray168 */ 535, /* Empty */         0 },
  { /* custom-atomic-properties */                              3339, /* DiagArray169 */ 541, /* Empty */         0 },
  { /* dangling */                                              3364, /* DiagArray170 */ 543, /* DiagSubGroup170 */ 158 },
  { /* dangling-else */                                         3373, /* DiagArray171 */ 546, /* Empty */         0 },
  { /* dangling-field */                                        3387, /* DiagArray172 */ 548, /* Empty */         0 },
  { /* dangling-gsl */                                          3402, /* DiagArray173 */ 553, /* Empty */         0 },
  { /* dangling-initializer-list */                             3415, /* DiagArray174 */ 556, /* Empty */         0 },
  { /* darwin-sdk-settings */                                   3441, /* DiagArray175 */ 558, /* Empty */         0 },
  { /* date-time */                                             3461, /* DiagArray176 */ 560, /* Empty */         0 },
  { /* dealloc-in-category */                                   3471, /* DiagArray177 */ 562, /* Empty */         0 },
  { /* debug-compression-unavailable */                         3491, /* DiagArray178 */ 564, /* Empty */         0 },
  { /* declaration-after-statement */                           3521, /* DiagArray179 */ 566, /* Empty */         0 },
  { /* defaulted-function-deleted */                            3549, /* DiagArray180 */ 568, /* Empty */         0 },
  { /* delegating-ctor-cycles */                                3576, /* DiagArray181 */ 571, /* Empty */         0 },
  { /* delete-abstract-non-virtual-dtor */                      3599, /* DiagArray182 */ 573, /* Empty */         0 },
  { /* delete-incomplete */                                     3632, /* DiagArray183 */ 575, /* Empty */         0 },
  { /* delete-non-abstract-non-virtual-dtor */                  3650, /* DiagArray184 */ 578, /* Empty */         0 },
  { /* delete-non-virtual-dtor */                               3687, /* Empty */     0, /* DiagSubGroup185 */ 163 },
  { /* deprecated */                                            3711, /* DiagArray186 */ 580, /* DiagSubGroup186 */ 166 },
  { /* deprecated-anon-enum-enum-conversion */                  3722, /* DiagArray187 */ 589, /* Empty */         0 },
  { /* deprecated-array-compare */                              3759, /* DiagArray188 */ 591, /* Empty */         0 },
  { /* deprecated-attributes */                                 3784, /* DiagArray189 */ 593, /* Empty */         0 },
  { /* deprecated-comma-subscript */                            3806, /* DiagArray190 */ 595, /* Empty */         0 },
  { /* deprecated-copy */                                       3833, /* DiagArray191 */ 597, /* Empty */         0 },
  { /* deprecated-copy-dtor */                                  3849, /* DiagArray192 */ 599, /* Empty */         0 },
  { /* deprecated-declarations */                               3870, /* DiagArray193 */ 601, /* Empty */         0 },
  { /* deprecated-dynamic-exception-spec */                     3894, /* DiagArray194 */ 608, /* Empty */         0 },
  { /* deprecated-enum-compare */                               3928, /* DiagArray195 */ 610, /* Empty */         0 },
  { /* deprecated-enum-compare-conditional */                   3952, /* DiagArray196 */ 612, /* Empty */         0 },
  { /* deprecated-enum-enum-conversion */                       3988, /* DiagArray197 */ 614, /* Empty */         0 },
  { /* deprecated-enum-float-conversion */                      4020, /* DiagArray198 */ 616, /* Empty */         0 },
  { /* deprecated-implementations */                            4053, /* DiagArray199 */ 618, /* Empty */         0 },
  { /* deprecated-increment-bool */                             4080, /* DiagArray200 */ 621, /* Empty */         0 },
  { /* deprecated-objc-isa-usage */                             4106, /* DiagArray201 */ 623, /* Empty */         0 },
  { /* deprecated-objc-pointer-introspection */                 4132, /* DiagArray202 */ 626, /* DiagSubGroup202 */ 184 },
  { /* deprecated-objc-pointer-introspection-performSelector */ 4170, /* DiagArray203 */ 628, /* Empty */         0 },
  { /* deprecated-register */                                   4224, /* DiagArray204 */ 630, /* Empty */         0 },
  { /* deprecated-this-capture */                               4244, /* DiagArray205 */ 632, /* Empty */         0 },
  { /* deprecated-volatile */                                   4268, /* DiagArray206 */ 634, /* Empty */         0 },
  { /* deprecated-writable-strings */                           4288, /* Empty */     0, /* DiagSubGroup207 */ 186 },
  { /* direct-ivar-access */                                    4316, /* DiagArray208 */ 641, /* Empty */         0 },
  { /* disabled-macro-expansion */                              4335, /* DiagArray209 */ 643, /* Empty */         0 },
  { /* disabled-optimization */                                 4360, /* Empty */     0, /* Empty */         0 },
  { /* discard-qual */                                          4382, /* Empty */     0, /* Empty */         0 },
  { /* distributed-object-modifiers */                          4395, /* DiagArray212 */ 645, /* Empty */         0 },
  { /* div-by-zero */                                           4424, /* Empty */     0, /* DiagSubGroup213 */ 188 },
  { /* division-by-zero */                                      4436, /* DiagArray214 */ 648, /* Empty */         0 },
  { /* dll-attribute-on-redeclaration */                        4453, /* DiagArray215 */ 650, /* Empty */         0 },
  { /* dllexport-explicit-instantiation-decl */                 4484, /* DiagArray216 */ 652, /* Empty */         0 },
  { /* dllimport-static-field-def */                            4522, /* DiagArray217 */ 654, /* Empty */         0 },
  { /* documentation */                                         4549, /* DiagArray218 */ 656, /* DiagSubGroup218 */ 190 },
  { /* documentation-deprecated-sync */                         4563, /* DiagArray219 */ 676, /* Empty */         0 },
  { /* documentation-html */                                    4593, /* DiagArray220 */ 678, /* Empty */         0 },
  { /* documentation-pedantic */                                4612, /* DiagArray221 */ 683, /* DiagSubGroup221 */ 193 },
  { /* documentation-unknown-command */                         4635, /* DiagArray222 */ 685, /* Empty */         0 },
  { /* dollar-in-identifier-extension */                        4665, /* DiagArray223 */ 688, /* Empty */         0 },
  { /* double-promotion */                                      4696, /* DiagArray224 */ 690, /* Empty */         0 },
  { /* dtor-name */                                             4713, /* DiagArray225 */ 692, /* Empty */         0 },
  { /* dtor-typedef */                                          4723, /* DiagArray226 */ 696, /* Empty */         0 },
  { /* duplicate-decl-specifier */                              4736, /* DiagArray227 */ 698, /* Empty */         0 },
  { /* duplicate-enum */                                        4761, /* DiagArray228 */ 703, /* Empty */         0 },
  { /* duplicate-method-arg */                                  4776, /* DiagArray229 */ 705, /* Empty */         0 },
  { /* duplicate-method-match */                                4797, /* DiagArray230 */ 707, /* Empty */         0 },
  { /* duplicate-protocol */                                    4820, /* DiagArray231 */ 709, /* Empty */         0 },
  { /* dynamic-class-memaccess */                               4839, /* DiagArray232 */ 711, /* Empty */         0 },
  { /* dynamic-exception-spec */                                4863, /* DiagArray233 */ 713, /* DiagSubGroup233 */ 195 },
  { /* effc++ */                                                4886, /* Empty */     0, /* DiagSubGroup234 */ 197 },
  { /* elaborated-enum-base */                                  4893, /* DiagArray235 */ 715, /* Empty */         0 },
  { /* elaborated-enum-class */                                 4914, /* DiagArray236 */ 717, /* Empty */         0 },
  { /* embedded-directive */                                    4936, /* DiagArray237 */ 719, /* Empty */         0 },
  { /* empty-body */                                            4955, /* DiagArray238 */ 721, /* Empty */         0 },
  { /* empty-decomposition */                                   4966, /* DiagArray239 */ 727, /* Empty */         0 },
  { /* empty-init-stmt */                                       4986, /* DiagArray240 */ 729, /* Empty */         0 },
  { /* empty-translation-unit */                                5002, /* DiagArray241 */ 731, /* Empty */         0 },
  { /* encode-type */                                           5025, /* DiagArray242 */ 733, /* Empty */         0 },
  { /* endif-labels */                                          5037, /* Empty */     0, /* DiagSubGroup243 */ 199 },
  { /* enum-compare */                                          5050, /* DiagArray244 */ 735, /* DiagSubGroup244 */ 201 },
  { /* enum-compare-conditional */                              5063, /* DiagArray245 */ 737, /* DiagSubGroup245 */ 204 },
  { /* enum-compare-switch */                                   5088, /* DiagArray246 */ 739, /* Empty */         0 },
  { /* enum-conversion */                                       5108, /* DiagArray247 */ 741, /* DiagSubGroup247 */ 206 },
  { /* enum-enum-conversion */                                  5124, /* DiagArray248 */ 743, /* DiagSubGroup248 */ 210 },
  { /* enum-float-conversion */                                 5145, /* DiagArray249 */ 745, /* DiagSubGroup249 */ 212 },
  { /* enum-too-large */                                        5167, /* DiagArray250 */ 747, /* Empty */         0 },
  { /* exceptions */                                            5182, /* DiagArray251 */ 750, /* Empty */         0 },
  { /* excess-initializers */                                   5193, /* DiagArray252 */ 754, /* Empty */         0 },
  { /* exit-time-destructors */                                 5213, /* DiagArray253 */ 759, /* Empty */         0 },
  { /* expansion-to-defined */                                  5235, /* DiagArray254 */ 761, /* Empty */         0 },
  { /* explicit-initialize-call */                              5256, /* DiagArray255 */ 764, /* Empty */         0 },
  { /* explicit-ownership-type */                               5281, /* DiagArray256 */ 767, /* Empty */         0 },
  { /* export-unnamed */                                        5305, /* DiagArray257 */ 769, /* Empty */         0 },
  { /* export-using-directive */                                5320, /* DiagArray258 */ 772, /* Empty */         0 },
  { /* extern-c-compat */                                       5343, /* DiagArray259 */ 774, /* Empty */         0 },
  { /* extern-initializer */                                    5359, /* DiagArray260 */ 776, /* Empty */         0 },
  { /* extra */                                                 5378, /* DiagArray261 */ 778, /* DiagSubGroup261 */ 214 },
  { /* extra-qualification */                                   5384, /* DiagArray262 */ 780, /* Empty */         0 },
  { /* extra-semi */                                            5404, /* DiagArray263 */ 782, /* DiagSubGroup263 */ 227 },
  { /* extra-semi-stmt */                                       5415, /* DiagArray264 */ 785, /* DiagSubGroup264 */ 230 },
  { /* extra-tokens */                                          5431, /* DiagArray265 */ 787, /* Empty */         0 },
  { /* fallback */                                              5444, /* DiagArray266 */ 790, /* Empty */         0 },
  { /* final-dtor-non-final-class */                            5453, /* DiagArray267 */ 792, /* Empty */         0 },
  { /* fixed-enum-extension */                                  5480, /* DiagArray268 */ 794, /* Empty */         0 },
  { /* fixed-point-overflow */                                  5501, /* DiagArray269 */ 796, /* Empty */         0 },
  { /* flag-enum */                                             5522, /* DiagArray270 */ 798, /* Empty */         0 },
  { /* flexible-array-extensions */                             5532, /* DiagArray271 */ 800, /* Empty */         0 },
  { /* float-conversion */                                      5558, /* DiagArray272 */ 803, /* DiagSubGroup272 */ 232 },
  { /* float-equal */                                           5575, /* DiagArray273 */ 805, /* Empty */         0 },
  { /* float-overflow-conversion */                             5587, /* DiagArray274 */ 807, /* Empty */         0 },
  { /* float-zero-conversion */                                 5613, /* DiagArray275 */ 810, /* Empty */         0 },
  { /* for-loop-analysis */                                     5635, /* DiagArray276 */ 812, /* Empty */         0 },
  { /* format */                                                5653, /* DiagArray277 */ 815, /* DiagSubGroup277 */ 235 },
  { /* format-extra-args */                                     5660, /* DiagArray278 */ 841, /* Empty */         0 },
  { /* format-insufficient-args */                              5678, /* DiagArray279 */ 843, /* Empty */         0 },
  { /* format-invalid-specifier */                              5703, /* DiagArray280 */ 845, /* Empty */         0 },
  { /* format-non-iso */                                        5728, /* DiagArray281 */ 847, /* Empty */         0 },
  { /* format-nonliteral */                                     5743, /* DiagArray282 */ 851, /* Empty */         0 },
  { /* format-pedantic */                                       5761, /* DiagArray283 */ 853, /* Empty */         0 },
  { /* format-security */                                       5777, /* DiagArray284 */ 856, /* Empty */         0 },
  { /* format-type-confusion */                                 5793, /* DiagArray285 */ 858, /* Empty */         0 },
  { /* format-y2k */                                            5815, /* Empty */     0, /* Empty */         0 },
  { /* format-zero-length */                                    5826, /* DiagArray287 */ 860, /* Empty */         0 },
  { /* format=2 */                                              5845, /* Empty */     0, /* DiagSubGroup288 */ 243 },
  { /* fortify-source */                                        5854, /* DiagArray289 */ 862, /* Empty */         0 },
  { /* four-char-constants */                                   5869, /* DiagArray290 */ 866, /* Empty */         0 },
  { /* frame-address */                                         5889, /* DiagArray291 */ 868, /* Empty */         0 },
  { /* frame-larger-than= */                                    5903, /* DiagArray292 */ 870, /* Empty */         0 },
  { /* framework-include-private-from-public */                 5922, /* DiagArray293 */ 873, /* Empty */         0 },
  { /* free-nonheap-object */                                   5960, /* DiagArray294 */ 875, /* Empty */         0 },
  { /* function-def-in-objc-container */                        5980, /* DiagArray295 */ 877, /* Empty */         0 },
  { /* function-multiversion */                                 6011, /* DiagArray296 */ 879, /* Empty */         0 },
  { /* fuse-ld-path */                                          6033, /* DiagArray297 */ 882, /* Empty */         0 },
  { /* future-compat */                                         6046, /* Empty */     0, /* Empty */         0 },
  { /* gcc-compat */                                            6060, /* DiagArray299 */ 884, /* Empty */         0 },
  { /* global-constructors */                                   6071, /* DiagArray300 */ 895, /* Empty */         0 },
  { /* global-isel */                                           6091, /* DiagArray301 */ 898, /* Empty */         0 },
  { /* gnu */                                                   6103, /* Empty */     0, /* DiagSubGroup302 */ 247 },
  { /* gnu-alignof-expression */                                6107, /* DiagArray303 */ 901, /* Empty */         0 },
  { /* gnu-anonymous-struct */                                  6130, /* DiagArray304 */ 903, /* Empty */         0 },
  { /* gnu-array-member-paren-init */                           6151, /* DiagArray305 */ 905, /* Empty */         0 },
  { /* gnu-auto-type */                                         6179, /* DiagArray306 */ 907, /* Empty */         0 },
  { /* gnu-binary-literal */                                    6193, /* DiagArray307 */ 909, /* Empty */         0 },
  { /* gnu-case-range */                                        6212, /* DiagArray308 */ 911, /* Empty */         0 },
  { /* gnu-complex-integer */                                   6227, /* DiagArray309 */ 913, /* Empty */         0 },
  { /* gnu-compound-literal-initializer */                      6247, /* DiagArray310 */ 915, /* Empty */         0 },
  { /* gnu-conditional-omitted-operand */                       6280, /* DiagArray311 */ 917, /* Empty */         0 },
  { /* gnu-designator */                                        6312, /* DiagArray312 */ 919, /* Empty */         0 },
  { /* gnu-empty-initializer */                                 6327, /* DiagArray313 */ 923, /* Empty */         0 },
  { /* gnu-empty-struct */                                      6349, /* DiagArray314 */ 925, /* Empty */         0 },
  { /* gnu-flexible-array-initializer */                        6366, /* DiagArray315 */ 929, /* Empty */         0 },
  { /* gnu-flexible-array-union-member */                       6397, /* DiagArray316 */ 931, /* Empty */         0 },
  { /* gnu-folding-constant */                                  6429, /* DiagArray317 */ 933, /* Empty */         0 },
  { /* gnu-imaginary-constant */                                6450, /* DiagArray318 */ 937, /* Empty */         0 },
  { /* gnu-include-next */                                      6473, /* DiagArray319 */ 939, /* Empty */         0 },
  { /* gnu-inline-cpp-without-extern */                         6490, /* DiagArray320 */ 941, /* Empty */         0 },
  { /* gnu-label-as-value */                                    6520, /* DiagArray321 */ 943, /* Empty */         0 },
  { /* gnu-redeclared-enum */                                   6539, /* DiagArray322 */ 946, /* Empty */         0 },
  { /* gnu-statement-expression */                              6559, /* DiagArray323 */ 948, /* Empty */         0 },
  { /* gnu-static-float-init */                                 6584, /* DiagArray324 */ 950, /* Empty */         0 },
  { /* gnu-string-literal-operator-template */                  6606, /* DiagArray325 */ 952, /* Empty */         0 },
  { /* gnu-union-cast */                                        6643, /* DiagArray326 */ 954, /* Empty */         0 },
  { /* gnu-variable-sized-type-not-at-end */                    6658, /* DiagArray327 */ 956, /* Empty */         0 },
  { /* gnu-zero-line-directive */                               6693, /* DiagArray328 */ 958, /* Empty */         0 },
  { /* gnu-zero-variadic-macro-arguments */                     6717, /* DiagArray329 */ 960, /* Empty */         0 },
  { /* header-guard */                                          6751, /* DiagArray330 */ 963, /* Empty */         0 },
  { /* header-hygiene */                                        6764, /* DiagArray331 */ 965, /* Empty */         0 },
  { /* hip-only */                                              6779, /* DiagArray332 */ 967, /* Empty */         0 },
  { /* idiomatic-parentheses */                                 6788, /* DiagArray333 */ 969, /* Empty */         0 },
  { /* ignored-attributes */                                    6810, /* DiagArray334 */ 971, /* Empty */         0 },
  { /* ignored-optimization-argument */                         6829, /* DiagArray335 */ 1048, /* Empty */         0 },
  { /* ignored-pragma-intrinsic */                              6859, /* DiagArray336 */ 1051, /* Empty */         0 },
  { /* ignored-pragma-optimize */                               6884, /* DiagArray337 */ 1053, /* Empty */         0 },
  { /* ignored-pragmas */                                       6908, /* DiagArray338 */ 1055, /* DiagSubGroup338 */ 276 },
  { /* ignored-qualifiers */                                    6924, /* DiagArray339 */ 1101, /* Empty */         0 },
  { /* implicit */                                              6943, /* Empty */     0, /* DiagSubGroup340 */ 279 },
  { /* implicit-atomic-properties */                            6952, /* DiagArray341 */ 1107, /* Empty */         0 },
  { /* implicit-const-int-float-conversion */                   6979, /* DiagArray342 */ 1110, /* Empty */         0 },
  { /* implicit-conversion-floating-point-to-bool */            7015, /* DiagArray343 */ 1112, /* Empty */         0 },
  { /* implicit-exception-spec-mismatch */                      7058, /* DiagArray344 */ 1114, /* Empty */         0 },
  { /* implicit-fallthrough */                                  7091, /* DiagArray345 */ 1116, /* DiagSubGroup345 */ 282 },
  { /* implicit-fallthrough-per-function */                     7112, /* DiagArray346 */ 1119, /* Empty */         0 },
  { /* implicit-fixed-point-conversion */                       7146, /* DiagArray347 */ 1121, /* Empty */         0 },
  { /* implicit-float-conversion */                             7178, /* DiagArray348 */ 1123, /* DiagSubGroup348 */ 284 },
  { /* implicit-function-declaration */                         7204, /* DiagArray349 */ 1126, /* Empty */         0 },
  { /* implicit-int */                                          7234, /* DiagArray350 */ 1131, /* Empty */         0 },
  { /* implicit-int-conversion */                               7247, /* DiagArray351 */ 1133, /* DiagSubGroup351 */ 287 },
  { /* implicit-int-float-conversion */                         7271, /* DiagArray352 */ 1136, /* DiagSubGroup352 */ 289 },
  { /* implicit-retain-self */                                  7301, /* DiagArray353 */ 1138, /* Empty */         0 },
  { /* implicitly-unsigned-literal */                           7322, /* DiagArray354 */ 1140, /* Empty */         0 },
  { /* import */                                                7350, /* Empty */     0, /* Empty */         0 },
  { /* import-preprocessor-directive-pedantic */                7357, /* DiagArray356 */ 1142, /* Empty */         0 },
  { /* inaccessible-base */                                     7396, /* DiagArray357 */ 1144, /* Empty */         0 },
  { /* include-next-absolute-path */                            7414, /* DiagArray358 */ 1146, /* Empty */         0 },
  { /* include-next-outside-header */                           7441, /* DiagArray359 */ 1148, /* Empty */         0 },
  { /* incompatible-exception-spec */                           7469, /* DiagArray360 */ 1150, /* Empty */         0 },
  { /* incompatible-function-pointer-types */                   7497, /* DiagArray361 */ 1153, /* Empty */         0 },
  { /* incompatible-library-redeclaration */                    7533, /* DiagArray362 */ 1155, /* Empty */         0 },
  { /* incompatible-ms-struct */                                7568, /* DiagArray363 */ 1157, /* Empty */         0 },
  { /* incompatible-pointer-types */                            7591, /* DiagArray364 */ 1160, /* DiagSubGroup364 */ 291 },
  { /* incompatible-pointer-types-discards-qualifiers */        7618, /* DiagArray365 */ 1162, /* Empty */         0 },
  { /* incompatible-property-type */                            7665, /* DiagArray366 */ 1166, /* Empty */         0 },
  { /* incompatible-sysroot */                                  7692, /* DiagArray367 */ 1168, /* Empty */         0 },
  { /* incomplete-framework-module-declaration */               7713, /* DiagArray368 */ 1170, /* Empty */         0 },
  { /* incomplete-implementation */                             7753, /* DiagArray369 */ 1172, /* Empty */         0 },
  { /* incomplete-module */                                     7779, /* Empty */     0, /* DiagSubGroup370 */ 294 },
  { /* incomplete-setjmp-declaration */                         7797, /* DiagArray371 */ 1174, /* Empty */         0 },
  { /* incomplete-umbrella */                                   7827, /* DiagArray372 */ 1176, /* Empty */         0 },
  { /* inconsistent-dllimport */                                7847, /* DiagArray373 */ 1180, /* Empty */         0 },
  { /* inconsistent-missing-destructor-override */              7870, /* DiagArray374 */ 1183, /* Empty */         0 },
  { /* inconsistent-missing-override */                         7911, /* DiagArray375 */ 1185, /* Empty */         0 },
  { /* increment-bool */                                        7941, /* DiagArray376 */ 1187, /* DiagSubGroup376 */ 297 },
  { /* infinite-recursion */                                    7956, /* DiagArray377 */ 1189, /* Empty */         0 },
  { /* init-self */                                             7975, /* Empty */     0, /* Empty */         0 },
  { /* initializer-overrides */                                 7985, /* DiagArray379 */ 1191, /* Empty */         0 },
  { /* injected-class-name */                                   8007, /* DiagArray380 */ 1194, /* Empty */         0 },
  { /* inline */                                                8027, /* Empty */     0, /* Empty */         0 },
  { /* inline-asm */                                            8034, /* DiagArray382 */ 1196, /* Empty */         0 },
  { /* inline-namespace-reopened-noninline */                   8045, /* DiagArray383 */ 1198, /* Empty */         0 },
  { /* inline-new-delete */                                     8081, /* DiagArray384 */ 1200, /* Empty */         0 },
  { /* instantiation-after-specialization */                    8099, /* DiagArray385 */ 1202, /* Empty */         0 },
  { /* int-conversion */                                        8134, /* DiagArray386 */ 1204, /* Empty */         0 },
  { /* int-conversions */                                       8149, /* Empty */     0, /* DiagSubGroup387 */ 299 },
  { /* int-in-bool-context */                                   8165, /* DiagArray388 */ 1207, /* Empty */         0 },
  { /* int-to-pointer-cast */                                   8185, /* DiagArray389 */ 1210, /* DiagSubGroup389 */ 301 },
  { /* int-to-void-pointer-cast */                              8205, /* DiagArray390 */ 1212, /* Empty */         0 },
  { /* integer-overflow */                                      8230, /* DiagArray391 */ 1214, /* Empty */         0 },
  { /* invalid-command-line-argument */                         8247, /* DiagArray392 */ 1216, /* DiagSubGroup392 */ 303 },
  { /* invalid-constexpr */                                     8277, /* DiagArray393 */ 1223, /* Empty */         0 },
  { /* invalid-iboutlet */                                      8295, /* DiagArray394 */ 1225, /* Empty */         0 },
  { /* invalid-initializer-from-system-header */                8312, /* DiagArray395 */ 1228, /* Empty */         0 },
  { /* invalid-ios-deployment-target */                         8351, /* DiagArray396 */ 1230, /* Empty */         0 },
  { /* invalid-no-builtin-names */                              8381, /* DiagArray397 */ 1232, /* Empty */         0 },
  { /* invalid-noreturn */                                      8406, /* DiagArray398 */ 1234, /* Empty */         0 },
  { /* invalid-offsetof */                                      8423, /* DiagArray399 */ 1237, /* Empty */         0 },
  { /* invalid-or-nonexistent-directory */                      8440, /* DiagArray400 */ 1240, /* Empty */         0 },
  { /* invalid-partial-specialization */                        8473, /* DiagArray401 */ 1243, /* Empty */         0 },
  { /* invalid-pch */                                           8504, /* Empty */     0, /* Empty */         0 },
  { /* invalid-pp-token */                                      8516, /* DiagArray403 */ 1245, /* Empty */         0 },
  { /* invalid-source-encoding */                               8533, /* DiagArray404 */ 1248, /* Empty */         0 },
  { /* invalid-token-paste */                                   8557, /* DiagArray405 */ 1251, /* Empty */         0 },
  { /* jump-seh-finally */                                      8577, /* DiagArray406 */ 1253, /* Empty */         0 },
  { /* keyword-compat */                                        8594, /* DiagArray407 */ 1255, /* Empty */         0 },
  { /* keyword-macro */                                         8609, /* DiagArray408 */ 1257, /* Empty */         0 },
  { /* knr-promoted-parameter */                                8623, /* DiagArray409 */ 1259, /* Empty */         0 },
  { /* language-extension-token */                              8646, /* DiagArray410 */ 1261, /* Empty */         0 },
  { /* large-by-value-copy */                                   8671, /* DiagArray411 */ 1263, /* Empty */         0 },
  { /* liblto */                                                8691, /* Empty */     0, /* Empty */         0 },
  { /* literal-conversion */                                    8698, /* DiagArray413 */ 1266, /* Empty */         0 },
  { /* literal-range */                                         8717, /* DiagArray414 */ 1269, /* Empty */         0 },
  { /* local-type-template-args */                              8731, /* DiagArray415 */ 1272, /* DiagSubGroup415 */ 305 },
  { /* logical-not-parentheses */                               8756, /* DiagArray416 */ 1274, /* Empty */         0 },
  { /* logical-op-parentheses */                                8780, /* DiagArray417 */ 1276, /* Empty */         0 },
  { /* long-long */                                             8803, /* DiagArray418 */ 1278, /* DiagSubGroup418 */ 307 },
  { /* loop-analysis */                                         8813, /* Empty */     0, /* DiagSubGroup419 */ 309 },
  { /* macro-redefined */                                       8827, /* DiagArray420 */ 1280, /* Empty */         0 },
  { /* main */                                                  8843, /* DiagArray421 */ 1282, /* Empty */         0 },
  { /* main-return-type */                                      8848, /* DiagArray422 */ 1290, /* Empty */         0 },
  { /* malformed-warning-check */                               8865, /* DiagArray423 */ 1292, /* Empty */         0 },
  { /* many-braces-around-scalar-init */                        8889, /* DiagArray424 */ 1294, /* Empty */         0 },
  { /* max-tokens */                                            8920, /* DiagArray425 */ 1296, /* Empty */         0 },
  { /* max-unsigned-zero */                                     8931, /* DiagArray426 */ 1299, /* Empty */         0 },
  { /* memset-transposed-args */                                8949, /* DiagArray427 */ 1301, /* Empty */         0 },
  { /* memsize-comparison */                                    8972, /* DiagArray428 */ 1303, /* Empty */         0 },
  { /* method-signatures */                                     8991, /* DiagArray429 */ 1305, /* Empty */         0 },
  { /* microsoft */                                             9009, /* Empty */     0, /* DiagSubGroup430 */ 312 },
  { /* microsoft-anon-tag */                                    9019, /* DiagArray431 */ 1308, /* Empty */         0 },
  { /* microsoft-cast */                                        9038, /* DiagArray432 */ 1311, /* Empty */         0 },
  { /* microsoft-charize */                                     9053, /* DiagArray433 */ 1314, /* Empty */         0 },
  { /* microsoft-comment-paste */                               9071, /* DiagArray434 */ 1316, /* Empty */         0 },
  { /* microsoft-const-init */                                  9095, /* DiagArray435 */ 1318, /* Empty */         0 },
  { /* microsoft-cpp-macro */                                   9116, /* DiagArray436 */ 1320, /* Empty */         0 },
  { /* microsoft-default-arg-redefinition */                    9136, /* DiagArray437 */ 1322, /* Empty */         0 },
  { /* microsoft-drectve-section */                             9171, /* DiagArray438 */ 1324, /* Empty */         0 },
  { /* microsoft-end-of-file */                                 9197, /* DiagArray439 */ 1326, /* Empty */         0 },
  { /* microsoft-enum-forward-reference */                      9219, /* DiagArray440 */ 1328, /* Empty */         0 },
  { /* microsoft-enum-value */                                  9252, /* DiagArray441 */ 1330, /* Empty */         0 },
  { /* microsoft-exception-spec */                              9273, /* DiagArray442 */ 1332, /* Empty */         0 },
  { /* microsoft-exists */                                      9298, /* DiagArray443 */ 1339, /* Empty */         0 },
  { /* microsoft-explicit-constructor-call */                   9315, /* DiagArray444 */ 1341, /* Empty */         0 },
  { /* microsoft-extra-qualification */                         9351, /* DiagArray445 */ 1343, /* Empty */         0 },
  { /* microsoft-fixed-enum */                                  9381, /* DiagArray446 */ 1345, /* Empty */         0 },
  { /* microsoft-flexible-array */                              9402, /* DiagArray447 */ 1347, /* Empty */         0 },
  { /* microsoft-goto */                                        9427, /* DiagArray448 */ 1350, /* Empty */         0 },
  { /* microsoft-inaccessible-base */                           9442, /* DiagArray449 */ 1352, /* Empty */         0 },
  { /* microsoft-include */                                     9470, /* DiagArray450 */ 1354, /* Empty */         0 },
  { /* microsoft-mutable-reference */                           9488, /* DiagArray451 */ 1356, /* Empty */         0 },
  { /* microsoft-pure-definition */                             9516, /* DiagArray452 */ 1358, /* Empty */         0 },
  { /* microsoft-redeclare-static */                            9542, /* DiagArray453 */ 1360, /* Empty */         0 },
  { /* microsoft-sealed */                                      9569, /* DiagArray454 */ 1362, /* Empty */         0 },
  { /* microsoft-template */                                    9586, /* DiagArray455 */ 1364, /* DiagSubGroup455 */ 341 },
  { /* microsoft-template-shadow */                             9605, /* DiagArray456 */ 1374, /* Empty */         0 },
  { /* microsoft-union-member-reference */                      9631, /* DiagArray457 */ 1376, /* Empty */         0 },
  { /* microsoft-unqualified-friend */                          9664, /* DiagArray458 */ 1378, /* Empty */         0 },
  { /* microsoft-using-decl */                                  9693, /* DiagArray459 */ 1380, /* Empty */         0 },
  { /* microsoft-void-pseudo-dtor */                            9714, /* DiagArray460 */ 1382, /* Empty */         0 },
  { /* misleading-indentation */                                9741, /* DiagArray461 */ 1384, /* Empty */         0 },
  { /* mismatched-new-delete */                                 9764, /* DiagArray462 */ 1386, /* Empty */         0 },
  { /* mismatched-parameter-types */                            9786, /* DiagArray463 */ 1388, /* Empty */         0 },
  { /* mismatched-return-types */                               9813, /* DiagArray464 */ 1390, /* Empty */         0 },
  { /* mismatched-tags */                                       9837, /* DiagArray465 */ 1392, /* Empty */         0 },
  { /* missing-braces */                                        9853, /* DiagArray466 */ 1395, /* Empty */         0 },
  { /* missing-constinit */                                     9868, /* DiagArray467 */ 1397, /* Empty */         0 },
  { /* missing-declarations */                                  9886, /* DiagArray468 */ 1399, /* Empty */         0 },
  { /* missing-exception-spec */                                9907, /* DiagArray469 */ 1404, /* Empty */         0 },
  { /* missing-field-initializers */                            9930, /* DiagArray470 */ 1406, /* Empty */         0 },
  { /* missing-format-attribute */                              9957, /* Empty */     0, /* Empty */         0 },
  { /* missing-include-dirs */                                  9982, /* Empty */     0, /* Empty */         0 },
  { /* missing-method-return-type */                            10003, /* DiagArray473 */ 1408, /* Empty */         0 },
  { /* missing-noescape */                                      10030, /* DiagArray474 */ 1410, /* Empty */         0 },
  { /* missing-noreturn */                                      10047, /* DiagArray475 */ 1412, /* Empty */         0 },
  { /* missing-prototype-for-cc */                              10064, /* DiagArray476 */ 1415, /* Empty */         0 },
  { /* missing-prototypes */                                    10089, /* DiagArray477 */ 1417, /* Empty */         0 },
  { /* missing-selector-name */                                 10108, /* DiagArray478 */ 1419, /* Empty */         0 },
  { /* missing-sysroot */                                       10130, /* DiagArray479 */ 1421, /* Empty */         0 },
  { /* missing-variable-declarations */                         10146, /* DiagArray480 */ 1423, /* Empty */         0 },
  { /* misspelled-assumption */                                 10176, /* DiagArray481 */ 1425, /* Empty */         0 },
  { /* module-build */                                          10198, /* DiagArray482 */ 1427, /* Empty */         0 },
  { /* module-conflict */                                       10211, /* DiagArray483 */ 1432, /* Empty */         0 },
  { /* module-file-config-mismatch */                           10227, /* DiagArray484 */ 1435, /* Empty */         0 },
  { /* module-file-extension */                                 10255, /* DiagArray485 */ 1437, /* Empty */         0 },
  { /* module-import */                                         10277, /* DiagArray486 */ 1439, /* Empty */         0 },
  { /* module-import-in-extern-c */                             10291, /* DiagArray487 */ 1441, /* Empty */         0 },
  { /* modules-ambiguous-internal-linkage */                    10317, /* DiagArray488 */ 1443, /* Empty */         0 },
  { /* modules-import-nested-redundant */                       10352, /* DiagArray489 */ 1445, /* Empty */         0 },
  { /* most */                                                  10384, /* Empty */     0, /* DiagSubGroup490 */ 343 },
  { /* move */                                                  10389, /* Empty */     0, /* DiagSubGroup491 */ 379 },
  { /* msvc-include */                                          10394, /* Empty */     0, /* DiagSubGroup492 */ 384 },
  { /* msvc-not-found */                                        10407, /* DiagArray493 */ 1447, /* Empty */         0 },
  { /* multichar */                                             10422, /* DiagArray494 */ 1449, /* Empty */         0 },
  { /* multiple-move-vbase */                                   10432, /* DiagArray495 */ 1451, /* Empty */         0 },
  { /* narrowing */                                             10452, /* Empty */     0, /* DiagSubGroup496 */ 386 },
  { /* nested-anon-types */                                     10462, /* DiagArray497 */ 1453, /* Empty */         0 },
  { /* nested-externs */                                        10480, /* Empty */     0, /* Empty */         0 },
  { /* new-returns-null */                                      10495, /* DiagArray499 */ 1455, /* Empty */         0 },
  { /* newline-eof */                                           10512, /* DiagArray500 */ 1457, /* Empty */         0 },
  { /* noderef */                                               10524, /* DiagArray501 */ 1460, /* Empty */         0 },
  { /* noexcept-type */                                         10532, /* Empty */     0, /* DiagSubGroup502 */ 388 },
  { /* non-c-typedef-for-linkage */                             10546, /* DiagArray503 */ 1464, /* Empty */         0 },
  { /* non-gcc */                                               10572, /* Empty */     0, /* DiagSubGroup504 */ 390 },
  { /* non-literal-null-conversion */                           10580, /* DiagArray505 */ 1466, /* Empty */         0 },
  { /* non-modular-include-in-framework-module */               10608, /* DiagArray506 */ 1468, /* Empty */         0 },
  { /* non-modular-include-in-module */                         10648, /* DiagArray507 */ 1470, /* DiagSubGroup507 */ 394 },
  { /* non-pod-varargs */                                       10678, /* DiagArray508 */ 1472, /* Empty */         0 },
  { /* non-power-of-two-alignment */                            10694, /* DiagArray509 */ 1477, /* Empty */         0 },
  { /* non-virtual-dtor */                                      10721, /* DiagArray510 */ 1479, /* Empty */         0 },
  { /* nonnull */                                               10738, /* DiagArray511 */ 1481, /* Empty */         0 },
  { /* nonportable-cfstrings */                                 10746, /* Empty */     0, /* Empty */         0 },
  { /* nonportable-include-path */                              10768, /* DiagArray513 */ 1484, /* Empty */         0 },
  { /* nonportable-system-include-path */                       10793, /* DiagArray514 */ 1486, /* Empty */         0 },
  { /* nonportable-vector-initialization */                     10825, /* DiagArray515 */ 1488, /* Empty */         0 },
  { /* nontrivial-memaccess */                                  10859, /* DiagArray516 */ 1490, /* Empty */         0 },
  { /* nsconsumed-mismatch */                                   10880, /* DiagArray517 */ 1492, /* Empty */         0 },
  { /* nsreturns-mismatch */                                    10900, /* DiagArray518 */ 1494, /* Empty */         0 },
  { /* null-arithmetic */                                       10919, /* DiagArray519 */ 1496, /* Empty */         0 },
  { /* null-character */                                        10935, /* DiagArray520 */ 1499, /* Empty */         0 },
  { /* null-conversion */                                       10950, /* DiagArray521 */ 1502, /* Empty */         0 },
  { /* null-dereference */                                      10966, /* DiagArray522 */ 1504, /* Empty */         0 },
  { /* null-pointer-arithmetic */                               10983, /* DiagArray523 */ 1507, /* Empty */         0 },
  { /* nullability */                                           11007, /* DiagArray524 */ 1510, /* Empty */         0 },
  { /* nullability-completeness */                              11019, /* DiagArray525 */ 1516, /* DiagSubGroup525 */ 396 },
  { /* nullability-completeness-on-arrays */                    11044, /* DiagArray526 */ 1518, /* Empty */         0 },
  { /* nullability-declspec */                                  11079, /* DiagArray527 */ 1520, /* Empty */         0 },
  { /* nullability-extension */                                 11100, /* DiagArray528 */ 1522, /* Empty */         0 },
  { /* nullability-inferred-on-nested-type */                   11122, /* DiagArray529 */ 1524, /* Empty */         0 },
  { /* nullable-to-nonnull-conversion */                        11158, /* DiagArray530 */ 1526, /* Empty */         0 },
  { /* objc-autosynthesis-property-ivar-name-match */           11189, /* DiagArray531 */ 1528, /* Empty */         0 },
  { /* objc-bool-constant-conversion */                         11233, /* DiagArray532 */ 1530, /* Empty */         0 },
  { /* objc-boxing */                                           11263, /* DiagArray533 */ 1532, /* Empty */         0 },
  { /* objc-circular-container */                               11275, /* DiagArray534 */ 1534, /* Empty */         0 },
  { /* objc-cocoa-api */                                        11299, /* Empty */     0, /* DiagSubGroup535 */ 398 },
  { /* objc-designated-initializers */                          11314, /* DiagArray536 */ 1536, /* Empty */         0 },
  { /* objc-dictionary-duplicate-keys */                        11343, /* DiagArray537 */ 1543, /* Empty */         0 },
  { /* objc-flexible-array */                                   11374, /* DiagArray538 */ 1545, /* Empty */         0 },
  { /* objc-forward-class-redefinition */                       11394, /* DiagArray539 */ 1548, /* Empty */         0 },
  { /* objc-interface-ivars */                                  11426, /* DiagArray540 */ 1550, /* Empty */         0 },
  { /* objc-literal-compare */                                  11447, /* DiagArray541 */ 1552, /* DiagSubGroup541 */ 400 },
  { /* objc-literal-conversion */                               11468, /* DiagArray542 */ 1554, /* Empty */         0 },
  { /* objc-macro-redefinition */                               11492, /* DiagArray543 */ 1557, /* Empty */         0 },
  { /* objc-messaging-id */                                     11516, /* DiagArray544 */ 1559, /* Empty */         0 },
  { /* objc-method-access */                                    11534, /* DiagArray545 */ 1561, /* Empty */         0 },
  { /* objc-missing-property-synthesis */                       11553, /* DiagArray546 */ 1568, /* Empty */         0 },
  { /* objc-missing-super-calls */                              11585, /* DiagArray547 */ 1570, /* Empty */         0 },
  { /* objc-multiple-method-names */                            11610, /* DiagArray548 */ 1572, /* Empty */         0 },
  { /* objc-noncopy-retain-block-property */                    11637, /* DiagArray549 */ 1574, /* Empty */         0 },
  { /* objc-nonunified-exceptions */                            11672, /* DiagArray550 */ 1576, /* Empty */         0 },
  { /* objc-property-assign-on-object-type */                   11699, /* DiagArray551 */ 1578, /* Empty */         0 },
  { /* objc-property-implementation */                          11735, /* DiagArray552 */ 1580, /* Empty */         0 },
  { /* objc-property-implicit-mismatch */                       11764, /* DiagArray553 */ 1585, /* Empty */         0 },
  { /* objc-property-matches-cocoa-ownership-rule */            11796, /* DiagArray554 */ 1587, /* Empty */         0 },
  { /* objc-property-no-attribute */                            11839, /* DiagArray555 */ 1589, /* Empty */         0 },
  { /* objc-property-synthesis */                               11866, /* DiagArray556 */ 1592, /* Empty */         0 },
  { /* objc-protocol-method-implementation */                   11890, /* DiagArray557 */ 1596, /* Empty */         0 },
  { /* objc-protocol-property-synthesis */                      11926, /* DiagArray558 */ 1598, /* Empty */         0 },
  { /* objc-protocol-qualifiers */                              11959, /* DiagArray559 */ 1600, /* Empty */         0 },
  { /* objc-readonly-with-setter-property */                    11984, /* DiagArray560 */ 1602, /* Empty */         0 },
  { /* objc-redundant-api-use */                                12019, /* Empty */     0, /* DiagSubGroup561 */ 402 },
  { /* objc-redundant-literal-use */                            12042, /* DiagArray562 */ 1604, /* Empty */         0 },
  { /* objc-root-class */                                       12069, /* DiagArray563 */ 1606, /* Empty */         0 },
  { /* objc-signed-char-bool */                                 12085, /* Empty */     0, /* DiagSubGroup564 */ 404 },
  { /* objc-signed-char-bool-implicit-float-conversion */       12107, /* DiagArray565 */ 1608, /* Empty */         0 },
  { /* objc-signed-char-bool-implicit-int-conversion */         12155, /* DiagArray566 */ 1610, /* Empty */         0 },
  { /* objc-string-compare */                                   12201, /* DiagArray567 */ 1612, /* Empty */         0 },
  { /* objc-string-concatenation */                             12221, /* DiagArray568 */ 1614, /* Empty */         0 },
  { /* objc-unsafe-perform-selector */                          12247, /* DiagArray569 */ 1616, /* Empty */         0 },
  { /* odr */                                                   12276, /* DiagArray570 */ 1618, /* Empty */         0 },
  { /* old-style-cast */                                        12280, /* DiagArray571 */ 1637, /* Empty */         0 },
  { /* old-style-definition */                                  12295, /* Empty */     0, /* Empty */         0 },
  { /* opencl-unsupported-rgba */                               12316, /* DiagArray573 */ 1639, /* Empty */         0 },
  { /* openmp */                                                12340, /* Empty */     0, /* DiagSubGroup574 */ 409 },
  { /* openmp-clauses */                                        12347, /* DiagArray575 */ 1641, /* Empty */         0 },
  { /* openmp-loop-form */                                      12362, /* DiagArray576 */ 1659, /* Empty */         0 },
  { /* openmp-mapping */                                        12379, /* DiagArray577 */ 1662, /* Empty */         0 },
  { /* openmp-target */                                         12394, /* DiagArray578 */ 1664, /* DiagSubGroup578 */ 415 },
  { /* option-ignored */                                        12408, /* DiagArray579 */ 1668, /* Empty */         0 },
  { /* ordered-compare-function-pointers */                     12423, /* DiagArray580 */ 1677, /* Empty */         0 },
  { /* out-of-line-declaration */                               12457, /* DiagArray581 */ 1679, /* Empty */         0 },
  { /* out-of-scope-function */                                 12481, /* DiagArray582 */ 1681, /* Empty */         0 },
  { /* over-aligned */                                          12503, /* DiagArray583 */ 1683, /* Empty */         0 },
  { /* overflow */                                              12516, /* Empty */     0, /* Empty */         0 },
  { /* overlength-strings */                                    12525, /* DiagArray585 */ 1685, /* Empty */         0 },
  { /* overloaded-shift-op-parentheses */                       12544, /* DiagArray586 */ 1687, /* Empty */         0 },
  { /* overloaded-virtual */                                    12576, /* DiagArray587 */ 1689, /* Empty */         0 },
  { /* override-init */                                         12595, /* Empty */     0, /* DiagSubGroup588 */ 417 },
  { /* override-module */                                       12609, /* DiagArray589 */ 1691, /* Empty */         0 },
  { /* overriding-method-mismatch */                            12625, /* DiagArray590 */ 1693, /* Empty */         0 },
  { /* overriding-t-option */                                   12652, /* DiagArray591 */ 1701, /* Empty */         0 },
  { /* packed */                                                12672, /* DiagArray592 */ 1703, /* Empty */         0 },
  { /* padded */                                                12679, /* DiagArray593 */ 1705, /* Empty */         0 },
  { /* parentheses */                                           12686, /* DiagArray594 */ 1709, /* DiagSubGroup594 */ 419 },
  { /* parentheses-equality */                                  12698, /* DiagArray595 */ 1713, /* Empty */         0 },
  { /* partial-availability */                                  12719, /* Empty */     0, /* DiagSubGroup596 */ 428 },
  { /* pass */                                                  12740, /* DiagArray597 */ 1715, /* Empty */         0 },
  { /* pass-analysis */                                         12745, /* DiagArray598 */ 1717, /* Empty */         0 },
  { /* pass-failed */                                           12759, /* DiagArray599 */ 1721, /* Empty */         0 },
  { /* pass-missed */                                           12771, /* DiagArray600 */ 1723, /* Empty */         0 },
  { /* pch-date-time */                                         12783, /* DiagArray601 */ 1725, /* Empty */         0 },
  { /* pedantic */                                              12797, /* DiagArray602 */ 1727, /* DiagSubGroup602 */ 430 },
  { /* pedantic-core-features */                                12806, /* DiagArray603 */ 1803, /* Empty */         0 },
  { /* pessimizing-move */                                      12829, /* DiagArray604 */ 1805, /* Empty */         0 },
  { /* pointer-arith */                                         12846, /* DiagArray605 */ 1808, /* Empty */         0 },
  { /* pointer-bool-conversion */                               12860, /* DiagArray606 */ 1815, /* Empty */         0 },
  { /* pointer-compare */                                       12884, /* DiagArray607 */ 1818, /* Empty */         0 },
  { /* pointer-integer-compare */                               12900, /* DiagArray608 */ 1820, /* Empty */         0 },
  { /* pointer-sign */                                          12924, /* DiagArray609 */ 1822, /* Empty */         0 },
  { /* pointer-to-enum-cast */                                  12937, /* DiagArray610 */ 1824, /* DiagSubGroup610 */ 481 },
  { /* pointer-to-int-cast */                                   12958, /* DiagArray611 */ 1826, /* DiagSubGroup611 */ 483 },
  { /* pointer-type-mismatch */                                 12978, /* DiagArray612 */ 1828, /* Empty */         0 },
  { /* poison-system-directories */                             13000, /* DiagArray613 */ 1830, /* Empty */         0 },
  { /* potentially-direct-selector */                           13026, /* DiagArray614 */ 1832, /* Empty */         0 },
  { /* potentially-evaluated-expression */                      13054, /* DiagArray615 */ 1834, /* Empty */         0 },
  { /* pragma-clang-attribute */                                13087, /* DiagArray616 */ 1836, /* Empty */         0 },
  { /* pragma-once-outside-header */                            13110, /* DiagArray617 */ 1838, /* Empty */         0 },
  { /* pragma-pack */                                           13137, /* DiagArray618 */ 1840, /* DiagSubGroup618 */ 486 },
  { /* pragma-pack-suspicious-include */                        13149, /* DiagArray619 */ 1843, /* Empty */         0 },
  { /* pragma-system-header-outside-header */                   13180, /* DiagArray620 */ 1845, /* Empty */         0 },
  { /* pragmas */                                               13216, /* DiagArray621 */ 1847, /* DiagSubGroup621 */ 488 },
  { /* predefined-identifier-outside-function */                13224, /* DiagArray622 */ 1849, /* Empty */         0 },
  { /* private-extern */                                        13263, /* DiagArray623 */ 1851, /* Empty */         0 },
  { /* private-header */                                        13278, /* DiagArray624 */ 1853, /* Empty */         0 },
  { /* private-module */                                        13293, /* DiagArray625 */ 1855, /* Empty */         0 },
  { /* profile-instr-missing */                                 13308, /* DiagArray626 */ 1860, /* Empty */         0 },
  { /* profile-instr-out-of-date */                             13330, /* DiagArray627 */ 1862, /* Empty */         0 },
  { /* profile-instr-unprofiled */                              13356, /* DiagArray628 */ 1864, /* Empty */         0 },
  { /* property-access-dot-syntax */                            13381, /* DiagArray629 */ 1866, /* Empty */         0 },
  { /* property-attribute-mismatch */                           13408, /* DiagArray630 */ 1868, /* Empty */         0 },
  { /* protocol */                                              13436, /* DiagArray631 */ 1873, /* Empty */         0 },
  { /* protocol-property-synthesis-ambiguity */                 13445, /* DiagArray632 */ 1875, /* Empty */         0 },
  { /* psabi */                                                 13483, /* DiagArray633 */ 1877, /* Empty */         0 },
  { /* qualified-void-return-type */                            13489, /* DiagArray634 */ 1879, /* Empty */         0 },
  { /* quoted-include-in-framework-header */                    13516, /* DiagArray635 */ 1881, /* Empty */         0 },
  { /* range-loop-analysis */                                   13551, /* Empty */     0, /* DiagSubGroup636 */ 493 },
  { /* range-loop-bind-reference */                             13571, /* DiagArray637 */ 1883, /* Empty */         0 },
  { /* range-loop-construct */                                  13597, /* DiagArray638 */ 1885, /* Empty */         0 },
  { /* readonly-iboutlet-property */                            13618, /* DiagArray639 */ 1888, /* Empty */         0 },
  { /* receiver-expr */                                         13645, /* DiagArray640 */ 1890, /* Empty */         0 },
  { /* receiver-forward-class */                                13659, /* DiagArray641 */ 1892, /* Empty */         0 },
  { /* redeclared-class-member */                               13682, /* DiagArray642 */ 1895, /* Empty */         0 },
  { /* redundant-decls */                                       13706, /* Empty */     0, /* Empty */         0 },
  { /* redundant-move */                                        13722, /* DiagArray644 */ 1897, /* Empty */         0 },
  { /* redundant-parens */                                      13737, /* DiagArray645 */ 1899, /* Empty */         0 },
  { /* register */                                              13754, /* DiagArray646 */ 1901, /* DiagSubGroup646 */ 496 },
  { /* reinterpret-base-class */                                13763, /* DiagArray647 */ 1903, /* Empty */         0 },
  { /* remark-backend-plugin */                                 13786, /* DiagArray648 */ 1905, /* Empty */         0 },
  { /* reorder */                                               13808, /* Empty */     0, /* DiagSubGroup649 */ 498 },
  { /* reorder-ctor */                                          13816, /* DiagArray650 */ 1907, /* Empty */         0 },
  { /* reorder-init-list */                                     13829, /* DiagArray651 */ 1909, /* Empty */         0 },
  { /* requires-expression */                                   13847, /* DiagArray652 */ 1911, /* Empty */         0 },
  { /* requires-super-attribute */                              13867, /* DiagArray653 */ 1913, /* Empty */         0 },
  { /* reserved-id-macro */                                     13892, /* DiagArray654 */ 1915, /* Empty */         0 },
  { /* reserved-user-defined-literal */                         13910, /* DiagArray655 */ 1917, /* DiagSubGroup655 */ 501 },
  { /* retained-language-linkage */                             13940, /* DiagArray656 */ 1920, /* Empty */         0 },
  { /* return-stack-address */                                  13966, /* DiagArray657 */ 1922, /* Empty */         0 },
  { /* return-std-move */                                       13987, /* DiagArray658 */ 1926, /* Empty */         0 },
  { /* return-std-move-in-c++11 */                              14003, /* DiagArray659 */ 1928, /* Empty */         0 },
  { /* return-type */                                           14028, /* DiagArray660 */ 1930, /* DiagSubGroup660 */ 503 },
  { /* return-type-c-linkage */                                 14040, /* DiagArray661 */ 1940, /* Empty */         0 },
  { /* rewrite-not-bool */                                      14062, /* DiagArray662 */ 1943, /* Empty */         0 },
  { /* rtti */                                                  14079, /* DiagArray663 */ 1945, /* Empty */         0 },
  { /* sanitize-address */                                      14084, /* DiagArray664 */ 1948, /* Empty */         0 },
  { /* section */                                               14101, /* DiagArray665 */ 1951, /* Empty */         0 },
  { /* selector */                                              14109, /* DiagArray666 */ 1955, /* DiagSubGroup666 */ 505 },
  { /* selector-type-mismatch */                                14118, /* DiagArray667 */ 1957, /* Empty */         0 },
  { /* self-assign */                                           14141, /* DiagArray668 */ 1959, /* DiagSubGroup668 */ 507 },
  { /* self-assign-field */                                     14153, /* DiagArray669 */ 1961, /* Empty */         0 },
  { /* self-assign-overloaded */                                14171, /* DiagArray670 */ 1963, /* Empty */         0 },
  { /* self-move */                                             14194, /* DiagArray671 */ 1965, /* Empty */         0 },
  { /* semicolon-before-method-body */                          14204, /* DiagArray672 */ 1967, /* Empty */         0 },
  { /* sentinel */                                              14233, /* DiagArray673 */ 1969, /* Empty */         0 },
  { /* sequence-point */                                        14242, /* Empty */     0, /* DiagSubGroup674 */ 510 },
  { /* serialized-diagnostics */                                14257, /* DiagArray675 */ 1972, /* Empty */         0 },
  { /* shadow */                                                14280, /* DiagArray676 */ 1976, /* DiagSubGroup676 */ 512 },
  { /* shadow-all */                                            14287, /* Empty */     0, /* DiagSubGroup677 */ 515 },
  { /* shadow-field */                                          14298, /* DiagArray678 */ 1978, /* Empty */         0 },
  { /* shadow-field-in-constructor */                           14311, /* DiagArray679 */ 1980, /* DiagSubGroup679 */ 520 },
  { /* shadow-field-in-constructor-modified */                  14339, /* DiagArray680 */ 1982, /* Empty */         0 },
  { /* shadow-ivar */                                           14376, /* DiagArray681 */ 1984, /* Empty */         0 },
  { /* shadow-uncaptured-local */                               14388, /* DiagArray682 */ 1986, /* Empty */         0 },
  { /* shift-count-negative */                                  14412, /* DiagArray683 */ 1988, /* Empty */         0 },
  { /* shift-count-overflow */                                  14433, /* DiagArray684 */ 1990, /* Empty */         0 },
  { /* shift-negative-value */                                  14454, /* DiagArray685 */ 1992, /* Empty */         0 },
  { /* shift-op-parentheses */                                  14475, /* DiagArray686 */ 1994, /* Empty */         0 },
  { /* shift-overflow */                                        14496, /* DiagArray687 */ 1996, /* Empty */         0 },
  { /* shift-sign-overflow */                                   14511, /* DiagArray688 */ 1998, /* Empty */         0 },
  { /* shorten-64-to-32 */                                      14531, /* DiagArray689 */ 2000, /* Empty */         0 },
  { /* sign-compare */                                          14548, /* DiagArray690 */ 2002, /* Empty */         0 },
  { /* sign-conversion */                                       14561, /* DiagArray691 */ 2004, /* Empty */         0 },
  { /* sign-promo */                                            14577, /* Empty */     0, /* Empty */         0 },
  { /* signed-enum-bitfield */                                  14588, /* DiagArray693 */ 2008, /* Empty */         0 },
  { /* signed-unsigned-wchar */                                 14609, /* DiagArray694 */ 2010, /* Empty */         0 },
  { /* sizeof-array-argument */                                 14631, /* DiagArray695 */ 2012, /* Empty */         0 },
  { /* sizeof-array-decay */                                    14653, /* DiagArray696 */ 2014, /* Empty */         0 },
  { /* sizeof-array-div */                                      14672, /* DiagArray697 */ 2016, /* Empty */         0 },
  { /* sizeof-pointer-div */                                    14689, /* DiagArray698 */ 2018, /* Empty */         0 },
  { /* sizeof-pointer-memaccess */                              14708, /* DiagArray699 */ 2020, /* Empty */         0 },
  { /* slash-u-filename */                                      14733, /* DiagArray700 */ 2023, /* Empty */         0 },
  { /* slh-asm-goto */                                          14750, /* DiagArray701 */ 2025, /* Empty */         0 },
  { /* sometimes-uninitialized */                               14763, /* DiagArray702 */ 2027, /* Empty */         0 },
  { /* source-uses-openmp */                                    14787, /* DiagArray703 */ 2029, /* Empty */         0 },
  { /* spir-compat */                                           14806, /* DiagArray704 */ 2038, /* Empty */         0 },
  { /* stack-exhausted */                                       14818, /* DiagArray705 */ 2040, /* Empty */         0 },
  { /* stack-protector */                                       14834, /* DiagArray706 */ 2042, /* Empty */         0 },
  { /* static-float-init */                                     14850, /* DiagArray707 */ 2044, /* DiagSubGroup707 */ 522 },
  { /* static-in-inline */                                      14868, /* DiagArray708 */ 2046, /* Empty */         0 },
  { /* static-inline-explicit-instantiation */                  14885, /* DiagArray709 */ 2049, /* Empty */         0 },
  { /* static-local-in-inline */                                14922, /* DiagArray710 */ 2051, /* Empty */         0 },
  { /* static-self-init */                                      14945, /* DiagArray711 */ 2053, /* Empty */         0 },
  { /* stdlibcxx-not-found */                                   14962, /* DiagArray712 */ 2055, /* Empty */         0 },
  { /* strict-aliasing */                                       14982, /* Empty */     0, /* Empty */         0 },
  { /* strict-aliasing=0 */                                     14998, /* Empty */     0, /* Empty */         0 },
  { /* strict-aliasing=1 */                                     15016, /* Empty */     0, /* Empty */         0 },
  { /* strict-aliasing=2 */                                     15034, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow */                                       15052, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=0 */                                     15068, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=1 */                                     15086, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=2 */                                     15104, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=3 */                                     15122, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=4 */                                     15140, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=5 */                                     15158, /* Empty */     0, /* Empty */         0 },
  { /* strict-potentially-direct-selector */                    15176, /* DiagArray724 */ 2057, /* DiagSubGroup724 */ 524 },
  { /* strict-prototypes */                                     15211, /* DiagArray725 */ 2059, /* Empty */         0 },
  { /* strict-selector-match */                                 15229, /* DiagArray726 */ 2061, /* Empty */         0 },
  { /* string-compare */                                        15251, /* DiagArray727 */ 2063, /* Empty */         0 },
  { /* string-concatenation */                                  15266, /* DiagArray728 */ 2065, /* Empty */         0 },
  { /* string-conversion */                                     15287, /* DiagArray729 */ 2067, /* Empty */         0 },
  { /* string-plus-char */                                      15305, /* DiagArray730 */ 2069, /* Empty */         0 },
  { /* string-plus-int */                                       15322, /* DiagArray731 */ 2071, /* Empty */         0 },
  { /* strlcpy-strlcat-size */                                  15338, /* DiagArray732 */ 2073, /* Empty */         0 },
  { /* strncat-size */                                          15359, /* DiagArray733 */ 2075, /* Empty */         0 },
  { /* suggest-destructor-override */                           15372, /* DiagArray734 */ 2079, /* Empty */         0 },
  { /* suggest-override */                                      15400, /* DiagArray735 */ 2081, /* Empty */         0 },
  { /* super-class-method-mismatch */                           15417, /* DiagArray736 */ 2083, /* Empty */         0 },
  { /* suspicious-bzero */                                      15445, /* DiagArray737 */ 2085, /* Empty */         0 },
  { /* suspicious-memaccess */                                  15462, /* Empty */     0, /* DiagSubGroup738 */ 526 },
  { /* swift-name-attribute */                                  15483, /* DiagArray739 */ 2087, /* Empty */         0 },
  { /* switch */                                                15504, /* DiagArray740 */ 2101, /* Empty */         0 },
  { /* switch-bool */                                           15511, /* DiagArray741 */ 2105, /* Empty */         0 },
  { /* switch-default */                                        15523, /* Empty */     0, /* Empty */         0 },
  { /* switch-enum */                                           15538, /* DiagArray743 */ 2107, /* Empty */         0 },
  { /* sync-fetch-and-nand-semantics-changed */                 15550, /* DiagArray744 */ 2109, /* Empty */         0 },
  { /* synth */                                                 15588, /* Empty */     0, /* Empty */         0 },
  { /* tautological-bitwise-compare */                          15594, /* DiagArray746 */ 2111, /* Empty */         0 },
  { /* tautological-compare */                                  15623, /* DiagArray747 */ 2114, /* DiagSubGroup747 */ 532 },
  { /* tautological-constant-compare */                         15644, /* DiagArray748 */ 2117, /* DiagSubGroup748 */ 539 },
  { /* tautological-constant-in-range-compare */                15674, /* Empty */     0, /* DiagSubGroup749 */ 541 },
  { /* tautological-constant-out-of-range-compare */            15713, /* DiagArray750 */ 2121, /* Empty */         0 },
  { /* tautological-objc-bool-compare */                        15756, /* DiagArray751 */ 2123, /* Empty */         0 },
  { /* tautological-overlap-compare */                          15787, /* DiagArray752 */ 2125, /* Empty */         0 },
  { /* tautological-pointer-compare */                          15816, /* DiagArray753 */ 2127, /* Empty */         0 },
  { /* tautological-type-limit-compare */                       15845, /* DiagArray754 */ 2130, /* Empty */         0 },
  { /* tautological-undefined-compare */                        15877, /* DiagArray755 */ 2132, /* Empty */         0 },
  { /* tautological-unsigned-enum-zero-compare */               15908, /* DiagArray756 */ 2135, /* Empty */         0 },
  { /* tautological-unsigned-zero-compare */                    15948, /* DiagArray757 */ 2137, /* Empty */         0 },
  { /* tautological-value-range-compare */                      15983, /* DiagArray758 */ 2139, /* Empty */         0 },
  { /* tcb-enforcement */                                       16016, /* DiagArray759 */ 2141, /* Empty */         0 },
  { /* tentative-definition-incomplete-type */                  16032, /* DiagArray760 */ 2143, /* Empty */         0 },
  { /* thread-safety */                                         16069, /* Empty */     0, /* DiagSubGroup761 */ 544 },
  { /* thread-safety-analysis */                                16083, /* DiagArray762 */ 2145, /* Empty */         0 },
  { /* thread-safety-attributes */                              16106, /* DiagArray763 */ 2164, /* Empty */         0 },
  { /* thread-safety-beta */                                    16131, /* DiagArray764 */ 2171, /* Empty */         0 },
  { /* thread-safety-negative */                                16150, /* DiagArray765 */ 2173, /* Empty */         0 },
  { /* thread-safety-precise */                                 16173, /* DiagArray766 */ 2175, /* Empty */         0 },
  { /* thread-safety-reference */                               16195, /* DiagArray767 */ 2179, /* Empty */         0 },
  { /* thread-safety-verbose */                                 16219, /* DiagArray768 */ 2182, /* Empty */         0 },
  { /* trigraphs */                                             16241, /* DiagArray769 */ 2184, /* Empty */         0 },
  { /* type-limits */                                           16251, /* Empty */     0, /* DiagSubGroup770 */ 549 },
  { /* type-safety */                                           16263, /* DiagArray771 */ 2189, /* Empty */         0 },
  { /* typedef-redefinition */                                  16275, /* DiagArray772 */ 2193, /* Empty */         0 },
  { /* typename-missing */                                      16296, /* DiagArray773 */ 2195, /* Empty */         0 },
  { /* unable-to-open-stats-file */                             16313, /* DiagArray774 */ 2197, /* Empty */         0 },
  { /* unavailable-declarations */                              16339, /* DiagArray775 */ 2199, /* Empty */         0 },
  { /* undeclared-selector */                                   16364, /* DiagArray776 */ 2201, /* Empty */         0 },
  { /* undef */                                                 16384, /* DiagArray777 */ 2204, /* Empty */         0 },
  { /* undef-prefix */                                          16390, /* DiagArray778 */ 2206, /* Empty */         0 },
  { /* undefined-bool-conversion */                             16403, /* DiagArray779 */ 2208, /* Empty */         0 },
  { /* undefined-func-template */                               16429, /* DiagArray780 */ 2211, /* Empty */         0 },
  { /* undefined-inline */                                      16453, /* DiagArray781 */ 2213, /* Empty */         0 },
  { /* undefined-internal */                                    16470, /* DiagArray782 */ 2215, /* Empty */         0 },
  { /* undefined-internal-type */                               16489, /* DiagArray783 */ 2217, /* Empty */         0 },
  { /* undefined-reinterpret-cast */                            16513, /* DiagArray784 */ 2219, /* Empty */         0 },
  { /* undefined-var-template */                                16540, /* DiagArray785 */ 2222, /* Empty */         0 },
  { /* underaligned-exception-object */                         16563, /* DiagArray786 */ 2224, /* Empty */         0 },
  { /* unevaluated-expression */                                16593, /* DiagArray787 */ 2226, /* DiagSubGroup787 */ 553 },
  { /* unguarded-availability */                                16616, /* DiagArray788 */ 2228, /* DiagSubGroup788 */ 555 },
  { /* unguarded-availability-new */                            16639, /* DiagArray789 */ 2230, /* Empty */         0 },
  { /* unicode */                                               16666, /* DiagArray790 */ 2232, /* Empty */         0 },
  { /* unicode-homoglyph */                                     16674, /* DiagArray791 */ 2238, /* Empty */         0 },
  { /* unicode-whitespace */                                    16692, /* DiagArray792 */ 2240, /* Empty */         0 },
  { /* unicode-zero-width */                                    16711, /* DiagArray793 */ 2242, /* Empty */         0 },
  { /* uninitialized */                                         16730, /* DiagArray794 */ 2244, /* DiagSubGroup794 */ 557 },
  { /* uninitialized-const-reference */                         16744, /* DiagArray795 */ 2252, /* Empty */         0 },
  { /* unknown-argument */                                      16774, /* DiagArray796 */ 2254, /* Empty */         0 },
  { /* unknown-assumption */                                    16791, /* DiagArray797 */ 2257, /* Empty */         0 },
  { /* unknown-attributes */                                    16810, /* DiagArray798 */ 2259, /* Empty */         0 },
  { /* unknown-cuda-version */                                  16829, /* DiagArray799 */ 2261, /* Empty */         0 },
  { /* unknown-escape-sequence */                               16850, /* DiagArray800 */ 2263, /* Empty */         0 },
  { /* unknown-pragmas */                                       16874, /* DiagArray801 */ 2265, /* Empty */         0 },
  { /* unknown-sanitizers */                                    16890, /* DiagArray802 */ 2286, /* Empty */         0 },
  { /* unknown-warning-option */                                16909, /* DiagArray803 */ 2288, /* Empty */         0 },
  { /* unnamed-type-template-args */                            16932, /* DiagArray804 */ 2292, /* DiagSubGroup804 */ 561 },
  { /* unneeded-internal-declaration */                         16959, /* DiagArray805 */ 2294, /* Empty */         0 },
  { /* unneeded-member-function */                              16989, /* DiagArray806 */ 2297, /* Empty */         0 },
  { /* unreachable-code */                                      17014, /* DiagArray807 */ 2299, /* DiagSubGroup807 */ 563 },
  { /* unreachable-code-aggressive */                           17031, /* Empty */     0, /* DiagSubGroup808 */ 565 },
  { /* unreachable-code-break */                                17059, /* DiagArray809 */ 2301, /* Empty */         0 },
  { /* unreachable-code-loop-increment */                       17082, /* DiagArray810 */ 2303, /* Empty */         0 },
  { /* unreachable-code-return */                               17114, /* DiagArray811 */ 2305, /* Empty */         0 },
  { /* unsequenced */                                           17138, /* DiagArray812 */ 2307, /* Empty */         0 },
  { /* unsupported-abs */                                       17150, /* DiagArray813 */ 2310, /* Empty */         0 },
  { /* unsupported-availability-guard */                        17166, /* DiagArray814 */ 2313, /* Empty */         0 },
  { /* unsupported-cb */                                        17197, /* DiagArray815 */ 2315, /* Empty */         0 },
  { /* unsupported-dll-base-class-template */                   17212, /* DiagArray816 */ 2317, /* Empty */         0 },
  { /* unsupported-floating-point-opt */                        17248, /* DiagArray817 */ 2319, /* Empty */         0 },
  { /* unsupported-friend */                                    17279, /* DiagArray818 */ 2322, /* Empty */         0 },
  { /* unsupported-gpopt */                                     17298, /* DiagArray819 */ 2325, /* Empty */         0 },
  { /* unsupported-nan */                                       17316, /* DiagArray820 */ 2327, /* Empty */         0 },
  { /* unsupported-target-opt */                                17332, /* DiagArray821 */ 2330, /* Empty */         0 },
  { /* unsupported-visibility */                                17355, /* DiagArray822 */ 2333, /* Empty */         0 },
  { /* unusable-partial-specialization */                       17378, /* DiagArray823 */ 2335, /* Empty */         0 },
  { /* unused */                                                17410, /* Empty */     0, /* DiagSubGroup824 */ 569 },
  { /* unused-argument */                                       17417, /* Empty */     0, /* Empty */         0 },
  { /* unused-command-line-argument */                          17433, /* DiagArray826 */ 2337, /* Empty */         0 },
  { /* unused-comparison */                                     17462, /* DiagArray827 */ 2346, /* Empty */         0 },
  { /* unused-const-variable */                                 17480, /* DiagArray828 */ 2348, /* Empty */         0 },
  { /* unused-exception-parameter */                            17502, /* DiagArray829 */ 2350, /* Empty */         0 },
  { /* unused-function */                                       17529, /* DiagArray830 */ 2352, /* DiagSubGroup830 */ 579 },
  { /* unused-getter-return-value */                            17545, /* DiagArray831 */ 2354, /* Empty */         0 },
  { /* unused-label */                                          17572, /* DiagArray832 */ 2356, /* Empty */         0 },
  { /* unused-lambda-capture */                                 17585, /* DiagArray833 */ 2358, /* Empty */         0 },
  { /* unused-local-typedef */                                  17607, /* DiagArray834 */ 2360, /* Empty */         0 },
  { /* unused-local-typedefs */                                 17628, /* Empty */     0, /* DiagSubGroup835 */ 581 },
  { /* unused-macros */                                         17650, /* DiagArray836 */ 2362, /* Empty */         0 },
  { /* unused-member-function */                                17664, /* DiagArray837 */ 2364, /* DiagSubGroup837 */ 583 },
  { /* unused-parameter */                                      17687, /* DiagArray838 */ 2366, /* Empty */         0 },
  { /* unused-private-field */                                  17704, /* DiagArray839 */ 2368, /* Empty */         0 },
  { /* unused-property-ivar */                                  17725, /* DiagArray840 */ 2370, /* Empty */         0 },
  { /* unused-result */                                         17746, /* DiagArray841 */ 2372, /* Empty */         0 },
  { /* unused-template */                                       17760, /* DiagArray842 */ 2375, /* DiagSubGroup842 */ 585 },
  { /* unused-value */                                          17776, /* DiagArray843 */ 2377, /* DiagSubGroup843 */ 587 },
  { /* unused-variable */                                       17789, /* DiagArray844 */ 2384, /* DiagSubGroup844 */ 591 },
  { /* unused-volatile-lvalue */                                17805, /* DiagArray845 */ 2386, /* Empty */         0 },
  { /* used-but-marked-unused */                                17828, /* DiagArray846 */ 2388, /* Empty */         0 },
  { /* user-defined-literals */                                 17851, /* DiagArray847 */ 2390, /* Empty */         0 },
  { /* user-defined-warnings */                                 17873, /* DiagArray848 */ 2392, /* Empty */         0 },
  { /* varargs */                                               17895, /* DiagArray849 */ 2394, /* Empty */         0 },
  { /* variadic-macros */                                       17903, /* DiagArray850 */ 2398, /* Empty */         0 },
  { /* vec-elem-size */                                         17919, /* DiagArray851 */ 2402, /* Empty */         0 },
  { /* vector-conversion */                                     17933, /* DiagArray852 */ 2404, /* Empty */         0 },
  { /* vector-conversions */                                    17951, /* Empty */     0, /* DiagSubGroup853 */ 593 },
  { /* vexing-parse */                                          17970, /* DiagArray854 */ 2406, /* Empty */         0 },
  { /* visibility */                                            17983, /* DiagArray855 */ 2410, /* Empty */         0 },
  { /* vla */                                                   17994, /* DiagArray856 */ 2413, /* DiagSubGroup856 */ 595 },
  { /* vla-extension */                                         17998, /* DiagArray857 */ 2415, /* Empty */         0 },
  { /* void-pointer-to-enum-cast */                             18012, /* DiagArray858 */ 2417, /* Empty */         0 },
  { /* void-pointer-to-int-cast */                              18038, /* DiagArray859 */ 2419, /* DiagSubGroup859 */ 597 },
  { /* void-ptr-dereference */                                  18063, /* DiagArray860 */ 2421, /* Empty */         0 },
  { /* volatile-register-var */                                 18084, /* Empty */     0, /* Empty */         0 },
  { /* wasm-exception-spec */                                   18106, /* DiagArray862 */ 2423, /* Empty */         0 },
  { /* weak-template-vtables */                                 18126, /* DiagArray863 */ 2425, /* Empty */         0 },
  { /* weak-vtables */                                          18148, /* DiagArray864 */ 2427, /* Empty */         0 },
  { /* writable-strings */                                      18161, /* DiagArray865 */ 2429, /* DiagSubGroup865 */ 599 },
  { /* write-strings */                                         18178, /* Empty */     0, /* DiagSubGroup866 */ 601 },
  { /* xor-used-as-pow */                                       18192, /* DiagArray867 */ 2431, /* Empty */         0 },
  { /* zero-as-null-pointer-constant */                         18208, /* DiagArray868 */ 2435, /* Empty */         0 },
  { /* zero-length-array */                                     18238, /* DiagArray869 */ 2437, /* Empty */         0 },
#endif // GET_DIAG_TABLE


#ifdef GET_CATEGORY_TABLE
CATEGORY("", DiagCat_None)
CATEGORY("Lexical or Preprocessor Issue", DiagCat_Lexical_or_Preprocessor_Issue)
CATEGORY("Semantic Issue", DiagCat_Semantic_Issue)
CATEGORY("Lambda Issue", DiagCat_Lambda_Issue)
CATEGORY("Parse Issue", DiagCat_Parse_Issue)
CATEGORY("ARC Semantic Issue", DiagCat_ARC_Semantic_Issue)
CATEGORY("ARC and @properties", DiagCat_ARC_and__properties)
CATEGORY("ARC Casting Rules", DiagCat_ARC_Casting_Rules)
CATEGORY("ARC Parse Issue", DiagCat_ARC_Parse_Issue)
CATEGORY("ARC Weak References", DiagCat_ARC_Weak_References)
CATEGORY("ARC Restrictions", DiagCat_ARC_Restrictions)
CATEGORY("OpenMP Issue", DiagCat_OpenMP_Issue)
CATEGORY("Inline Assembly Issue", DiagCat_Inline_Assembly_Issue)
CATEGORY("AST Deserialization Issue", DiagCat_AST_Deserialization_Issue)
CATEGORY("Modules Issue", DiagCat_Modules_Issue)
CATEGORY("Coroutines Issue", DiagCat_Coroutines_Issue)
CATEGORY("Concepts Issue", DiagCat_Concepts_Issue)
CATEGORY("Dependency Directive Source Minimization Issue", DiagCat_Dependency_Directive_Source_Minimization_Issue)
CATEGORY("Backend Issue", DiagCat_Backend_Issue)
CATEGORY("Related Result Type Issue", DiagCat_Related_Result_Type_Issue)
CATEGORY("AST Serialization Issue", DiagCat_AST_Serialization_Issue)
CATEGORY("Nullability Issue", DiagCat_Nullability_Issue)
CATEGORY("Generics Issue", DiagCat_Generics_Issue)
CATEGORY("User-Defined Issue", DiagCat_User_Defined_Issue)
CATEGORY("Refactoring Invocation Issue", DiagCat_Refactoring_Invocation_Issue)
CATEGORY("VTable ABI Issue", DiagCat_VTable_ABI_Issue)
CATEGORY("Value Conversion Issue", DiagCat_Value_Conversion_Issue)
CATEGORY("Documentation Issue", DiagCat_Documentation_Issue)
CATEGORY("ARC Retain Cycle", DiagCat_ARC_Retain_Cycle)
CATEGORY("Deprecations", DiagCat_Deprecations)
CATEGORY("Format String Issue", DiagCat_Format_String_Issue)
CATEGORY("Cocoa API Issue", DiagCat_Cocoa_API_Issue)
CATEGORY("#pragma message Directive", DiagCat__pragma_message_Directive)
CATEGORY("Instrumentation Issue", DiagCat_Instrumentation_Issue)
CATEGORY("Unused Entity Issue", DiagCat_Unused_Entity_Issue)
#endif // GET_CATEGORY_TABLE

